<?php
/**
 * CLink Canonical Functions
 *
 * CLink canonical verifications and execution functions
 *
 * @package Clink
 * @subpackage System
 */
 
 // Direct Access Not Allowed
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );



/**
 * CLink Create Canonical URL for Post
 * 
 * @param string $url url of the post 
 * 
 * @return string
 */

function wpclink_show_cononical($url = false){

$cl_options = wpclink_get_option( 'preferences_general' );
// Site URL
$link_site_url = apply_filters('cl_site_link',$cl_options['sync_site']);;
	
	global $post;
	$page_id = $post->ID;

    // Disable for 'search' page
	$sync_key = get_post_meta( $page_id, 'wpclink_referent_post_synch', true );
	if ( ! empty( $sync_key ) ) {
		$canonical = $sync_key[$link_site_url]['canonical'];
		return $canonical;
	}else{
		return $url;
	}
}


/**
 * CLink Create HTML Canonical URL
 */

function wpclink_canonical_html(){
		echo '<link rel="canonical" href="'.wpclink_show_cononical().'" />';
}


/**
 * CLink Overwrite WP SEO (YOAST) URL
 * 
 */

function wpclink_remove_canonical() {
	
	global $post;
	$page_id = $post->ID;

    // Disable for 'search' page
	$sync_key = get_post_meta( $page_id, 'wpclink_referent_post_synch', true );
	
    if ( ! empty( $sync_key ) ) {
        add_filter( 'wpseo_canonical', 'wpclink_show_cononical',  10, 1 );
		
		// WordPress Canonical
		remove_action('wp_head', 'rel_canonical');
		
		//if(! has_filter( 'wpseo_canonical' ) ){
		// My Canonical
		add_action('wp_head','wpclink_canonical_html');
		//}
		
		
	}
}
// CLink canonical url overwrite
add_action('wp', 'wpclink_remove_canonical');


/**
 * Get Liecense Voilation by Site URL
 * 
 * @param string $site_url url of site 
 * 
 * @return mixed string|boolean
 */
function wpclink_first_license_violation($site_url = false){

	global $wpdb;
	
	// CLINK  TABLE
	$clink_sites_table = $wpdb->prefix . 'wpclink_licenses';
	
	$clink_site_url = urldecode($site_url);
	
	$mylink = $wpdb->get_row( "SELECT * FROM $clink_sites_table WHERE site_url LIKE '%$clink_site_url%' AND mode = 'referent' AND verification_status = 'violated' ", ARRAY_A );
	
	
	if ( null !== $mylink ) {
		return get_permalink($mylink['licensed_creation_id']);
	}else{
		 return false;
	}
	
}

/**
 * CLink Linked Site Canonical Verification
 * 
 * @param strting $single_url url of linked site
 * @param string $site_name name of linked site
 * 
 * @return boolean
 */

function wpclink_agreement_canonical_test($single_url = false, $site_name = false){
	
	 $weburl = $single_url;
		$found = false;

		$html = wpclink_file_get_contents_curl($weburl);
         
		//parsing begins here:
		$doc = new DOMDocument();
		@$doc->loadHTML($html);
		
		$link_nodes = $doc->getElementsByTagName('link');
		
		for ($link = 0; $link < $link_nodes->length; $link++){
			$mylink = $link_nodes->item($link);
			if($mylink->getAttribute('rel') == 'canonical' ){
				$full_url = $mylink->getAttribute('href');
				
				// Find WP
				if (strpos($full_url, $site_name) !== false) {
 			   		$found = true;
					break;
				}
			}
				
		}
		if($found){
			return true;
		}
		return false;
}



/**
 * CLink Canonical Linked Content Verification Cycle
 * 
 * Record How many times linked content voilate the cononical url
 * 
 */

function wpclink_canonical_linked_content(){
	
	$all_links = wpclink_get_all_license_aggregated();
	
	foreach($all_links as $single_link){
		
		$post_id = $single_link['licensed_creation_id'];
		$site_url = $single_link['site_url'];
		
		
	$all_sync_posts = get_posts( array( 'meta_key' => 'wpclink_referent_post_synch','posts_per_page' => -1 ) ); 	
  	foreach($all_sync_posts as $single_sync){
		
		$post_sync_id = $single_sync->ID;
		$get_origin_id = get_post_meta($post_sync_id,'wpclink_referent_post_synch', true);
		$catched_id = $get_origin_id[$site_url]['origin_id'];
		// Store ORIGIM
		$origin_id[] = $catched_id;
		// Strore Origin to link
		$origin_id_to_link[$catched_id] = $post_sync_id;
	}
				
			
		if(isset($origin_id_to_link[$post_id])){
			$found_id = $origin_id_to_link[$post_id];
		}
		
		
		$canonical_url_data = get_post_meta($found_id,'wpclink_referent_post_synch', true);
		$canonical_url = $canonical_url_data[$site_url]['canonical'];
		
		$match = wpclink_agreement_canonical_test($canonical_url,$site_url);
				
				if($match == false){
					update_post_meta($found_id,'wpclink_canonical_violation',1);
				}
				if($match == true){
					delete_post_meta($found_id,'wpclink_canonical_violation');
				}
	}
	
}



/**
 * CLink Canonical Linked Content Voilation Warning
 * 
 */

function wpclink_canonical_linked_warning() {
	
	$class = 'notice notice-error';
	$message = __( 'The canonical URL of this post has been modified and the License has been violated. Licensor has the right to revoke the license and blacklist your site from obtaining future content.', 'sample-text-domain' );
	
	
	$screen = get_current_screen();
	
	if($screen->post_type == 'page'){
		if(isset($_GET['post'])){
			
			if($post_canonical_violation = get_post_meta($_GET['post'],'wpclink_canonical_violation')){
				printf( '<div class="%1$s"><p>%2$s</p></div>', esc_attr( $class ), esc_html( $message ) ); 
			}

		}
	}elseif($screen->post_type == 'post'){
		if(isset($_GET['post'])){
			
			if($post_canonical_violation = get_post_meta($_GET['post'],'wpclink_canonical_violation')){
				printf( '<div class="%1$s"><p>%2$s</p></div>', esc_attr( $class ), esc_html( $message ) ); 
			}
		}
	}	
}
// Register canonical voilation warnining on WordPress Admin notices
add_action( 'admin_notices', 'wpclink_canonical_linked_warning' );


/**
 * CLink Linked Content Voilated Show In WordPress Post List
 * 
 */

function wpclink_post_list_filter_class(){
    global $typenow; // current post type
	global $post;
    add_filter( 'post_class', function( $classes, $class, $postID ) {
		
		if($post_canonical_violation = get_post_meta($postID,'wpclink_canonical_violation')){
        	$classes[] = "violated";
		}
        return $classes;
    },10,3);
}
// Register Voilated Canonical Function on Edit Post 
add_action( 'load-edit.php','wpclink_post_list_filter_class');

/**
 * CLink Filter Voilated Post
 * 
 */

function wpclink_filter_violated_posts() {
  global $typenow;
  global $wp_query;
    if ( $typenow == 'post' ) { // Your custom post type slug
      $plugins = array( 'Violated' ); // Options for the filter select field
      $current_plugin = 'all';
      if( isset( $_GET['slug'] ) ) {
        $current_plugin = $_GET['slug']; // Check if option has been selected
      } ?>
      <select name="slug" id="slug">
        <option value="all" <?php selected( 'all', $current_plugin ); ?>><?php _e( 'All', 'wisdom-plugin' ); ?></option>
        <?php foreach( $plugins as $key=>$value ) { ?>
          <option value="<?php echo esc_attr( $key ); ?>" <?php selected( $key, $current_plugin ); ?>><?php echo esc_attr( $value ); ?></option>
        <?php } ?>
      </select>
  <?php }
}
// Register Filter Voilated Post on WordPress Post List
add_action( 'restrict_manage_posts', 'wpclink_filter_violated_posts' );


/**
 * Clink Filter Voilated Post Query
 * 
 * @param string $query default query
 * 
 */

function wpclink_filter_violated_posts_slug( $query ) {
  global $pagenow;
  // Get the post type
  $post_type = isset( $_GET['post_type'] ) ? $_GET['post_type'] : '';
  if ( is_admin() && $pagenow=='edit.php' && $post_type == 'post' && isset( $_GET['slug'] ) && $_GET['slug'] !='all' ) {
    $query->query_vars['meta_key'] = 'wpclink_canonical_violation';
    $query->query_vars['meta_value'] = 1;
    $query->query_vars['meta_compare'] = '=';
  }
}
add_filter( 'parse_query', 'wpclink_filter_violated_posts_slug' );