<?php
/**
 * CLink Creation Functions
 *
 * CLink creation post and pages functions
 *
 * @package Clink
 * @subpackage Content Manager
 */
 
 // Direct Access Not Allowed
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );


/**
 * CLink Request to Care.CLink.Meda for register the content on CLink.ID
 * 
 * @param integer $post_id 
 * @param object $post 
 * 
 */

function wpclink_request_to_clink_media( $post_id, $post) {
	
	 // if our current user can't edit this post, bail
    if( !current_user_can( 'edit_post' ) ) return;
	
	if(isset($_POST['cl_register_process']) and $_POST['cl_register_process'] == '1'){
		update_post_meta($post_id,'wpclink_post_register_status',$_POST['cl_register_process']);	
	}else{
		update_post_meta($post_id,'wpclink_post_register_status',0);
	}
	
	if($content_register_restrict = get_post_meta($post_id,'wpclink_post_register_status', true)){
		if($content_register_restrict == '1'){
			return false;
		}
	}
	
	
	// RULE #1
	$current_user_id = get_current_user_id();
	$reg_creators = wpclink_get_option('authorized_creators');
	
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
	}
	
	
	// RULE #2
	// Copyright Owner or Creator
	if($copyright_owner_id == $current_user_id || $reg_creators[0] == $current_user_id){
	}else{
		return false;	
	}
	

	
	// RULE #3
	$territory = wpclink_get_option('territory_code');
	if(empty($territory)){
		// Error Message
		
		return false;
		
	}
	
	// RULE #4
	if(wpclink_clink_domain_quota() > 0){
		
	}else{
		return false;
	}
	
	// RULE #5
	$post_author_id = get_post_field( 'post_author', $post_id );
	if($current_user_id == $post_author_id){
		
	}else{
		return false;
	}
	
	
	// Party
	$clink_party_id = wpclink_get_option('authorized_party');
	
	
	// API REQUEST
	$post_title = get_the_title($post_id);
	$guid = get_the_guid($post_id);
	$permalink = get_permalink($post_id);
	
	// Author ID
	$author_id = get_post_field ('post_author', $post_id);
	$creator_id = get_user_meta($author_id,'wpclink_creator_identifier',true);
	$post_excerpts = get_the_excerpt($post_id);
	$post_type = get_post_type($post_id);
	$post_character = 'language';
	$clink_party_id = get_user_meta($clink_party_id,'wpclink_party_identifier',true);
	
	
	
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
		
	}
	
	$content = apply_filters('the_content', get_post_field('post_content', $post_id));
	$content_without_html = strip_tags($content);
	$content_word_count = str_word_count($content_without_html);
	
	$copyright_owner_user_id = $copyright_owner_id;
	$copyright_owner_user_id = get_user_meta($copyright_owner_user_id,'wpclink_creator_identifier',true);
	
	
	// If content is linked and has referent copyright Owner
	if($referent_copyright_id = get_post_meta($post_id,'wpclink_referent_copyright_owner_identifier',true)){
		
		$copyright_owner_user_id = $referent_copyright_id;
	}
	
	
	$post_year = get_the_date( 'Y', $post_id );
	$clink_language = wpclink_language_code_to_display(get_bloginfo("language"));
	$clink_terriory_code = wpclink_get_option('territory_code');
	$content_id = '';
	$clink_referent_creation_identifier = '';
	$clink_party_link_role = '';
	$clink_creation_link_role = '';
	$creation_date = get_the_date( 'F j, Y g:i a', $post_id );
	$modified_date = get_the_modified_time('U',$post_id);
	
	$care_domain_id = wpclink_get_option('domainID');
	
	
	$post_categories = wp_get_post_categories($post_id);
	
	
	$cats = array();
     
	foreach($post_categories as $c){
		$cat = get_category( $c );
		$cats[] = $cat->name;
	}
	
	
	
	$post_tags = wp_get_post_tags( $post_id );
	
	$tags = array();
	
	foreach($post_tags as $t){
		$tags[] = $t->name;
	}
	
	/*____URL____*/
	
	$url_content = WPCLINK_CREATION_API;
	
	
	$contentID = get_post_meta( $post_id, 'wpclink_creation_identifier', true );
	
	// If referent URI
	if($referent_uri = get_post_meta($post_id,'wpclink_referent_uri',true)){
		$permalink = $referent_uri;
	}
	
	if(!empty($contentID)){

	// CL Version
	$cl_version = $_POST['cl_version'];

if(isset($cl_version) and $cl_version == 1){
	
		$sending_version = array(
                    'body' => array(
						'CLinkContentID' => $contentID,
                        'post_title'  => html_entity_decode($post_title),
                        'guid'	=> $guid,
						'creation_uri' => $permalink,
						'clink_creatorID' => $creator_id,
                        'post_excerpts' => html_entity_decode($post_excerpts),
						'post_type' => strtolower($post_type),
						'clink_word_count' => $content_word_count,
						'post_charcter' => $post_character,
						'clink_partyID' => $clink_party_id,
						'copyright_owner_user_id'=> $copyright_owner_user_id,
						'post_year' => $post_year,
						'clink_category' => $cats,
						'clink_tag' => $tags,
						'clink_territory_code' => $clink_terriory_code,
						'clink_referent_creation_identifier'=> $clink_referent_creation_identifier,
						'clink_party_link_role' => $clink_party_link_role,
						'clink_creation_link_role' => $clink_creation_link_role,
						'clink_contentID' => $content_id,
						'clink_language' => $clink_language,
						'clink_post_creation_date' =>$creation_date,
						'clink_post_modification_date'=> $modified_date,
						'clink_care_domain_id' => $care_domain_id,
						'clink_edition' => 'personal',
						'action'=> 'version'
						
                    ),'timeout' => WPCLINK_API_TIMEOUT,'method' => 'POST'
                );
	
		
		if($creation_license_type = get_post_meta( $post_id, 'wpclink_creation_license_type', true )){
			// Rescricted License Only				
			if($creation_license_type == 'restricted' || $creation_license_type == 'as_is'){	
				$sending['body']['clink_license_version'] = 's-0.9';
				$sending['body']['clink_license_type'] = wpclink_get_license_type_label($creation_license_type);
			}
		}
	
		$response = wp_remote_post(
                $url_content,
                $sending_version
            );
						
			
 
            if ( is_wp_error( $response ) ) {
 
               $resposne_Array = is_wp_error( $response );
			   
			   // Response Debug
				wpclink_debug_log('PUBLISH CONTENT '.print_r($response,true));
			  
 
            }else {
				
				// Response Debug
				wpclink_debug_log('PUBLISH CONTENT '.print_r($response,true));
 
               $response_json = $response['body'];
			   $resposne_Array=json_decode($response_json,true);
  
  
	if($resposne_Array['status'] == 'version'){
		// RESPONSE
		
		
		
		if(!empty($resposne_Array['data']['id'])){
			
			if($prev_data = get_post_meta($post_id,'wpclink_versions',true)){
				
				$version_id = array($resposne_Array['data']['id']);
				
				$final_array = array_merge($prev_data,$version_id);
				
				update_post_meta($post_id,'wpclink_versions',$final_array);
				
			}else{
				
				$version_id = array($resposne_Array['data']['id']);
				update_post_meta($post_id,'wpclink_versions',$version_id);
			}
			
			
			
			
		}
	}
}


	
}else{
	
	$sending = array(
                    'body' => array(
						'CLinkContentID' => $contentID,
                        'post_title'  => html_entity_decode($post_title),
                        'guid'	=> $guid,
						'creation_uri' => $permalink,
						'clink_creatorID' => $creator_id,
                        'post_excerpts' => html_entity_decode($post_excerpts),
						'post_type' => strtolower($post_type),
						'clink_word_count' => $content_word_count,
						'post_charcter' => $post_character,
						'clink_partyID' => $clink_party_id,
						'copyright_owner_user_id'=> $copyright_owner_user_id,
						'post_year' => $post_year,
						'clink_category' => $cats,
						'clink_tag' => $tags,
						'clink_territory_code' => $clink_terriory_code,
						'clink_referent_creation_identifier'=> $clink_referent_creation_identifier,
						'clink_party_link_role' => $clink_party_link_role,
						'clink_creation_link_role' => $clink_creation_link_role,
						'clink_contentID' => $content_id,
						'clink_language' => $clink_language,
						'clink_post_creation_date' =>$creation_date,
						'clink_post_modification_date'=> $modified_date,
						'clink_care_domain_id' => $care_domain_id,
						'action'=> 'update'
						
                    ),'timeout' => WPCLINK_API_TIMEOUT,'method' => 'POST'
                );
	
	if($creation_license_type = get_post_meta( $post_id, 'wpclink_creation_license_type', true )){
		// Rescricted License Only				
		if($creation_license_type == 'restricted' || $creation_license_type == 'as_is'){	
			$sending['body']['clink_license_version'] = 's-0.9';
			$sending['body']['clink_license_type'] = wpclink_get_license_type_label($creation_license_type);
		}
	}

/* ========= UPDATE ============ */
	$response = wp_remote_post(
                $url_content,
                $sending
            );
						
			
 
            if ( is_wp_error( $response ) ) {
 
               $resposne_Array = is_wp_error( $response );
				
			   // Response Debug
				wpclink_debug_log('UPDATE CONTENT '.print_r($response,true));
			   
			  
 
            }else {
				
				// Response Debug
				wpclink_debug_log('UPDATE CONTENT '.print_r($response,true));
 
               $response_json = $response['body'];
			   $resposne_Array=json_decode($response_json,true);
			   
			 
			 
  
  
	if($resposne_Array['status'] == 'update'){
		// RESPONSE
		

	update_post_meta($post_id,'wpclink_creation_creation_date',$resposne_Array['data']['clink_creation_date']);
	update_post_meta($post_id,'wpclink_creation_modification_date',$resposne_Array['data']['clink_modification_date']);
	update_post_meta($post_id,'wpclink_creation_copyright_owner',$author_id);
	
	
	
		
	}
}

}

	}else{
/* ========= CREATE ============ */

	$response = wp_remote_post(
                $url_content,
                array(
                    'body' => array(
                        'post_title'  => html_entity_decode($post_title),
                        'guid'	=> $guid,
						'creation_uri' => $permalink,
						'clink_creatorID' => $creator_id,
                        'post_excerpts' => html_entity_decode($post_excerpts),
						'post_type' => strtolower($post_type),
						'clink_word_count' => $content_word_count,
						'post_charcter' => $post_character,
						'clink_partyID' => $clink_party_id,
						'copyright_owner_user_id'=> $copyright_owner_user_id,
						'post_year' => $post_year,
						'clink_category' => $cats,
						'clink_tag' => $tags,
						'clink_territory_code' => $clink_terriory_code,
						'clink_referent_creation_identifier'=> $clink_referent_creation_identifier,
						'clink_party_link_role' => $clink_party_link_role,
						'clink_creation_link_role' => $clink_creation_link_role,
						'clink_contentID' => $content_id,
						'clink_language' => $clink_language,
						'clink_post_creation_date' =>$creation_date,
						'clink_post_modification_date'=> $modified_date,
						'clink_care_domain_id' => $care_domain_id,
						'action'=> 'create'
						
                    ),'timeout' => WPCLINK_API_TIMEOUT,'method' => 'POST'
                )
            );
						

			 
 
            if ( is_wp_error( $response ) ) {
 
               $resposne_Array = is_wp_error( $response );
			   
			   // Response Debug
				wpclink_debug_log('PUBLISH CONTENT '.print_r($response,true));
			  
 
            }else {
				// Response Debug
				wpclink_debug_log('PUBLISH CONTENT '.print_r($response,true));
 
               $response_json = $response['body'];
			   $resposne_Array=json_decode($response_json,true);
  
			   
			   
			   
			  
	if($resposne_Array['status'] == 'create'){
		// RESPONSE
		
	update_post_meta($post_id,'wpclink_creation_identifier',$resposne_Array['data']['clink_contentID']);
	update_post_meta($post_id,'wpclink_creation_creation_date',$resposne_Array['data']['clink_creation_date']);
	update_post_meta($post_id,'wpclink_creation_modification_date',$resposne_Array['data']['clink_modification_date']);
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
		
	}
	
	
	$copyright_owner_user_id = $copyright_owner_id;
	$copyright_owner_user_id = get_user_meta($copyright_owner_user_id,'wpclink_creator_identifier',true);
	
	
	update_post_meta($post_id,'wpclink_creation_copyright_owner',$copyright_owner_user_id);
		
	}
	
}

	}

}
// Register request on publish post trigger
add_action( 'publish_post', 'wpclink_request_to_clink_media', 10, 2 );
// Register request on publish page trigger
add_action( 'publish_page', 'wpclink_request_to_clink_media', 10, 2 );

/**
 * CLink Future Requests to Care.CLink.Meda for register the content on CLink.ID
 * 
 * @param integer $post_id 
 * 
 */
function wpclink_request_to_clink_media_future($post_id) {
	
	
	// RULE #1
	$territory = wpclink_get_option('territory_code');
	if(empty($territory)){
		// Error Message
		
		return false;
		
	}
	
	// RULE #2
	if(wpclink_clink_domain_quota() > 0){
		
	}else{
		return false;
	}
	
	
	// Party
	$clink_party_id = wpclink_get_option('authorized_party');
	
	
	// API REQUEST
	$post_title = get_the_title($post_id);
	$guid = get_the_guid($post_id);
	$permalink = get_permalink($post_id);
	
	// Author ID
	$author_id = get_post_field ('post_author', $post_id);
	$creator_id = get_user_meta($author_id,'wpclink_creator_identifier',true);
	$post_excerpts = get_the_excerpt($post_id);
	$post_type = get_post_type($post_id);
	$post_character = 'language';
	$clink_party_id = get_user_meta($clink_party_id,'wpclink_party_identifier',true);
	
	
	
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
		
	}
	
	$content = apply_filters('the_content', get_post_field('post_content', $post_id));
	$content_without_html = strip_tags($content);
	$content_word_count = str_word_count($content_without_html);
	
	$copyright_owner_user_id = $copyright_owner_id;
	$copyright_owner_user_id = get_user_meta($copyright_owner_user_id,'wpclink_creator_identifier',true);
	
	
	// If content is linked and has referent copyright Owner
	if($referent_copyright_id = get_post_meta($post_id,'wpclink_referent_copyright_owner_identifier',true)){
		
		$copyright_owner_user_id = $referent_copyright_id;
	}
	
	$post_year = get_the_date( 'Y', $post_id );
	$clink_language = wpclink_language_code_to_display(get_bloginfo("language"));
	$clink_terriory_code = wpclink_get_option('territory_code');
	$content_id = '';
	$clink_referent_creation_identifier = '';
	$clink_party_link_role = '';
	$clink_creation_link_role = '';
	$creation_date = get_the_date( 'F j, Y g:i a', $post_id );
	$modified_date = get_the_modified_time('U',$post_id);
	
	$care_domain_id = wpclink_get_option('domainID');
	
	
	$post_categories = wp_get_post_categories($post_id);
	
	
	$cats = array();
     
	foreach($post_categories as $c){
		$cat = get_category( $c );
		$cats[] = $cat->name;
	}
	
	
	
	$post_tags = wp_get_post_tags( $post_id );
	
	$tags = array();
	
	foreach($post_tags as $t){
		$tags[] = $t->name;
	}
	
	/*____URL____*/
	
	$url_content = WPCLINK_CREATION_API;
	
	
	$contentID = get_post_meta( $post_id, 'wpclink_creation_identifier', true );
	
	// If referent URI
	if($referent_uri = get_post_meta($post_id,'wpclink_referent_uri',true)){
		$permalink = $referent_uri;
	}
	
	if(!empty($contentID)){


/* ========= UPDATE ============ */
	$response = wp_remote_post(
                $url_content,
                array(
                    'body' => array(
						'CLinkContentID' => $contentID,
                        'post_title'  => $post_title,
                        'guid'	=> $guid,
						'creation_uri' => $permalink,
						'clink_creatorID' => $creator_id,
                        'post_excerpts' => $post_excerpts,
						'post_type' => strtolower($post_type),
						'clink_word_count' => $content_word_count,
						'post_charcter' => $post_character,
						'clink_partyID' => $clink_party_id,
						'copyright_owner_user_id'=> $copyright_owner_user_id,
						'post_year' => $post_year,
						'clink_category' => $cats,
						'clink_tag' => $tags,
						'clink_territory_code' => $clink_terriory_code,
						'clink_referent_creation_identifier'=> $clink_referent_creation_identifier,
						'clink_party_link_role' => $clink_party_link_role,
						'clink_creation_link_role' => $clink_creation_link_role,
						'clink_contentID' => $content_id,
						'clink_language' => $clink_language,
						'clink_post_creation_date' =>$creation_date,
						'clink_post_modification_date'=> $modified_date,
						'clink_care_domain_id' => $care_domain_id,
						'clink_edition' => 'personal',						
						'action'=> 'update'
						
                    ),'timeout' => WPCLINK_API_TIMEOUT,'method' => 'POST'
                )
            );
						
			
 
            if ( is_wp_error( $response ) ) {
 
               $resposne_Array = is_wp_error( $response );
			   
			   // Response Debug
				wpclink_debug_log('PUBLISH CONTENT FUTURE '.print_r($response,true));
			  
 
            }else {
				
				// Response Debug
				wpclink_debug_log('PUBLISH CONTENT FUTURE '.print_r($response,true));
 
               $response_json = $response['body'];
			   $resposne_Array=json_decode($response_json,true);
  
  
	if($resposne_Array['status'] == 'update'){
		// RESPONSE
		

	update_post_meta($post_id,'wpclink_creation_creation_date',$resposne_Array['data']['clink_creation_date']);
	update_post_meta($post_id,'wpclink_creation_modification_date',$resposne_Array['data']['clink_modification_date']);
	
		
	}
}



	}else{
/* ========= CREATE ============ */

	$response = wp_remote_post(
                $url_content,
                array(
                    'body' => array(
                        'post_title'  => $post_title,
                        'guid'	=> $guid,
						'creation_uri' => $permalink,
						'clink_creatorID' => $creator_id,
                        'post_excerpts' => $post_excerpts,
						'post_type' => strtolower($post_type),
						'clink_word_count' => $content_word_count,
						'post_charcter' => $post_character,
						'clink_partyID' => $clink_party_id,
						'copyright_owner_user_id'=> $copyright_owner_user_id,
						'post_year' => $post_year,
						'clink_category' => $cats,
						'clink_tag' => $tags,
						'clink_territory_code' => $clink_terriory_code,
						'clink_referent_creation_identifier'=> $clink_referent_creation_identifier,
						'clink_party_link_role' => $clink_party_link_role,
						'clink_creation_link_role' => $clink_creation_link_role,
						'clink_contentID' => $content_id,
						'clink_language' => $clink_language,
						'clink_post_creation_date' =>$creation_date,
						'clink_post_modification_date'=> $modified_date,
						'clink_care_domain_id' => $care_domain_id,
						'action'=> 'create'
						
                    ),'timeout' => WPCLINK_API_TIMEOUT,'method' => 'POST'
                )
            );
						
			

 
            if ( is_wp_error( $response ) ) {
 
               $resposne_Array = is_wp_error( $response );
			   
				// Response Debug
				wpclink_debug_log('PUBLISH CONTENT FUTURE'.print_r($response,true)); 
 
            }else {
				
				// Response Debug
				wpclink_debug_log('PUBLISH CONTENT FUTURE'.print_r($response,true)); 
 
               $response_json = $response['body'];
			   $resposne_Array=json_decode($response_json,true);
  
			   
			   
			  
	if($resposne_Array['status'] == 'create'){
		// RESPONSE
		
	update_post_meta($post_id,'wpclink_creation_identifier',$resposne_Array['data']['clink_contentID']);
	update_post_meta($post_id,'wpclink_creation_creation_date',$resposne_Array['data']['clink_creation_date']);
	update_post_meta($post_id,'wpclink_creation_modification_date',$resposne_Array['data']['clink_modification_date']);
	
		
	}
	
	
}

	}

}
// Register future request to care.clink.media function
add_action( 'publish_future_post', 'wpclink_request_to_clink_media_future' );


/**
 * Clink Create Linked Page
 * 
 * @return interger page id
 */
function wpclink_generation_page(){
	
$cl_options = wpclink_get_option( 'preferences_general' );
// Site URL
$link_site_url = apply_filters('cl_site_link',$cl_options['sync_site']);;

if (!isset($_GET['_action_nonce_get']) || !wp_verify_nonce($_GET['_action_nonce_get'], 'content_get_post')) {
	return false;
}

if(wpclink_user_readonly()){
		return false;
}

// Validate
if(!isset($_GET['p_sync']) and $_GET['action'] != 'sync') return false;	

/* ====== PREPARING REQUEST ======= */
$request_query = array();
$request_query['post__in'] = $_GET['p_sync'];
$request_query['get_type'] = 'content';
$request_query['post_type'] = 'c-page';
$origin_data = array();

$build_query = build_query( $request_query );

/* ====== QUERY REQUEST ======= */
$context  = stream_context_create(array('http' => array('header' => 'Accept: application/xml')));
$xml=file_get_contents(wpclink_linked_site().'&'.$build_query,false,$context);
$xml = simplexml_load_string($xml);

$result_update = false;

foreach($xml->channel->item as $single){ 

/* ===== PREPARING DATA ===== */

// Post ID
$post_id_old = (int)$single->post_id; 

// Post Title
$post_title = (string)$single->title;

// Post Link
$post_link = (string)$single->link;

// Post Author
$ns_dc = $single->children('http://purl.org/dc/elements/1.1/');
$post_author = $ns_dc->creator_id;

// Post Content 
$post_content = (string)$single->children("content", true);

// Post Excerpt 
$post_excerpt = (string)$single->children("excerpt", true);

// Post Parent		  
$post_parent = (string)$single->children('wp', true)->post_parent;

// License Type
$post_license_type = (string)$single->post_license_type;

// Post Copyright Owner
$post_copyright_owner = (string)$single->post_copyright_owner;

// ContentID
$post_contentID = (string)$single->content_id;

// Post Creator ID
$post_creator_clinkid = (string)$single->post_creator_clink_id;

// Post Creator
$post_creator = (string)$single->post_creator;

// Image URL		  
if($single->children('wp', true)->post_thumbnail){
	$image_url = $single->children('wp', true)->post_thumbnail->children()->post_thumbnail_url;
}else{
	$image_url = NULL;
}

// Modified Time
$modified_time = (string)$single->modified_time;




/* ====== INSERT POST ======= */
// Initialize the page ID to -1. This indicates no action has been taken.
	$post_id = -1;
	// Setup the author, slug, and title for the post
	
	$selected_author = wpclink_get_option('page_author_assign');
	if(empty($selected_author) or $selected_author == false){
		$author_id = get_current_user_id();
	}else{
		$author_id = $selected_author;
	}
	
	$time = current_time( 'Y-m-d', $gmt = 0 );
	$origin_data = array();
	
	
	
	// No Found Parent
	$found_parent = 0;
	
	
	// If the page doesn't already exist, then create it
	
	
	/* == PAGE PARENT PREPATION == */
	$all_posts = get_posts( array( 'meta_key' => 'wpclink_referent_post_synch','posts_per_page' => -1, 'post_type' => 'page') );
	
	foreach ( $all_posts as $post_see ) {
		$data_post_see = get_post_meta($post_see->ID,'wpclink_referent_post_synch',true);
		$origin_id_get = $data_post_see[$link_site_url]['origin_id'];
		// Debug
		//print_r($origin_id_get);
		
		echo $post_parent."->". $origin_id_get;
		echo "<br />";
			
		if($post_parent == $origin_id_get){
			$found_parent = $post_see->ID;
			break;
		}
	}
	

		// Set the post ID so that we know the post was created successfully
		if($post_id = wp_insert_post(
			array(
				'comment_status'	=>	'closed',
				'ping_status'		=>	'closed',
				'post_author'		=>	$author_id,
				'post_title'		=>	$post_title,
				'post_status'		=>	'publish',
				'post_content'  => $post_content,
				'post_excerpt' => $post_excerpt,
				'post_type'		=>	'page',
				'post_parent'	=> $found_parent
				
			),true
		)){

		  // Origin
		  $time = current_time( 'Y-m-d', $gmt = 0 );
		  $origin_data[$link_site_url] = array(	'origin_id' => $post_id_old, 
		  																'last_sync' => $time,
																		'sync_status' => true,
																		'sync_parent' => $post_parent,
																		'canonical'   => $post_link);
																		
																		
		 update_post_meta($post_id, 'wpclink_referent_uri', $post_link);
		 update_post_meta($post_id, 'wpclink_creation_reuse_status', 1);
		 update_post_meta($post_id, 'wpclink_creation_license_type', $post_license_type);
		
		// Post Creator ID
		$post_creator_clinkid = (string)$single->post_creator_clink_id;

		// Post Creator
		$post_creator = (string)$single->post_creator;
		 
		  // License Type
		  $license_type_post = wpclink_get_license_type_by_id(wpclink_get_license_type_by_content($post_id));
		  
		  if($post_license_type == 'restricted'){
			 // Referent Copyright Owner
		 	 update_post_meta($post_id, 'wpclink_referent_copyright_owner_identifier', $post_copyright_owner); 
		  }
		  
		  
		  
		  $content = apply_filters('the_content', get_post_field('post_content', $post_id));
		  $content_without_html = strip_tags($content);
		  $content_word_count = str_word_count($content_without_html);
		  
		  // Update post
		  if($updated_post_meta = update_post_meta($post_id, 'wpclink_referent_post_synch', $origin_data)){
				if($updated_post_meta = update_post_meta($post_id, 'origin_parent', $post_parent)){	  
				
					$result_update = $updated_post_meta;
					$updated_post_id = $updated_post_meta;
					
					if(!empty($image_url)){
						// Set Image
					wpclink_post_thumbnail_generator($post_id,$image_url);
					}
					
					//Update Time
		  			update_post_meta($post_id, 'wpclink_referent_last_update', $modified_time);
		  
					
				}
				
			

// CODRA


// RULE #1
	$current_user_id = get_current_user_id();
	$reg_creators = wpclink_get_option('authorized_creators');
	
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
	}
	
	
// RULE #2
	if($copyright_owner_id == $current_user_id || $reg_creators[0] == $current_user_id){
	}else{
		return false;
	}
	
// RULE #3
	$territory = wpclink_get_option('territory_code');
	if(empty($territory)){
		// Error Message
		
		return false;
		
	}
	
// RULE #4
	if(wpclink_clink_domain_quota() > 0){
		
	}else{
		return false;
	}
	
	
	
	// Party
	$clink_party_id = wpclink_get_option('authorized_party');
	
	
	// API REQUEST
	$post_title = get_the_title($post_id);
	$guid = get_the_guid($post_id);
	$permalink = get_permalink($post_id);
	
	// Author ID
	$author_id = get_post_field ('post_author', $post_id);
	$creator_id = get_user_meta($author_id,'wpclink_creator_identifier',true);
	$post_excerpts = get_the_excerpt($post_id);
	$post_type = get_post_type($post_id);
	$post_character = 'language';
	$clink_party_id = get_user_meta($clink_party_id,'wpclink_party_identifier',true);
	
	
	
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
		
	}
	
	$copyright_owner_user_id = $copyright_owner_id;
	$copyright_owner_user_id = get_user_meta($copyright_owner_user_id,'wpclink_creator_identifier',true);
	
	$post_year = get_the_date( 'Y', $post_id );
	$clink_language = wpclink_language_code_to_display(get_bloginfo("language"));
	$clink_terriory_code = wpclink_get_option('territory_code');
	$content_id = '';
	$clink_referent_creation_identifier = $post_contentID;
	$clink_party_link_role = 'Licensee';
	$clink_creation_link_role = 'LicensedContent';
	$creation_date = get_the_date( 'F j, Y g:i a', $post_id );
	$modified_date = get_the_modified_time('U',$post_id);
	
	$care_domain_id = wpclink_get_option('domainID');
	
	
	$post_categories = wp_get_post_categories($post_id);
	
	
	$cats = array();
	
	
	$post_tags = wp_get_post_tags( $post_id );
	
	$tags = array();
	
	/*____URL____*/
	
	$url_content = WPCLINK_CREATION_API;
	
	
	$contentID = get_post_meta( $post_id, 'wpclink_creation_identifier', true );
	
	


/* ========= CREATE ============ */

	$response = wp_remote_post(
                $url_content,
                array(
                    'body' => array(
                        'post_title'  => html_entity_decode($post_title),
                        'guid'	=> $guid,
						'creation_uri' => $post_link,
						'clink_creatorID' => $creator_id,
                        'post_excerpts' => html_entity_decode($post_excerpts),
						'post_type' => strtolower($post_type),
						'clink_word_count' => $content_word_count,
						'post_charcter' => $post_character,
						'clink_partyID' => $clink_party_id,
						'copyright_owner_user_id'=> $post_copyright_owner,
						'post_year' => $post_year,
						'clink_category' => $cats,
						'clink_tag' => $tags,
						'clink_territory_code' => $clink_terriory_code,
						'clink_referent_creation_identifier'=> $clink_referent_creation_identifier,
						'clink_party_link_role' => '',
						'clink_creation_link_role' => $clink_creation_link_role,
						'clink_contentID' => $content_id,
						'clink_license_type' => wpclink_get_license_type_label($post_license_type),
						'clink_license_version' => 's-0.9',
						'clink_language' => $clink_language,
						'clink_post_creation_date' =>$creation_date,
						'clink_post_modification_date'=> $modified_date,
						'clink_care_domain_id' => $care_domain_id,
						'clink_edition' => 'personal',
						'action'=> 'create'
						
                    ),'timeout' => WPCLINK_API_TIMEOUT,'method' => 'POST'
                )
            );
						
			
			
			 
            if ( is_wp_error( $response ) ) {
 
               $resposne_Array = is_wp_error( $response );
				
				// Response Debug
				wpclink_debug_log('GENERATE PAGE '.print_r($response,true));
			    
            }else {
				
				// Response Debug
				wpclink_debug_log('GENERATE PAGE '.print_r($response,true));
 
               $response_json = $response['body'];
			   $resposne_Array=json_decode($response_json,true);
 			   
			  
	if($resposne_Array['status'] == 'create'){
		// RESPONSE
		
	update_post_meta($post_id,'wpclink_creation_identifier',$resposne_Array['data']['clink_contentID']);
	// REFERENT ID
	update_post_meta($post_id,'wpclink_referent_creation_identifier',$post_contentID);
	update_post_meta($post_id,'wpclink_referent_creator_identifier',$post_author_creator);
	update_post_meta($post_id,'wpclink_creation_creation_date',$resposne_Array['data']['clink_creation_date']);
	update_post_meta($post_id,'wpclink_creation_modification_date',$resposne_Array['data']['clink_modification_date']);
	//update_post_meta($post_id,'createdBy',$resposne_Array['data']['clink_createdBy']);
	//update_post_meta($post_id,'modifiedBy',$resposne_Array['data']['clink_modifiedBy']);	
		
	}

	
			}

		  	
			  }else{

		 
		  }
	}

	



}	// Return Post ID
	return $result_update;
}





/**
 * Clink Create Linked Multi Select Page
 * 
 * @return interger page id
 */
function wpclink_generation_page_multiple(){
	
$cl_options = wpclink_get_option( 'preferences_general' );
// Site URL
$link_site_url = apply_filters('cl_site_link',$cl_options['sync_site']);

// Validate
if(empty($_POST['post']) or !isset($_POST['action']) or !isset($_POST['action2'])) return false;
if(($_POST['action'] == 'sync' and $_POST['action2'] == '-1') or ($_POST['action'] == '-1' and $_POST['action2'] == 'sync')){
}else{
	return false;
}

if(wpclink_user_readonly()){
	return false;
}

/* ====== PREPARING REQUEST ======= */
$request_query = array();

$all_posts = $_POST['post'];
$comma_posts = implode(",",$all_posts);
$request_query['post__in'] = $comma_posts;
$request_query['nopaging'] = true;
$request_query['post_type'] = 'c-page';
$request_query['get_type'] = 'content';
$origin_data = array();

$build_query = build_query( $request_query );

/* ====== QUERY REQUEST ======= */
$context  = stream_context_create(array('http' => array('header' => 'Accept: application/xml')));
$xml=file_get_contents(wpclink_linked_site().'&'.$build_query,false,$context);
$xml = simplexml_load_string($xml);

$result_update = false;


foreach($xml->channel->item as $single){ 

/* ===== PREPARING DATA ===== */

// Post ID
$post_id_old = (int)$single->post_id; 

// Post Title
$post_title = (string)$single->title;

// Post Link
$post_link = (string)$single->link;

// Post Author
$ns_dc = $single->children('http://purl.org/dc/elements/1.1/');
$post_author = $ns_dc->creator_id;

// Post Content 
$post_content = (string)$single->children("content", true);

// Post Excerpt 
$post_excerpt = (string)$single->children("excerpt", true);

  // Post Parent		  
$post_parent = (string)$single->children('wp', true)->post_parent;

// Modified Time
$modified_time = (string)$single->modified_time;

// License Type
$post_license_type = (string)$single->post_license_type;

// Post Copyright Owner
$post_copyright_owner = (string)$single->post_copyright_owner;

// ContentID
$post_contentID = (string)$single->content_id;
	
// Post Creator ID
$post_creator_clinkid = (string)$single->post_creator_clink_id;

// Post Creator
$post_creator = (string)$single->post_creator;


// Image URL		  
if($single->children('wp', true)->post_thumbnail){
	$image_url = $single->children('wp', true)->post_thumbnail->children()->post_thumbnail_url;
}else{
	$image_url = NULL;
}


/* ====== INSERT POST ======= */


// Initialize the page ID to -1. This indicates no action has been taken.
	$post_id = -1;
	

	// Setup the author, slug, and title for the post
	
	$selected_author = wpclink_get_option('page_author_assign');
	if(empty($selected_author) or $selected_author == false){
		$author_id = get_current_user_id();
	}else{
		$author_id = $selected_author;
	}
	
	$time = current_time( 'Y-m-d', $gmt = 0 );
	$origin_data = array();
	$found_id = array();
	
	
	// No Found Parent
	$found_parent = 0;
	
	
	// If the page doesn't already exist, then create it
	
	
	/* == PAGE PARENT PREPATION == */
	$all_posts = get_posts( array( 'meta_key' => 'wpclink_referent_post_synch','posts_per_page' => -1, 'post_type' => 'page') );
	
	foreach ( $all_posts as $post_see ) {
		$data_post_see = get_post_meta($post_see->ID,'wpclink_referent_post_synch',true);
		$origin_id_get = $data_post_see[$link_site_url]['origin_id'];

		//print_r($origin_id_get);
		
		echo $post_parent."->". $origin_id_get;
		echo "<br />";
			
		if($post_parent == $origin_id_get){
			$found_parent = $post_see->ID;
			break;
		}
	}
	
	

		// Set the post ID so that we know the post was created successfully
		if($post_id = wp_insert_post(
			array(
				'comment_status'	=>	'closed',
				'ping_status'		=>	'closed',
				'post_author'		=>	$author_id,
				'post_title'		=>	$post_title,
				'post_status'		=>	'publish',
				'post_content'  => $post_content,
				'post_excerpt' => $post_excerpt,
				'post_type'		=>	'page',
				'post_parent' => $found_parent,
				
			),true
		)){

		  // Origin
		  $time = current_time( 'Y-m-d', $gmt = 0 );
		  $origin_data[$link_site_url] = array('origin_id' => $post_id_old, 'last_sync' => $time, 'sync_status' => true,'sync_parent'=> $post_parent, 'canonical' => $post_link);
		  
		  $post_parent = 0;
		  
		 update_post_meta($post_id, 'wpclink_referent_uri', $post_link);
		 update_post_meta($post_id, 'wpclink_creation_reuse_status', 1);
		 update_post_meta($post_id, 'wpclink_creation_license_type', $post_license_type);
		 
		 update_post_meta($post_id, 'wpclink_post_creator_id', $post_creator_clinkid);
		 update_post_meta($post_id, 'wpclink_post_creator', $post_creator);
		 
		 // License Type
		  $license_type_post = wpclink_get_license_type_by_id(wpclink_get_license_type_by_content($post_id));
		  
		  if($post_license_type == 'restricted'){
			 // Referent Copyright Owner
		 	 update_post_meta($post_id, 'wpclink_referent_copyright_owner_identifier', $post_copyright_owner); 
		  }
		  
		  $content = apply_filters('the_content', get_post_field('post_content', $post_id));
		  $content_without_html = strip_tags($content);
		  $content_word_count = str_word_count($content_without_html);
		  
		  // Update post
		  if($updated_post_meta = update_post_meta($post_id, 'wpclink_referent_post_synch', $origin_data)){	  
		  		if($updated_post_meta = update_post_meta($post_id, 'origin_parent', $post_parent)){	  
				
					$result_update = $updated_post_meta;
					$updated_post_id = $updated_post_meta;
					
					if(!empty($image_url)){
						// Set Image
					wpclink_post_thumbnail_generator($post_id,$image_url);
					}
					
					//Update Time
				  update_post_meta($post_id, 'wpclink_referent_last_update', $modified_time);
					
				}

			  }else{
		  	
		  }
		  
		  
		  
// CODRA


	// RULE #1
	$current_user_id = get_current_user_id();
	$reg_creators = wpclink_get_option('authorized_creators');
	
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
	}
	
	
	// RULE #2
	// Copyright Owner or Creator
	if($copyright_owner_id == $current_user_id || $reg_creators[0] == $current_user_id){
	}else{
		return false;	
	}
	
	
	// RULE #3
	$territory = wpclink_get_option('territory_code');
	if(empty($territory)){
		// Error Message
		
		return false;
		
	}
	
	// RULE #4
	if(wpclink_clink_domain_quota() > 0){
		
	}else{
		return false;
	}
	
	
	
	// Party
	$clink_party_id = wpclink_get_option('authorized_party');
	
	
	// API REQUEST
	$post_title = get_the_title($post_id);
	$guid = get_the_guid($post_id);
	$permalink = get_permalink($post_id);
	
	// Author ID
	$author_id = get_post_field ('post_author', $post_id);
	$creator_id = get_user_meta($author_id,'wpclink_creator_identifier',true);
	$post_excerpts = get_the_excerpt($post_id);
	$post_type = get_post_type($post_id);
	$post_character = 'language';
	$clink_party_id = get_user_meta($clink_party_id,'wpclink_party_identifier',true);
	
	
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
		
	}
	
	$copyright_owner_user_id = $copyright_owner_id;
	$copyright_owner_user_id = get_user_meta($copyright_owner_user_id,'wpclink_creator_identifier',true);
	
	$post_year = get_the_date( 'Y', $post_id );
	$clink_language = wpclink_language_code_to_display(get_bloginfo("language"));
	$clink_terriory_code = wpclink_get_option('territory_code');
	$content_id = '';
	$clink_referent_creation_identifier = $post_contentID;
	$clink_party_link_role = 'Licensee';

	$clink_creation_link_role = 'LicensedContent';
	$creation_date = get_the_date( 'F j, Y g:i a', $post_id );
	$modified_date = get_the_modified_time('U',$post_id);
	
	$care_domain_id = wpclink_get_option('domainID');
	
	$post_categories = wp_get_post_categories($post_id);
	
	
	$cats = array();
	
	
	$post_tags = wp_get_post_tags( $post_id );
	
	$tags = array();
	
	/*____URL____*/
	
	$url_content = WPCLINK_CREATION_API;
	
	$contentID = get_post_meta( $post_id, 'wpclink_creation_identifier', true );
	
	


/* ========= CREATE ============ */

	$response = wp_remote_post(
                $url_content,
                array(
                    'body' => array(
                        'post_title'  => html_entity_decode($post_title),
                        'guid'	=> $guid,
						'creation_uri' => $post_link,
						'clink_creatorID' => $creator_id,
                        'post_excerpts' => html_entity_decode($post_excerpts),
						'post_type' => strtolower($post_type),
						'clink_word_count' => $content_word_count,
						'post_charcter' => $post_character,
						'clink_partyID' => $clink_party_id,
						'copyright_owner_user_id'=> $post_copyright_owner,
						'post_year' => $post_year,
						'clink_category' => $cats,
						'clink_tag' => $tags,
						'clink_territory_code' => $clink_terriory_code,
						'clink_referent_creation_identifier'=> $clink_referent_creation_identifier,
						'clink_party_link_role' => '',
						'clink_creation_link_role' => $clink_creation_link_role,
						'clink_contentID' => $content_id,
						'clink_license_type' => wpclink_get_license_type_label($post_license_type),
						'clink_license_version' => 's-0.9',
						'clink_language' => $clink_language,
						'clink_post_creation_date' =>$creation_date,
						'clink_post_modification_date'=> $modified_date,
						'clink_care_domain_id' => $care_domain_id,
						'clink_edition' => 'personal',
						'action'=> 'create'
						
                    ),'timeout' => WPCLINK_API_TIMEOUT,'method' => 'POST'
                )
            );
						
 
            if ( is_wp_error( $response ) ) {
 
               $resposne_Array = is_wp_error( $response );
				
				// Response Debug
				wpclink_debug_log('GENERATE PAGE MULTIPLE '.print_r($response,true));
			   
 
            }else {
				
				// Response Debug
				wpclink_debug_log('GENERATE PAGE MULTIPLE '.print_r($response,true));
 
               $response_json = $response['body'];
			   $resposne_Array=json_decode($response_json,true);
  
			   
			  
	if($resposne_Array['status'] == 'create'){
		// RESPONSE
		
		update_post_meta($post_id,'wpclink_creation_identifier',$resposne_Array['data']['clink_contentID']);
		// REFERENT ID
		update_post_meta($post_id,'wpclink_referent_creation_identifier',$post_contentID);
		update_post_meta($post_id,'wpclink_referent_creator_identifier',$post_author_creator);
		update_post_meta($post_id,'wpclink_creation_creation_date',$resposne_Array['data']['clink_creation_date']);
		update_post_meta($post_id,'wpclink_creation_modification_date',$resposne_Array['data']['clink_modification_date']);
		
	}
			}
	  
	}

}	// Return Post ID
	return $result_update;
}



/**
 * CLink Update Linked Page
 * 
 * 
 * @return integer page id
 */
function wpclink_update_page(){
	
$cl_options = wpclink_get_option( 'preferences_general' );
// Site URL
$link_site_url = apply_filters('cl_site_link',$cl_options['sync_site']);;

// Validate
if(!isset($_GET['p_sync']) and $_GET['action'] != 'sync_update' and $_GET['cl_type'] != 'page' and !isset($_GET['update_to'])) return false;	

// Update Page
$update_post_id = (int)$_GET['update_to'];

/* ====== PREPARING REQUEST ======= */
$request_query = array();
$request_query['post__in'] = $_GET['p_sync'];
$request_query['get_type'] = 'content';
$request_query['post_type'] = 'c-page';
$origin_data = array();

$build_query = build_query( $request_query );

/* ====== QUERY REQUEST ======= */
$context  = stream_context_create(array('http' => array('header' => 'Accept: application/xml')));
$xml=file_get_contents(wpclink_linked_site().'&'.$build_query,false,$context);
$xml = simplexml_load_string($xml);

$result_update = false;

foreach($xml->channel->item as $single){ 

/* ===== PREPARING DATA ===== */

// Post ID
$post_id_old = (int)$single->post_id; 

// Post Title
$post_title = (string)$single->title;

// Post Link
$post_link = (string)$single->link;

// Post Author
$ns_dc = $single->children('http://purl.org/dc/elements/1.1/');
$post_author = $ns_dc->creator_id;

// Post Content 
$post_content = (string)$single->children("content", true);

// Post Excerpt 
$post_excerpt = (string)$single->children("excerpt", true);

// Post Parent		  
$post_parent = (string)$single->children('wp', true)->post_parent;

// Image URL		  
$image_url = (string)$single->children('wp', true)->post_thumbnail->children()->post_thumbnail_url;

// Modified Time
$modified_time = (string)$single->modified_time;



/* ====== INSERT POST ======= */
// Initialize the page ID to -1. This indicates no action has been taken.
	$post_id = -1;
	// Setup the author, slug, and title for the post
	
	$selected_author = wpclink_get_option('page_author_assign');
	if(empty($selected_author) or $selected_author == false){
		$author_id = get_current_user_id();
	}else{
		$author_id = $selected_author;
	}
	
	$time = current_time( 'Y-m-d', $gmt = 0 );
	$origin_data = array();
	
	
	
	// No Found Parent
	$found_parent = 0;
	
	
	// If the page doesn't already exist, then create it
	
	
	/* == PAGE PARENT PREPATION == */
	$all_posts = get_posts( array( 'meta_key' => 'wpclink_referent_post_synch','posts_per_page' => -1, 'post_type' => 'page') );
	
	foreach ( $all_posts as $post_see ) {
		$data_post_see = get_post_meta($post_see->ID,'wpclink_referent_post_synch',true);
		$origin_id_get = $data_post_see[$link_site_url]['origin_id'];

		//print_r($origin_id_get);
		
		echo $post_parent."->". $origin_id_get;
		echo "<br />";
			
		if($post_parent == $origin_id_get){
			$found_parent = $post_see->ID;
			break;
		}
	}
	
	

		// Set the post ID so that we know the post was created successfully
		if($post_id = wp_update_post(
			array(
				'ID'				=> $update_post_id,
				'comment_status'	=>	'closed',
				'ping_status'		=>	'closed',
				'post_author'		=>	$author_id,
				'post_title'		=>	$post_title,
				'post_status'		=>	'publish',
				'post_content'  => $post_content,
				'post_excerpt' => $post_excerpt,
				'post_type'		=>	'page',
				'post_parent'	=> $found_parent
				
			),true
		)){
			
			// CLEAN
		  delete_post_meta($update_post_id, 'wpclink_referent_post_synch');
		
		  // Origin
		  $time = current_time( 'Y-m-d', $gmt = 0 );
		  $origin_data[$link_site_url] = array(	'origin_id' => $post_id_old, 
		  																'last_sync' => $time,
																		'sync_status' => true,
																		'sync_parent' => $post_parent,
																		'canonical'   => $post_link,
																		'modified_time' => $modified_time);
		  
		
		  
		
		  // Update post
		  if($updated_post_meta = update_post_meta($update_post_id, 'wpclink_referent_post_synch', $origin_data)){
			  
				if($updated_post_meta = update_post_meta($update_post_id, 'origin_parent', $post_parent)){	  
				}
				
					$result_update = $updated_post_meta;
					$updated_post_id = $updated_post_meta;
					
					if(!empty($image_url)){
						// Set Image
					wpclink_post_thumbnail_generator($update_post_id,$image_url);
					}
					
					//Update Time
					update_post_meta($update_post_id, 'wpclink_referent_last_update', $modified_time);
				
		  	
			  }else{
				  
				 		  
		  }
	}

	// Otherwise, we'll stop
	// end if



}	// Return Post ID
	return $result_update;
}



/**
 * CLink Create Linked Post
 *  
 * @return interger post id
 */

function wpclink_generation_post(){
	
$cl_options = wpclink_get_option( 'preferences_general' );
// Site URL
$link_site_url = apply_filters('cl_site_link',$cl_options['sync_site']);



if (!isset($_GET['_action_nonce_get']) || !wp_verify_nonce($_GET['_action_nonce_get'], 'content_get_post')) {
	return false;
}


if(wpclink_user_readonly()){
	return false;
}

// Validate
if(!isset($_GET['p_sync']) and $_GET['action'] != 'sync') return false;	

/* ====== PREPARING REQUEST ======= */
$request_query = array();
$request_query['post__in'] = $_GET['p_sync'];
$request_query['post_type'] = 'c-post';
$request_query['get_type'] = 'content';
$origin_data = array();

$build_query = build_query( $request_query );

/* ====== QUERY REQUEST ======= */
$context  = stream_context_create(array('http' => array('header' => 'Accept: application/xml')));
$xml=file_get_contents(wpclink_linked_site().'&'.$build_query,false,$context);
$xml = simplexml_load_string($xml);

$result_update = false;

foreach($xml->channel->item as $single){ 

/* ===== PREPARING DATA ===== */

// Post ID
$post_id_old = (int)$single->post_id; 

// Post Title
$post_title = (string)$single->title;

// Post Link
$post_link = (string)$single->link;

// ContentID
$post_contentID = (string)$single->content_id;

// License Type
$post_license_type = (string)$single->post_license_type;

// Post Creator ID
$post_creator_clinkid = (string)$single->post_creator_clink_id;

// Post Creator
$post_creator = (string)$single->post_creator;

// Post Copyright Owner
$post_copyright_owner = (string)$single->post_copyright_owner;

// Post Author
$ns_dc = $single->children('http://purl.org/dc/elements/1.1/');
$post_author = $ns_dc->creator_id;

$post_author_creator = (string)$ns_dc->creator;

// Post Content 
$post_content = (string)$single->children("content", true);

// Post Excerpt 
$post_excerpt = (string)$single->children("excerpt", true);

// Image URL		  
if($single->children('wp', true)->post_thumbnail){
	$image_url = $single->children('wp', true)->post_thumbnail->children()->post_thumbnail_url;
}else{
	$image_url = NULL;
}

// Modified Time
$modified_time = (string)$single->modified_time;



/* ===== GET CATEGORY NAME ==== */
$assign_cat = array();

foreach($single->category as $single_cat){
$category_arr = $single_cat->attributes();
if($category_arr["domain"] == 'category'){
	$assign_cat[] = (string)$single_cat;
}
}

/* ====== INSERT POST ======= */

// Initialize the page ID to -1. This indicates no action has been taken.
	$post_id = -1;
	

	// Setup the author, slug, and title for the post
	
	$selected_author = wpclink_get_option('post_author_assign');
	if(empty($selected_author) or $selected_author == false){
		$author_id = get_current_user_id();
	}else{
		$author_id = $selected_author;
	}
	
	$time = current_time( 'Y-m-d', $gmt = 0 );
	$origin_data = array();
	$found_id = array();
	
	
	
	
	$selected_cat = wpclink_get_option('post_cat_assign');
	if((empty($selected_cat)) or ($selected_cat == false) or ($selected_cat == '-1')){
		
	foreach($assign_cat as $cat_single){
	
		$term = term_exists($cat_single, 'category');
		if ($term !== 0 && $term !== null) {
			$found_id[]= $term['term_id'];
		}else{
			$found_id[] = wp_create_category( $cat_single, '0' );
		}
	
	}
		
	}else{
		$found_id = array($selected_cat);
	}
	
		// Set the post ID so that we know the post was created successfully
		if($post_id = wp_insert_post(
			array(
				'comment_status'	=>	'closed',
				'ping_status'		=>	'closed',
				'post_author'		=>	$author_id,
				'post_title'		=>	$post_title,
				'post_status'		=>	'publish',
				'post_content'  => $post_content,
				'post_excerpt' => $post_excerpt,
				'post_type'		=>	'post',
				'post_category' => $found_id
				
			),true
		)){

		  // Origin
		  $time = current_time( 'Y-m-d', $gmt = 0 );
		  $origin_data[$link_site_url] = array('origin_id' => $post_id_old, 'last_sync' => $time, 'sync_status' => true,'canonical'	=>	$post_link);
		  
		  
		  // Origin Url_shorten(
		  update_post_meta($post_id, 'wpclink_referent_uri', $post_link);
		  update_post_meta($post_id, 'wpclink_creation_reuse_status', 1);
		  
		  update_post_meta($post_id, 'wpclink_post_creator_id', $post_creator_clinkid);
		  update_post_meta($post_id, 'wpclink_post_creator', $post_creator);
		  
		  // License Type
		  update_post_meta($post_id, 'wpclink_creation_license_type', $post_license_type);
		  
		  
		  if($post_license_type == 'restricted'){
			 // Referent Copyright Owner
		 	 update_post_meta($post_id, 'wpclink_referent_copyright_owner_identifier', $post_copyright_owner); 
		  }
		  
		  // Update post
		  if($updated_post_meta = update_post_meta($post_id, 'wpclink_referent_post_synch', $origin_data)){	  

		  $result_update = $updated_post_meta;
		  $updated_post_id = $updated_post_meta;
		  
		  
		  if(!empty($image_url)){
		  // Set Image
		  wpclink_post_thumbnail_generator($post_id,$image_url);
		  }
		  
		  
		  //Update Time
		  update_post_meta($post_id, 'wpclink_referent_last_update', $modified_time);
		  
		  
		  // Referent Categories
		  update_post_meta($post_id, 'wpclink_creation_referent_categories', $found_id);
		  
		  // License Type
		  $license_type_post = wpclink_get_license_type_by_id(wpclink_get_license_type_by_content($post_id));
		  
		  $content = apply_filters('the_content', get_post_field('post_content', $post_id));
		  $content_without_html = strip_tags($content);
		  $content_word_count = str_word_count($content_without_html);
		  
		  
		  $tags_catch = array();
		  $tag_on = false;

  		  // Get All Tags
		  foreach($single->category as $single_tag){
		  
			$tags_arr = $single_tag->attributes();
			if($tags_arr["domain"] == 'post_tag'){	
				$tags_catch[] = (string)$single_tag;
				$tag_on = true;	
			}
		  }
		 
		  
		  foreach($tags_catch as $tag_single){
	
		  $term_tag = term_exists($tag_single, 'post_tag');
		  if ($term_tag !== 0 && $term_tag !== null) {
			  
			  // Assign
			  $term_id = $term_tag['term_id'];
			  $term = get_term( $term_id, 'post_tag' );
			  wp_set_post_tags( $post_id, $term->name, true );
			  
		  }else{
			  wp_set_post_tags( $post_id, $tag_single, true );
		  }
	
		}
		
		
		
		// Referent Tags
		  update_post_meta($post_id, 'wpclink_creation_referent_tags', $tags_catch);
		
			
			

// CODRA


// RULE #1
	$current_user_id = get_current_user_id();
	$reg_creators = wpclink_get_option('authorized_creators');
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
	}
	
// RULE #2	
	// Copyright Owner or Creator
	if($copyright_owner_id == $current_user_id || $reg_creators[0] == $current_user_id){
	}else{
		return false;	
	}
	

	
// RULE #3
	$territory = wpclink_get_option('territory_code');
	if(empty($territory)){
		// Error Message
		
		return false;
		
	}
	
// RULE #4
	if(wpclink_clink_domain_quota() > 0){

	}else{
		return false;
	}
	
	
	
	// Party
	$clink_party_id = wpclink_get_option('authorized_party');
	
	
	// API REQUEST
	$post_title = get_the_title($post_id);
	$guid = get_the_guid($post_id);
	$permalink = get_permalink($post_id);
	
	// Author ID
	$author_id = get_post_field ('post_author', $post_id);
	$creator_id = get_user_meta($author_id,'wpclink_creator_identifier',true);
	$post_excerpts = get_the_excerpt($post_id);
	$post_type = get_post_type($post_id);
	$post_character = 'language';
	$clink_party_id = get_user_meta($clink_party_id,'wpclink_party_identifier',true);
	
	
	
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
		
	}
	
	$copyright_owner_user_id = $copyright_owner_id;
	$copyright_owner_user_id = get_user_meta($copyright_owner_user_id,'wpclink_creator_identifier',true);
	
	$post_year = get_the_date( 'Y', $post_id );
	$clink_language = wpclink_language_code_to_display(get_bloginfo("language"));
	$clink_terriory_code = wpclink_get_option('territory_code');
	$content_id = '';
	$clink_referent_creation_identifier = $post_contentID;
	$clink_party_link_role = 'Licensee';
	$clink_creation_link_role = 'LicensedContent';
	$creation_date = get_the_date( 'F j, Y g:i a', $post_id );
	$modified_date = get_the_modified_time('U',$post_id);
	
	$care_domain_id = wpclink_get_option('domainID');
	
	
	$post_categories = wp_get_post_categories($post_id);
	
	
	$cats = array();
     
	foreach($post_categories as $c){
		$cat = get_category( $c );
		$cats[] = $cat->name;
	}
	
	
	
	$post_tags = wp_get_post_tags( $post_id );
	
	$tags = array();
	
	foreach($post_tags as $t){
		$tags[] = $t->name;
	}
	
	/*____URL____*/
	
	$url_content = WPCLINK_CREATION_API;
	
	
	$contentID = get_post_meta( $post_id, 'wpclink_creation_identifier', true );
	
	
	$sending = array(
                    'body' => array(
                        'post_title'  => html_entity_decode($post_title),
                        'guid'	=> $guid,
						'creation_uri' => $post_link,
						'clink_creatorID' => $creator_id,
                        'post_excerpts' => html_entity_decode($post_excerpts),
						'post_type' => strtolower($post_type),
						'clink_word_count' => $content_word_count,
						'post_charcter' => $post_character,
						'clink_partyID' => $clink_party_id,
						'copyright_owner_user_id'=> $post_copyright_owner,
						'post_year' => $post_year,
						'clink_category' => $cats,
						'clink_tag' => $tags,
						'clink_territory_code' => $clink_terriory_code,
						'clink_referent_creation_identifier'=> $clink_referent_creation_identifier,
						'clink_party_link_role' => '',
						'clink_creation_link_role' => $clink_creation_link_role,
						'clink_contentID' => $content_id,
						'clink_license_type' => wpclink_get_license_type_label($post_license_type),
						'clink_license_version' => 's-0.9',
						'clink_language' => $clink_language,
						'clink_post_creation_date' =>$creation_date,
						'clink_post_modification_date'=> $modified_date,
						'clink_care_domain_id' => $care_domain_id,
						'clink_edition' => 'personal',
						'action'=> 'create'
						
                    ),'timeout' => WPCLINK_API_TIMEOUT,'method' => 'POST'
                );

/* ========= CREATE ============ */

	$response = wp_remote_post(
                $url_content,
                $sending 
            );
			  
			  wpclink_debug_log('GENERATE PRE POST '.print_r($sending,true));
						
 
            if ( is_wp_error( $response ) ) {
 
               $resposne_Array = is_wp_error( $response );
				
				// Response Debug
				wpclink_debug_log('GENERATE POST '.print_r($response,true));
			   

            }else {
				
				// Response Debug
				wpclink_debug_log('GENERATE POST '.print_r($response,true));
 
               $response_json = $response['body'];
			   $resposne_Array=json_decode($response_json,true);
  
			   
	 
			   
			  
	if($resposne_Array['status'] == 'create'){
		// RESPONSE
		
	update_post_meta($post_id,'wpclink_creation_identifier',$resposne_Array['data']['clink_contentID']);
	// REFERENT ID
	update_post_meta($post_id,'wpclink_referent_creation_identifier',$post_contentID);
	update_post_meta($post_id,'wpclink_referent_creator_identifier',$post_author_creator);
	update_post_meta($post_id,'wpclink_creation_creation_date',$resposne_Array['data']['clink_creation_date']);
	update_post_meta($post_id,'wpclink_creation_modification_date',$resposne_Array['data']['clink_modification_date']);
		
	}
	
			}
		  	
			  }else{

		  }
	}

	



}	// Return Post ID
	return $result_update;
}

/**
 * Clink Create Linked Multi Select Post
 * 
 * @return interger post id
 */

function wpclink_generation_post_multiple(){
	
$cl_options = wpclink_get_option( 'preferences_general' );
// Site URL
$link_site_url = apply_filters('cl_site_link',$cl_options['sync_site']);


// Validate
if(empty($_POST['post']) or !isset($_POST['action']) or !isset($_POST['action2'])) return false;
if(($_POST['action'] == 'sync' and $_POST['action2'] == '-1') or ($_POST['action'] == '-1' and $_POST['action2'] == 'sync')){
}else{
	return false;
}


if(wpclink_user_readonly()){
	return false;
}

/* ====== PREPARING REQUEST ======= */
$request_query = array();

$all_posts = $_POST['post'];
$comma_posts = implode(",",$all_posts);
$request_query['post__in'] = $comma_posts;
$request_query['post_type'] = 'c-post';
$request_query['nopaging'] = true;

$request_query['get_type'] = 'content';
$origin_data = array();

$build_query = build_query( $request_query );

/* ====== QUERY REQUEST ======= */
$context  = stream_context_create(array('http' => array('header' => 'Accept: application/xml')));
$xml=file_get_contents(wpclink_linked_site().'&'.$build_query,false,$context);
$xml = simplexml_load_string($xml);

$result_update = false;


foreach($xml->channel->item as $single){ 

/* ===== PREPARING DATA ===== */

// Post ID
$post_id_old = (int)$single->post_id; 

// Post Title
$post_title = (string)$single->title;

// Post link
$post_link = (string)$single->link;

// ContentID
$post_contentID = (string)$single->content_id;

// License Type
$post_license_type = (string)$single->post_license_type;

// Post Creator ID
$post_creator_clinkid = (string)$single->post_creator_clink_id;

// Post Creator
$post_creator = (string)$single->post_creator;

// Post Copyright Owner
$post_copyright_owner = (string)$single->post_copyright_owner;

// Post Author
$ns_dc = $single->children('http://purl.org/dc/elements/1.1/');
$post_author = $ns_dc->creator_id;

// Post Content 
$post_content = (string)$single->children("content", true);

// Post Excerpt 
$post_excerpt = (string)$single->children("excerpt", true);

// Modified Time
$modified_time = (string)$single->modified_time;

// Image URL		  
if($single->children('wp', true)->post_thumbnail){
	$image_url = $single->children('wp', true)->post_thumbnail->children()->post_thumbnail_url;
}else{
	$image_url = NULL;
}

// Post Copyright Owner
$post_copyright_owner = (string)$single->post_copyright_owner;

/* ===== GET CATEGORY NAME ==== */
$assign_cat = array();

foreach($single->category as $single_cat){
$category_arr = $single_cat->attributes();
if($category_arr["domain"] == 'category'){
	$assign_cat[] = (string)$single_cat;
}
}

/* ====== INSERT POST ======= */

// Initialize the page ID to -1. This indicates no action has been taken.
	$post_id = -1;
	

	// Setup the author, slug, and title for the post
	
	$selected_author = wpclink_get_option('post_author_assign');
	if(empty($selected_author) or $selected_author == false){
		$author_id = get_current_user_id();
	}else{
		$author_id = $selected_author;
	}
	
	$time = current_time( 'Y-m-d', $gmt = 0 );
	$origin_data = array();
	$found_id = array();
		
	
	$selected_cat = wpclink_get_option('post_cat_assign');
	if((empty($selected_cat)) or ($selected_cat == false) or ($selected_cat == '-1')){
		
	foreach($assign_cat as $cat_single){
	
		$term = term_exists($cat_single, 'category');
		if ($term !== 0 && $term !== null) {
			$found_id[]= $term['term_id'];
		}else{
			$found_id[] = wp_create_category( $cat_single, '0' );
		}
	
	}
		
	}else{
		$found_id = array($selected_cat);
	}
	
	// If the page doesn't already exist, then create it
	

		// Set the post ID so that we know the post was created successfully
		if($post_id = wp_insert_post(
			array(
				'comment_status'	=>	'closed',
				'ping_status'		=>	'closed',
				'post_author'		=>	$author_id,
				'post_title'		=>	$post_title,
				'post_status'		=>	'publish',
				'post_content'  => $post_content,
				'post_excerpt' => $post_excerpt,
				'post_type'		=>	'post',
				'post_category' => $found_id
				
			),true
		)){
		

		  // Origin
		  $time = current_time( 'Y-m-d', $gmt = 0 );
		  $origin_data[$link_site_url] = array('origin_id' => $post_id_old, 'last_sync' => $time, 'sync_status' => true,'canonical' => $post_link);
		  
		  
		  
		  // Origin Url_shorten(
		  update_post_meta($post_id, 'wpclink_referent_uri', $post_link);
		  update_post_meta($post_id, 'wpclink_creation_reuse_status', 1);
		  
		  update_post_meta($post_id, 'wpclink_post_creator_id', $post_creator_clinkid);
		  update_post_meta($post_id, 'wpclink_post_creator', $post_creator);
		  
		  // License Type
		  update_post_meta($post_id, 'wpclink_creation_license_type', $post_license_type);
		  
		  
		  if($post_license_type == 'restricted'){
			 // Referent Copyright Owner
		 	 update_post_meta($post_id, 'wpclink_referent_copyright_owner_identifier', $post_copyright_owner); 
		  }
		  
		  // Update post
		  if($updated_post_meta = update_post_meta($post_id, 'wpclink_referent_post_synch', $origin_data)){	  

		  $result_update = $updated_post_meta;
		  $updated_post_id = $updated_post_meta;
		  
		  
		 	 if(!empty($image_url)){
						// Set Image
				wpclink_post_thumbnail_generator($post_id,$image_url);
			}
		  
		  //Update Time
		  update_post_meta($post_id, 'wpclink_referent_last_update', $modified_time);
		  
		  // Referent Categories
		  update_post_meta($post_id, 'wpclink_creation_referent_categories', $found_id);
		  
		  // License Type
		  $license_type_post = wpclink_get_license_type_by_id(wpclink_get_license_type_by_content($post_id));
		  
		  $content = apply_filters('the_content', get_post_field('post_content', $post_id));
		  $content_without_html = strip_tags($content);
		  $content_word_count = str_word_count($content_without_html);
		  
		  
		  $tags_catch = array();
		  $tag_on = false;

  		  // Get All Tags
		  foreach($single->category as $single_tag){
		  
			$tags_arr = $single_tag->attributes();
			if($tags_arr["domain"] == 'post_tag'){	
				$tags_catch[] = (string)$single_tag;
				$tag_on = true;	
			}
		  }
		 
		  
		  foreach($tags_catch as $tag_single){
	
		  $term_tag = term_exists($tag_single, 'post_tag');
		  if ($term_tag !== 0 && $term_tag !== null) {
			  
			  // Assign
			  $term_id = $term_tag['term_id'];
			  $term = get_term( $term_id, 'post_tag' );
			  wp_set_post_tags( $post_id, $term->name, true );
			  
		  }else{
			  wp_set_post_tags( $post_id, $tag_single, true );
		  }
	
		}
			
			// Referent Tags
		  update_post_meta($post_id, 'wpclink_creation_referent_tags', $tags_catch);
			
			 						

// CODRA

	// RULE #1
	$current_user_id = get_current_user_id();
	$reg_creators = wpclink_get_option('authorized_creators');
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
	}
	
	// RULE #2
	// Copyright Owner or Creator
	if($copyright_owner_id == $current_user_id || $reg_creators[0] == $current_user_id){
	}else{
		return false;	
	}
	
	// RULE #3
	$territory = wpclink_get_option('territory_code');
	if(empty($territory)){
		// Error Message
		
		return false;
		
	}
	
	// RULE #4
	if(wpclink_clink_domain_quota() > 0){
		
	}else{
		return false;
	}
	
	
	
	// Party
	$clink_party_id = wpclink_get_option('authorized_party');
	
	
	// API REQUEST
	$post_title = get_the_title($post_id);
	$guid = get_the_guid($post_id);
	$permalink = get_permalink($post_id);
	
	// Author ID
	$author_id = get_post_field ('post_author', $post_id);
	$creator_id = get_user_meta($author_id,'wpclink_creator_identifier',true);
	$post_excerpts = get_the_excerpt($post_id);
	$post_type = get_post_type($post_id);
	$post_character = 'language';
	$clink_party_id = get_user_meta($clink_party_id,'wpclink_party_identifier',true);
	
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
		
	}
	
	$copyright_owner_user_id = $copyright_owner_id;
	$copyright_owner_user_id = get_user_meta($copyright_owner_user_id,'wpclink_creator_identifier',true);
	
	$post_year = get_the_date( 'Y', $post_id );
	$clink_language = wpclink_language_code_to_display(get_bloginfo("language"));
	$clink_terriory_code = wpclink_get_option('territory_code');
	$content_id = '';
	$clink_referent_creation_identifier = $post_contentID;
	$clink_party_link_role = 'Licensee';
	$clink_creation_link_role = 'LicensedContent';
	$creation_date = get_the_date( 'F j, Y g:i a', $post_id );
	$modified_date = get_the_modified_time('U',$post_id);
	
	$care_domain_id = wpclink_get_option('domainID');
	
	
	$post_categories = wp_get_post_categories($post_id);
	
	
	$cats = array();
     
	foreach($post_categories as $c){
		$cat = get_category( $c );
		$cats[] = $cat->name;
	}
	
	
	$post_tags = wp_get_post_tags( $post_id );
	
	$tags = array();
	
	foreach($post_tags as $t){
		$tags[] = $t->name;
	}
	
	/*____URL____*/
	
	$url_content = WPCLINK_CREATION_API;
	
	
	$contentID = get_post_meta( $post_id, 'wpclink_creation_identifier', true );
	
	
	$sending = array(
                    'body' => array(
                        'post_title'  => html_entity_decode($post_title),
                        'guid'	=> $guid,
						'creation_uri' => $post_link,
						'clink_creatorID' => $creator_id,
                        'post_excerpts' => html_entity_decode($post_excerpts),
						'post_type' => strtolower($post_type),
						'clink_word_count' => $content_word_count,
						'post_charcter' => $post_character,
						'clink_partyID' => $clink_party_id,
						'copyright_owner_user_id'=> $post_copyright_owner,
						'post_year' => $post_year,
						'clink_category' => $cats,
						'clink_tag' => $tags,
						'clink_territory_code' => $clink_terriory_code,
						'clink_referent_creation_identifier'=> $clink_referent_creation_identifier,
						'clink_party_link_role' => '',
						'clink_creation_link_role' => $clink_creation_link_role,
						'clink_contentID' => $content_id,
						'clink_license_type' => wpclink_get_license_type_label($post_license_type),
						'clink_license_version' => 's-0.9',
						'clink_language' => $clink_language,
						'clink_post_creation_date' =>$creation_date,
						'clink_post_modification_date'=> $modified_date,
						'clink_care_domain_id' => $care_domain_id,
						'clink_edition' => 'personal',
						'action'=> 'create'
						
                    ),'timeout' => WPCLINK_API_TIMEOUT,'method' => 'POST'
                );

/* ========= CREATE ============ */

	$response = wp_remote_post(
                $url_content,
                $sending 
            );
						
 
            if ( is_wp_error( $response ) ) {
 
               $resposne_Array = is_wp_error( $response );   
				
				// Response Debug
				wpclink_debug_log('GENERATE POST MULTIPLE'.print_r($response,true));
			  
 
            }else {
				
				// Response Debug
				wpclink_debug_log('GENERATE POST MULTIPLE'.print_r($response,true));
 
               $response_json = $response['body'];
			   $resposne_Array=json_decode($response_json,true);
  			   
			  
		if($resposne_Array['status'] == 'create'){
			// RESPONSE

		update_post_meta($post_id,'wpclink_creation_identifier',$resposne_Array['data']['clink_contentID']);
		// REFERENT ID
		update_post_meta($post_id,'wpclink_referent_creation_identifier',$post_contentID);
		update_post_meta($post_id,'wpclink_referent_creator_identifier',$post_author_creator);
		update_post_meta($post_id,'wpclink_creation_creation_date',$resposne_Array['data']['clink_creation_date']);
		update_post_meta($post_id,'wpclink_creation_modification_date',$resposne_Array['data']['clink_modification_date']);

		}

			}
		  		  	
			  }else{

		  }
	}

	



	}	// Return Post ID
	return $result_update;
}

/**
 * CLink Update Linked Post
 * 
 * 
 * @return integer post id
 */

function wpclink_update_post(){
		
$cl_options = wpclink_get_option( 'preferences_general' );
// Site URL
$link_site_url = apply_filters('cl_site_link',$cl_options['sync_site']);


// Validate
if(!isset($_GET['p_sync']) and $_GET['action'] != 'sync_update' and !isset($_GET['update_to'])) return false;	

// ONLY POST
if($_GET['cl_type'] != 'post') return false;

/* ====== PREPARING REQUEST ======= */
$request_query = array();
$request_query['post__in'] = $_GET['p_sync'];
$request_query['get_type'] = 'content';
$request_query['post_type'] = 'c-post';
$origin_data = array();


$update_post_id = (int)$_GET['update_to'];

$build_query = build_query( $request_query );

/* ====== QUERY REQUEST ======= */
$context  = stream_context_create(array('http' => array('header' => 'Accept: application/xml')));
$xml=file_get_contents(wpclink_linked_site().'&'.$build_query,false,$context);
$xml = simplexml_load_string($xml);

$result_update = false;


foreach($xml->channel->item as $single){ 

/* ===== PREPARING DATA ===== */

// Post ID
$post_id_old = (int)$single->post_id; 

// Post Title
$post_title = (string)$single->title;

// Post Link
$post_link = (string)$single->link;

// Post Author
$ns_dc = $single->children('http://purl.org/dc/elements/1.1/');
$post_author = $ns_dc->creator_id;

// Post Content 
$post_content = (string)$single->children("content", true);

// Post Excerpt 
$post_excerpt = (string)$single->children("excerpt", true);

// Image URL		  
$image_url = (string)$single->children('wp', true)->post_thumbnail->children()->post_thumbnail_url;

// Modified Time
$modified_time = (string)$single->modified_time;





/* ===== GET CATEGORY NAME ==== */
$assign_cat = array();

foreach($single->category as $single_cat){
$category_arr = $single_cat->attributes();
if($category_arr["domain"] == 'category'){
	$assign_cat[] = (string)$single_cat;
}
}

/* ====== INSERT POST ======= */


// Initialize the page ID to -1. This indicates no action has been taken.
	$post_id = -1;
	

	// Setup the author, slug, and title for the post
	
	$selected_author = wpclink_get_option('post_author_assign');
	if(empty($selected_author) or $selected_author == false){
		$author_id = get_current_user_id();
	}else{
		$author_id = $selected_author;
	}
	
	$time = current_time( 'Y-m-d', $gmt = 0 );
	$origin_data = array();
	$found_id = array();
	
	
	
	
	$selected_cat = wpclink_get_option('post_cat_assign');
	if((empty($selected_cat)) or ($selected_cat == false) or ($selected_cat == '-1')){
		
	foreach($assign_cat as $cat_single){
	
		$term = term_exists($cat_single, 'category');
		if ($term !== 0 && $term !== null) {
			$found_id[]= $term['term_id'];
		}else{
			$found_id[] = wp_create_category( $cat_single, '0' );
		}
	
	}
		
	}else{
		$found_id = array($selected_cat);
	}
	

	// If the page doesn't already exist, then create it
	//if( null == get_page_by_title( $post_title ) ) 

		// Set the post ID so that we know the post was created successfully
		if($post_id = wp_update_post(
			array(
				'ID'				=> $update_post_id,
				'comment_status'	=>	'closed',
				'ping_status'		=>	'closed',
				'post_author'		=>	$author_id,
				'post_title'		=>	$post_title,
				'post_status'		=>	'publish',
				'post_content'  => $post_content,
				'post_excerpt' => $post_excerpt,
				'post_type'		=>	'post',
				'post_category' => $found_id
				
			),true
		)){

		  // Origin
		  $time = current_time( 'Y-m-d', $gmt = 0 );
		  
		  $origin_data[$link_site_url] = array('origin_id' => $post_id_old, 'last_sync' => $time, 'sync_status' => true,'canonical' =>	$post_link);
		  

		  
		  // CLEAN
		  delete_post_meta($update_post_id, 'wpclink_referent_post_synch');
		  
		  // Update post
		  if($updated_post_meta = update_post_meta($update_post_id, 'wpclink_referent_post_synch', $origin_data)){	  

		  $result_update = $updated_post_meta;
		  $updated_post_id = $updated_post_meta;
		  
		  
		  if(!empty($image_url)){
		  // Set Image
		  wpclink_post_thumbnail_generator($post_id,$image_url);
		  }
		  	 
		  
		  //Update Time
		  update_post_meta($post_id, 'wpclink_referent_last_update', $modified_time);
		  
		  
		  $tags_catch = array();
		  $tag_on = false;

  		  // Get All Tags
		  foreach($single->category as $single_tag){
		  
			$tags_arr = $single_tag->attributes();
			if($tags_arr["domain"] == 'post_tag'){	
				$tags_catch[] = (string)$single_tag;
				$tag_on = true;	
			}
		  }
		 
		  
		  foreach($tags_catch as $tag_single){
	
		  $term_tag = term_exists($tag_single, 'post_tag');
		  if ($term_tag !== 0 && $term_tag !== null) {
			  
			  // Assign
			  $term_id = $term_tag['term_id'];
			  $term = get_term( $term_id, 'post_tag' );
			  wp_set_post_tags( $post_id, $term->name, true );
			  
		  }else{
			  wp_set_post_tags( $post_id, $tag_single, true );
		  }
	
		}
		  	
			  }else{

		  }
	}

	


}	// Return Post ID
	return $result_update;
}


/**
 * CLink Remove Meta Boxes on the Linked Content
 * 
 */
function wpclink_remove_meta_box_linked_content() {
	
	
	
	if(isset($_GET['post'])){
		
	// post id
	$post_id = $_GET['post'];
	
		// Linked
		if($sync_origin = get_post_meta( $post_id, 'wpclink_referent_uri', true )){
		
			// For Posts
			remove_meta_box( 'categorydiv', 'post', 'normal' );
			remove_meta_box( 'slugdiv', 'post', 'normal' );
			remove_meta_box( 'tagsdiv-post_tag', 'post', 'normal' );
			remove_meta_box( 'authordiv', 'post', 'normal' );
			remove_meta_box( 'postcustom', 'post', 'normal' );
			remove_meta_box( 'postimagediv', 'post', 'normal' );
			remove_meta_box( 'revisionsdiv', 'page', 'normal' );
			remove_meta_box( 'revisionsdiv', 'post', 'normal' );
			
			// For Pages
			remove_meta_box( 'postcustom', 'page', 'normal' );
			remove_meta_box( 'slugdiv', 'page', 'normal' );
			remove_meta_box( 'postcustom' , 'page' , 'normal' ); 
			
		}

	}
	 
	 
}
// Register the clink remove meta boxes function 
add_action( 'admin_menu', 'wpclink_remove_meta_box_linked_content' );




/**
 * CLink Remove Featured Image Meta Box on Linked Content
 * 
 */
function wpclink_remove_featured_image_meta_box_linked_content() {
	
	if(isset($_GET['post'])){
		
	// post id
	$post_id = $_GET['post'];
	
		// Linked
		if($sync_origin = get_post_meta( $post_id, 'wpclink_referent_uri', true )){
			
			remove_meta_box( 'postimagediv','post','side' );
			remove_meta_box( 'postimagediv','page','side' );
			
		}
	}
	
}
add_action( 'do_meta_boxes', 'wpclink_remove_featured_image_meta_box_linked_content' );


/**
 * CLink Remove TinyMce Features on the Linked Content
 * 
 * @param array $settings settings of the tinymce
 * @param integer $editor_id id of the tinymce editor
 * 
 * @return array
 */

function wpclink_remove_wp_tinymce_linked_content( $settings, $editor_id ) {
	
	// Only Post and Pages
    if ( $editor_id === 'content' && get_current_screen()->post_type === 'post' ||
		 $editor_id === 'content' && get_current_screen()->post_type === 'page'
	 ) {
		 
		 if(isset($_GET['post'])){
			 if(is_numeric($_GET['post'])){
		 
			 // Post ID
			$post_id = $_GET['post'];
		
			// Only Linked Content
			if($sync_origin = get_post_meta( $post_id, 'wpclink_referent_uri', true )){
			 
			 
			$settings['tinymce']   = false;
			$settings['quicktags'] = false;
			$settings['media_buttons'] = false;
		
			}
		}
		
		}
    }

    return $settings;
}
// Register clink remove tinymce function
add_filter( 'wp_editor_settings', 'wpclink_remove_wp_tinymce_linked_content', 10, 2 );

/**
 * CLink Disable Editing on the Linked Content
 * 
 * It is disabled the editiog for those post which are linked to another site.
 */
function wpclink_disable_editing_linked_content(){
	
	// Only Post and Pages
    if ( get_current_screen()->post_type === 'post' ||
		 get_current_screen()->post_type === 'page'
	 ) {
		 
		 if(isset($_GET['post'])){
			 if(is_numeric($_GET['post'])){
		 
			 // Post ID
			$post_id = $_GET['post'];
		
			// Only Linked Content
			if($sync_origin = get_post_meta( $post_id, 'wpclink_referent_uri', true )){
				
				
				$license_type = get_post_meta( $post_id, 'wpclink_creation_license_type', true );
	
		if($license_type == 'restricted'){
				
				// Disabled on Restricted License
				echo '<script type="text/javascript">jQuery(".postarea .wp-editor-area").prop( "disabled", true ); jQuery("#postdivrich").css("margin-top","15px"); jQuery("textarea#excerpt").prop( "disabled", true ); 
				jQuery("#preview-action").hide();
				jQuery( document ).ready(function() {
				jQuery(".show_version").hide();
				jQuery(".make_version ").hide();
				});
				 </script>';
				 
		}else{
			// Other Licenses
			echo '<script type="text/javascript">jQuery(".postarea .wp-editor-area").prop( "disabled", true ); jQuery("#postdivrich").css("margin-top","15px"); jQuery("textarea#excerpt").prop( "disabled", true ); jQuery(".misc-pub-post-status").addClass("disable_now");
				
				jQuery(".misc-pub-post-status").find("input, textarea, button, select").attr("disabled","disabled");
				jQuery("#preview-action").hide();
				jQuery("#delete-action").hide();
				
				jQuery( document ).ready(function() {
					jQuery(".make_version").addClass("disable_now").attr("disabled","disabled").removeAttr("href");
					jQuery(".show_version").hide();
					jQuery(".make_version ").hide();
					jQuery("#delete-action").hide();
				});
				
				
				 </script>';
			
		}
				
			}
			
			}
		 }
	 }
	
}
// Register Clink disable editiong on linked content function
add_action('admin_footer','wpclink_disable_editing_linked_content');

/**
 * CLink Disable Editing on the Referent Linked Contents and Remove Meta Boxes
 * 
 */
function wpclink_disabled_editing_referent_content_boxes(){
	// Only Post and Pages

		 
		 if(isset($_GET['post'])){
			 if(is_numeric($_GET['post'])){
		 
				 // Post ID
				$post_id = $_GET['post'];
				
				if(wpclink_is_content_linked($post_id) > 0){
					
					remove_meta_box( 'slugdiv', 'post', 'normal' );
					remove_meta_box( 'slugdiv', 'page', 'normal' );
					remove_meta_box( 'authordiv', 'post', 'normal' );
					remove_meta_box( 'authordiv', 'page', 'normal' );
					remove_meta_box( 'postcustom' , 'post' , 'normal' ); 
					remove_meta_box( 'postcustom' , 'page' , 'normal' ); 
					
				}
		  	
	}  	}
}
// Register clink disable editing on referent linked contents and remove meta boxes function
add_action( 'admin_menu', 'wpclink_disabled_editing_referent_content_boxes' );
