<?php
/**
 * CLink License Functions
 *
 * CLink creation license functions
 *
 * @package CLink
 * @subpackage Link Manager
 */

// Direct Access Not Allowed
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

/**
 * CLink Request to Update the Content License Type for CLink.ID
 * 
 * @param integer $post_id post id for update
 * @param integer $license_type license type As Is | Restricted
 * 
 */

function wpclink_request_to_update_the_license( $post_id, $license_type = '') {
	
	
	
	// RULE #1
	if(wpclink_clink_domain_quota() > 0){
		
	}else{
		return false;
	}
	
	
	// Party
	$clink_party_id = wpclink_get_option('authorized_party');
	
	
	// API REQUEST
	$post_title = get_the_title($post_id);
	$guid = get_the_guid($post_id);
	$permalink = get_permalink($post_id);
	
	// Author ID
	$author_id = get_post_field ('post_author', $post_id);
	$creator_id = get_user_meta($author_id,'wpclink_creator_identifier',true);
	$post_excerpts = get_the_excerpt($post_id);
	$post_type = get_post_type($post_id);
	$post_character = 'language';
	$clink_party_id = get_user_meta($clink_party_id,'wpclink_party_identifier',true);
	
	
	
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
		
	}
	
	$copyright_owner_user_id = $copyright_owner_id;
	$copyright_owner_user_id = get_user_meta($copyright_owner_user_id,'wpclink_creator_identifier',true);
	
	$post_year = get_the_date( 'Y', $post_id );
	$clink_language = wpclink_language_code_to_display(get_bloginfo("language"));
	$clink_terriory_code = wpclink_get_option('territory_code');
	$content_id = '';
	$clink_referent_creation_identifier = '';
	$clink_party_link_role = '';
	$clink_creation_link_role = '';
	$creation_date = get_the_date( 'F j, Y g:i a', $post_id );
	$modified_date = get_the_modified_time('U',$post_id);
	
	$content = apply_filters('the_content', get_post_field('post_content', $post_id));
	$content_without_html = strip_tags($content);
	$content_word_count = str_word_count($content_without_html);
	
	$care_domain_id = wpclink_get_option('domainID');
	
	
	$post_categories = wp_get_post_categories($post_id);
	
	
	$cats = array();
     
	foreach($post_categories as $c){
		$cat = get_category( $c );
		$cats[] = $cat->name;
	}
	
	
	
	$post_tags = wp_get_post_tags( $post_id );
	
	$tags = array();
	
	foreach($post_tags as $t){
		$tags[] = $t->name;
	}
	
	/*____URL____*/
	
	$url_content = WPCLINK_CREATION_API;
	
	
	$contentID = get_post_meta( $post_id, 'wpclink_creation_identifier', true );
	
	if(!empty($contentID)){


	

/* ========= UPDATE ============ */
	$response = wp_remote_post(
                $url_content,
                array(
                    'body' => array(
						'CLinkContentID' => $contentID,
                        'post_title'  => html_entity_decode($post_title),
                        'guid'	=> $guid,
						'creation_uri' => $permalink,
						'clink_creatorID' => $creator_id,
                        'post_excerpts' => html_entity_decode($post_excerpts),
						'post_type' => strtolower($post_type),
						'clink_word_count' => $content_word_count,
						'clink_license_type' => wpclink_get_license_type_label($license_type),
						'clink_license_version' => 's-0.9',
						'post_charcter' => $post_character,
						'clink_partyID' => $clink_party_id,
						'copyright_owner_user_id'=> $copyright_owner_user_id,
						'post_year' => $post_year,
						'clink_category' => $cats,
						'clink_tag' => $tags,
						'clink_territory_code' => $clink_terriory_code,
						'clink_referent_creation_identifier'=> $clink_referent_creation_identifier,
						'clink_party_link_role' => $clink_party_link_role,
						'clink_creation_link_role' => $clink_creation_link_role,
						'clink_contentID' => $content_id,
						'clink_language' => $clink_language,
						'clink_post_creation_date' =>$creation_date,
						'clink_post_modification_date'=> $modified_date,
						'clink_care_domain_id' => $care_domain_id,
						'clink_edition' => 'personal',						
						'action'=> 'update'
						
                    ),'timeout' => WPCLINK_API_TIMEOUT,'method' => 'POST'
                )
            );
						
			
 
            if ( is_wp_error( $response ) ) {
 
               $resposne_Array = is_wp_error( $response );
			   
			   
			  // Response Debug
				wpclink_debug_log('CONTENT LICENSE UPDATE'.print_r($response,true));
 
            }else {
				
			  // Response Debug
				wpclink_debug_log('CONTENT LICENSE UPDATE'.print_r($response,true));
 
               $response_json = $response['body'];
			   $resposne_Array=json_decode($response_json,true);
  
  
	if($resposne_Array['status'] == 'update'){
		// RESPONSE
		

	update_post_meta($post_id,'wpclink_creation_creation_date',$resposne_Array['data']['clink_creation_date']);
	update_post_meta($post_id,'wpclink_creation_modification_date',$resposne_Array['data']['clink_modification_date']);
			
	}
}

}



}


/**
 * CLink Get All Content IDs From IP
 * 
 * @return array content ids
 */

function wpclink_get_all_content_from_ip(){
	
	global $wpdb;
	
	// CLINK  TABLE
	$clink_sites_table = $wpdb->prefix . 'wpclink_licenses';
	
	$ip_address = wpclink_get_client_ip();
	
	// QUERY
	$license_promote = $wpdb->get_results( "SELECT licensed_creation_id FROM $clink_sites_table WHERE site_IP = '$ip_address' AND verification_status = 'good' AND mode = 'referent' ", ARRAY_A );
	
	$content_ids = array();
	
	
	foreach($license_promote as $single_license){
		
		$content_ids[] = $single_license['licensed_creation_id'];
	}
	
	return $content_ids;
	
}

/**
 * CLink Get License ID by Content ID
 * 
 * @param integer $content_id  content id
 * 
 * @return integer license id
 */
function wpclink_get_license_type_by_content($content_id = 0){
	global $wpdb;
	// Table Prefix
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	
	$license_data = $wpdb->get_row( "SELECT * FROM $table_license WHERE licensed_creation_id = '$content_id' AND mode = 'linked' ", ARRAY_A);	
	
	return $license_data['license_id'];
}

/**
 * CLink Get Content ID by License ID
 * 
 * @param integer $license_id  license id
 * 
 * @return integer content id
 */
function wpclink_get_content_id_by_license_id($license_id = 0){
	global $wpdb;
	// Table Prefix
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	
	$license_data = $wpdb->get_row( "SELECT * FROM $table_license WHERE license_id = '$license_id' AND mode = 'referent' ", ARRAY_A);	
	
	return $license_data['licensed_creation_id'];
}


/**
 * CLink Get Licence Type by License ID
 * 
 * @param integer $license_id  license type
 * 
 * @return mixed false | licenser type
 */

function wpclink_get_license_type_by_id($license_id = false){

	global $wpdb;
		
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	$license_data = $wpdb->get_row( "SELECT * FROM $table_license WHERE license_id = '$license_id' ", ARRAY_A);
	
	
	if ( NULL !== $license_data ) {	
		return $license_data['license_type'];
	}else{
		return false;	
	}	
}


/**
 * CLink Creation Pre Authorize Effect Date
 * 
 * @param integer $post_id  post id
 * 
 */
function wpclink_creation_pre_auth_effect_date($post_id = 0){
	
	$effect_date = date("Y-m-d H:i:s");
	
	// Update
	update_post_meta($post_id,'wpclink_creation_pre_auth_effective_date',$effect_date);
}


/**
 * Add the License Aggregated Link
 * 
 * @param string $site_url url of the aggregated site 
 * @param string $site_ip ip of the aggregated site 
 * @param boolean $clink_status status of the clink link
 * @param boolean $clink_canonical_status status of canonical
 * @param string $secret_key secret key of the site to aggregate
 * @param string $auth_code authorization code of the site to aggregate
 * @param string $license_template license template of the aggregated site
 * @param string $license_type license type of the aggregated site content either it is as is or restricted
 * 
 * @return integer added the aggregated link
 */


function wpclink_add_license_aggregated($site_url = '', $site_ip, $clink_status = 'good', $clink_canonical_status = 1,$secret_key = '',$auth_code = '',$license_template = '',$license_type = '',$content_id = '',$content_url = '',$token = '',$unique = ' '){
	
	global $wpdb;
	// Table Prefix
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	
	$clink_mode = 'linked';
	
	$date = date("Y-m-d H:i:s");
	
	$added_license = $wpdb->insert($table_license, 
	  array( 
		  'mode' => $clink_mode, 
		  'site_url' => $site_url,
		  'site_IP' => $site_ip,
		  'verification_status' => $clink_status,
		  'licensed_creation_id' => $content_id,
		  'license_type' => $license_type,
		  'license_date' => $date,
		  'license_key' => ''
	  ), 
	  array( 
		  '%s', 
		  '%s',
		  '%s',
		  '%s',
		  '%d',
		  '%s',
		  '%s',
		  '%s'
	  ));
	  
	  if($added_license > 0){
		  
		  $add_license_id = $wpdb->insert_id;
		  // License Meta
		  wpclink_add_license_meta($add_license_id,'license',$license_template);
		  wpclink_add_license_meta($add_license_id,'wpclink_license_secret_key',$secret_key);
		  wpclink_add_license_meta($add_license_id,'wpclink_license_auth_code',$auth_code);
		  wpclink_add_license_meta($add_license_id,'wpclink_licensed_linked_post_url',$content_url);
		  wpclink_add_license_meta($add_license_id,'wpclink_license_token',$token);
		  wpclink_add_license_meta($add_license_id,'wpclink_license_dowload_id',$unique);
		  wpclink_add_license_meta($add_license_id,'wpclink_license_email_id',$unique);
	  }
	  
	  return $add_license_id;
		
}


/**
 * Delete Aggregated License
 * 
 * @param integer $license_id  license id
 * 
 * @return integer
 */

function wpclink_delete_license_aggregated($license_id = false){
	
	global $wpdb;
	// Table Prefix
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	$table_licensemeta = $wpdb->prefix . 'wpclink_licensemeta'; 
	
	// Query
	$deleted = $wpdb->delete( $table_license, array( 'license_id' => $license_id, 'mode' => 'linked') );

	
	// DELETE META
	$delete_id = $wpdb->delete( $table_licensemeta, array( 'license_id' => $license_id ) );	
	
	if($deleted > 0){
		
		// KEYS
		wpclink_delete_license_meta($license_id,'wpclink_license_secret_key');
		wpclink_delete_license_meta($license_id,'wpclink_license_auth_code');
			
	}
	
	return $deleted;	
	
}




/**
 * Get the License Aggregated
 * 
 * @param integer $license_id license id
 * 
 * @return array
 */

function wpclink_get_license_aggregated($license_id = false){
	global $wpdb;
	// Table Prefix
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	
	$license_data = $wpdb->get_row( "SELECT * FROM $table_license WHERE license_id = '$license_id' AND mode = 'linked' ", ARRAY_A);
	
	// License Meta
	$secret_key = wpclink_get_license_meta($license_id,'wpclink_license_secret_key');
	$auth_code = wpclink_get_license_meta($license_id,'wpclink_license_auth_code');
	
	if ( NULL !== $license_data ) {
		
		return array_merge($license_data, array('secret_key' => $secret_key, 'auth_code' => $auth_code) );
		
	}else{
		return false;	
	}
		
}


/**
 * Get License Aggregated by Download ID
 * 
 * @param string $download_id download id of license template
 * 
 * @return array
 */


function wpclink_get_license_aggregated_by_download_id($download_id = false){
	
	global $wpdb;
	
	// Table Prefix
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	$table_licensemeta = $wpdb->prefix . 'wpclink_licensemeta'; 
	
	$get_id = $wpdb->get_row( "SELECT * FROM $table_licensemeta WHERE meta_value = '$download_id' " );
	if ( NULL !== $get_id ) {
		$license_id = $get_id->license_id;
	}
	
	$license_data = $wpdb->get_row( "SELECT * FROM $table_license WHERE license_id = '$license_id' AND mode = 'linked' ", ARRAY_A);
	
	// License Meta
	$secret_key = wpclink_get_license_meta($license_id,'wpclink_license_secret_key');
	$auth_code = wpclink_get_license_meta($license_id,'wpclink_license_auth_code');
	
	if ( NULL !== $license_data ) {
		
		return array_merge($license_data, array('secret_key' => $secret_key, 'auth_code' => $auth_code) );
		
	}else{
		return false;	
	}
		
}
/**
 * Get One From Aggregated License
 * 
 * @return array
 */

function wpclink_get_one_from_all_license_aggregated(){
	
	global $wpdb;
	// Table Prefix
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	$array_licenses = $wpdb->get_results( "SELECT * FROM $table_license WHERE mode = 'linked'", ARRAY_A );
	
	
	
	$clink_site_url_list = array();
	$new_array = array();
	$array_count = 0;
	
	foreach($array_licenses as $single_array){
	
	if(in_array($single_array['site_url'],$clink_site_url_list)){
	
	
		// ASSIGN
		$clink_site_url_list[] = $single_array['site_url'];
		

		
	}else{
		//ASSIGN
		$clink_site_url_list[] = $single_array['site_url'];
		
		$new_array[$array_count]['license_id'] = $single_array['license_id']; 
		$new_array[$array_count]['mode'] = $single_array['mode']; 
		$new_array[$array_count]['site_IP'] = $single_array['site_IP']; 
		$new_array[$array_count]['site_url'] = $single_array['site_url'];
		$new_array[$array_count]['verification_status'] = $single_array['verification_status'];  
		$new_array[$array_count]['licensed_creation_id'] = $single_array['licensed_creation_id']; 
	}
	
	$array_count++;
		
	}
	
	return $new_array;
}

/**
 * Get All Aggregated License
 * 
 * @return array license
 */

function wpclink_get_all_license_aggregated(){
	
	global $wpdb;
	// Table Prefix
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	return $wpdb->get_results( "SELECT * FROM $table_license WHERE mode = 'linked'", ARRAY_A );
	
}
/**
 * Get All Aggregated ID's
 * 
 * 
 * @return array
 */

function wpclink_get_all_ids_license_aggregated(){
	
	global $wpdb;
	// Table Prefix
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	$license_ids = $wpdb->get_results( "SELECT license_id FROM $table_license WHERE mode = 'linked'", ARRAY_A );
	
	$collect_ids = array();
	
	foreach($license_ids as $single_id){
		$collect_ids[] = $single_id['license_id'];
	}
	
	return $collect_ids;
	
}

/**
 * Get All License Promoted
 * 
 * @return array data
 */

function wpclink_get_all_license_promoted(){
	global $wpdb;
	// Table Prefix
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	return $wpdb->get_results( "SELECT * FROM $table_license WHERE mode = 'referent' ", ARRAY_A );	
	
}

/**
 * Add License Meta
 * 
 * @param integer $post_id post id licensee
 * @param string $meta_key key licensee
 * @param string $meta_value value of licensee
 * @param boolean $unique unique to load
 * 
 * @return integer license id
 */

function wpclink_add_license_meta($post_id, $meta_key, $meta_value, $unique = false ){

	global $wpdb;
	// Table Prefix
	$table_licensemeta = $wpdb->prefix . 'wpclink_licensemeta'; 
	
	if(empty($post_id)) return false;
	
	
	if($unique == true){
		$found = $wpdb->get_row( "SELECT * FROM $table_licensemeta WHERE license_id = '$post_id' AND meta_key = '$meta_key' " );	
		if( NULL !== $found){
			return false;
		}
	}
	
	
	// Insert	
	 $return = $wpdb->insert($table_licensemeta, 
	  array( 
		  'license_id' => $post_id, 
		  'meta_key' => $meta_key,
		  'meta_value' => $meta_value 
	  ), 
	  array( 
		  '%d', 
		  '%s',
		  '%s' 
	  ));
	  
	  return $return;
}

/**
 * Update the Liecense Meta
 * 
 * @param integer $post_id license id
 * @param string $meta_key license key
 * @param string $meta_value license value
 * @param string $prev_value  previous value
 * 
 * @return integer license meta id
 */

function wpclink_update_license_meta($post_id, $meta_key, $meta_value, $prev_value = ''){
	global $wpdb;
	// Table Prefix
	$table_licensemeta = $wpdb->prefix . 'wpclink_licensemeta'; 

	if(empty($post_id)) return false;
	
	
	$updated_id = $wpdb->update( 
	$table_licensemeta, 
	array( 
		'meta_value' => $meta_value
	), 
	array( 'license_id' => $post_id, 'meta_key' => $meta_key ), 
	array( 
		'%s'
	));
	
	
	return $updated_id;
	
}

/**
 * Get the License Meta 
 * 
 * @param integer $post_id license id
 * @param string $key license key
 * @param boolean $single if return the single value
 * 
 * @return boolean
 */

function wpclink_get_license_meta($post_id, $key = '', $single = false ){
	global $wpdb;
	// Table Prefix
	$table_licensemeta = $wpdb->prefix . 'wpclink_licensemeta'; 
	
	if(empty($post_id)) return false;
	
	
	$get_id = $wpdb->get_row( "SELECT * FROM $table_licensemeta WHERE license_id = '$post_id' AND meta_key = '$key'" );
	
	if ( NULL !== $get_id ) {
		return $get_id->meta_value;	
	}else{
		return false;
	}
	
	
}

/**
 * Delete the License Meta
 * 
 * @param integer $post_id license id
 * @param string $meta_key license key
 * @param string $meta_value license value 
 * 
 * @return integer deleted the license 
 */

function wpclink_delete_license_meta($post_id, $meta_key, $meta_value = ''){
	global $wpdb;
	// Table Prefix
	
	$table_licensemeta = $wpdb->prefix . 'wpclink_licensemeta'; 
	if(empty($post_id) || empty($meta_key)) return false;
	
	// DELETE
	$delete_id = $wpdb->delete( $table_licensemeta, array( 'license_id' => $post_id, 'meta_key' => $meta_key ) );	
	
	return $delete_id;

	
}
/**
 * Add License Promoted
 * 
 * @param string $site_url url of promote license
 * @param string $site_ip ip of the promoted license
 * @param boolean $clink_status license activate status
 * @param string $clink_canonical_status canonical url verification status
 * @param string $linked_firstname first name of the linked user
 * @param string $linked_lastname last name of the linked user
 * @param string $linked_displayname display name of the linked user
 * @param string $content_id content id which is linked
 * @param string $content_url content url
 * @param string $license_type type of license
 * @param array $extra_link extra linked user infomation
 * @param string $token license token
 * 
 * @return integer
 */

function wpclink_add_license_promoted($site_url = '', $site_ip, $clink_status = 'good', $clink_canonical_status = 1,$linked_firstname = '',$linked_lastname = '',$linked_displayname = '', $content_id = '', $content_url = '', $license_type = '', $extra_link = array(),$token = NULL){
	
	global $wpdb;
	// Table Prefix
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	
	$clink_mode = 'referent';
	
	$date = date("Y-m-d H:i:s");
	
	$added_license = $wpdb->insert($table_license, 
	  array( 
		  'mode' => $clink_mode, 
		  'site_url' => $site_url,
		  'site_IP' => $site_ip,
		  'verification_status' => $clink_status,
		  'licensed_creation_id' => $content_id,
		  'license_type' => $license_type,
		  'license_date' => $date,
		  'license_key' => $token
	  ), 
	  array( 
		  '%s', 
		  '%s',
		  '%s',
		  '%s',
		  '%d',
		  '%s',
		  '%s',
		  '%s'
	  ));
	  
	  $inserted_license_id = $wpdb->insert_id;
	  
	   // Licensee Liked Variables
	  $licensee_data = array('licensee_first_name'=>$linked_firstname,
	  						 'licensee_last_name' => $linked_lastname,
							 'licensee_display_name' => $linked_displayname,
							 'licensee_email'=> $extra_link['link_email'],
							 'licensee_identifier'=>$extra_link['link_identifier']);
	  
	  wpclink_add_license_meta($inserted_license_id,'licensee_linked_variables',serialize($licensee_data));
	  wpclink_add_license_meta($inserted_license_id,'licensed_creation_uri',$content_url);
	  wpclink_add_license_meta($inserted_license_id,'licensee_license_accept_datetime',$extra_link['licensee_accept_datetime']);
	  wpclink_add_license_meta($inserted_license_id,'licensed_creation_delivery_status','delivered');
	  
	  
	  return $inserted_license_id;
		
}
/**
 * Delete Promoted License
 * 
 * @param integer $license_id license id
 * 
 * @return integer
 */


function wpclink_delete_license_promoted($license_id = false){
	
	global $wpdb;
	// Table Prefix
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	$table_licensemeta = $wpdb->prefix . 'wpclink_licensemeta'; 
	
	// Query
	$deleted = $wpdb->delete( $table_license, array( 'license_id' => $license_id, 'mode' => 'referent' ) );
	
	// DELETE META
	$delete_id = $wpdb->delete( $table_licensemeta, array( 'license_id' => $license_id ) );	
		
	return $deleted;	

}

/**
 * Get License Promoted by ID
 * 
 * @param integer $license_id license id
 * 
 * @return array
 */

function wpclink_get_license_promoted($license_id = false){
	global $wpdb;
	// Table Prefix
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	
	$license_data = $wpdb->get_row( "SELECT * FROM $table_license WHERE license_id = '$license_id' AND mode = 'referent' ", ARRAY_A);
	
	
	if ( NULL !== $license_data ) {
		return $license_data;
	}else{
		return false;	
	}
		
}

/**
 * CLink Show License Template 
 * 
 * To Show or Download License Template 
 * 
 */
function wpclink_show_site_license(){
	if(isset($_GET['license_show_id'])){
		
		// License ID
		$license_id = $_GET['license_show_id'];
		
		if(!is_user_logged_in()) die('Access Denide');
		if(empty($license_id) || $license_id < 1) die('License ID is Incorrect');
	
		wpclink_generate_pdf_template();
	die();
	}
}
// Register clink show license template function
add_action('wp_loaded','wpclink_show_site_license');

/**
 * CLink Generate PDF Template
 * 
 */
function wpclink_generate_pdf_template(){
	
	// Extension
	require_once( plugin_dir_path( __FILE__ ) . 'libraries/wpclink-dompdf.php' );
}


/**
 * CLink Show My License Template
 * 
 */
function wpclink_my_show_site_license(){
	if(isset($_GET['license_my_show_id'])){
		
		// License ID
		$license_id = $_GET['license_my_show_id'];
		
		$download_id = wpclink_get_license_meta($license_id,'wpclink_license_email_id',true);
		
		//if(!is_user_logged_in()) die('Access Denide');
		if($_GET['download_id'] != $download_id) return die('Download ID is Incorrect');
		if(empty($license_id) || $license_id < 1) die('License ID is Incorrect');
	
		wpclink_my_generate_pdf_template();
	die();
	}
}
// Register clink show my license template function
add_action('wp_loaded','wpclink_my_show_site_license');

/**
 * CLink Generate My PDF Template
 * 
 */
function wpclink_my_generate_pdf_template(){
	// Extension
	require_once( plugin_dir_path( __FILE__ ) . 'libraries/wpclink-dompdf-mylicense.php' );
}
