<?php
/**
 * CLink Query Functions 
 *
 * CLink query and conditional functions
 *
 * @package CLink
 * @subpackage System
 */
 
 // Direct Access Not Allowed
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );


/**
 * CLink Referent Mode Check
 * 
 * Conditional method for check the referent mode of CLink Plugin
 * 
 * @return boolean
 */

function wpclink_import_mode(){
	 $save_option = wpclink_get_option( 'preferences_general' );
	if($save_option['cl_mode'] == 'import'){
		return true;	
	}else{
		return false;
	}
}

/**
 * CLink Both Mode Check
 * 
 * Conditional method for check the referent and linked mode of CLink Plugin
 * 
 * @return boolean
 */
function wpclink_both_mode(){
	 $save_option = wpclink_get_option( 'preferences_general' );
	if($save_option['cl_mode'] == 'both'){
		return true;	
	}else{
		return false;
	}
}

/**
 * CLink Linked Mode Check
 * 
 * Conditional method for check the linked mode of CLink Plugin
 * 
 * @return boolean
 */
function wpclink_export_mode(){
	 $save_option = wpclink_get_option( 'preferences_general' );
	if($save_option['cl_mode'] == 'export'){
		return true;	
	}else{
		return false;
	}
}

/**
 * CLink Current Linked Site
 *
 * Mainly use for link of the site.
 */

function wpclink_linked_site(){

	$complete_url = '';	
	$complete_link_url = apply_filters( 'cl_linked_filter', $complete_url );
	$cleaned = strval(str_replace("\0", "", $complete_link_url));
	return $cleaned;
	
}

/**
 * Verify the Current Active Site Link is UP (200)
 * 
 * @return boolean
 */

function wpclink_check_path(){
	$context  = stream_context_create(array('http' => array('header' => 'Accept: application/xml')));
	$xml=@file_get_contents(wpclink_linked_site(),false,$context);
	
	if($xml === FALSE){
		return false;	
	}elseif($xml == '0'){
		return false;
	}else{
		return true;
	}
}

/**
 * CLink Check is Site is Register on Care.Cink.Meda
 * 
 * @param string $site_url site address
 * 
 * @return boolean true if found false on not found
 */

function wpclink_is_care_register($site_url = false){
	
	if($site_url == false) return false;
	
	
	  // Encode
	  $site_url_ready = urlencode($site_url);
		
	  global $wp_version;
	  $args = array(
		  'timeout'     => WPCLINK_API_TIMEOUT,
		  'redirection' => 5,
		  'httpversion' => '1.0',
		  'user-agent'  => 'WordPress/' . $wp_version . '; ' . home_url(),
		  'blocking'    => true,
		  'headers'     => array(),
		  'cookies'     => array(),
		  'body'        => null,
		  'compress'    => false,
		  'decompress'  => false,
		  'sslverify'   => false,
		  'stream'      => false,
		  'filename'    => null
	  ); 
	  $response = wp_remote_get( WPCLINK_CARE_SERVER.'/?cl_site=1&url='.$site_url_ready.'&time='.time(),$args);
 
	if ( is_array( $response ) ) {
		$body = $response['body']; // use the content
		$site_exists = json_decode($body,true);

		if($site_exists['site'] == '1'){
			return true;
		}else{
			return false;	
		}
	}
  
  return false;
}

/**
 * Get Copyright Owner ID
 * 
 * @return integer copyright_owner_id 
 * 
 */
function wpclink_get_copyright_owner_id(){
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	$creator_array = wpclink_get_option('authorized_creators');
	$user_id_asso = $creator_array[0];
	$party_id = wpclink_get_option('authorized_party');
	
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}else if($copyright_owner == 'creator'){
		$copyright_owner_id = $user_id_asso;
	}
	
	return $copyright_owner_id;
}

/**
 * CLink Display License Type Label
 * 
 * @param string $license_slug slug of license type
 * 
 */
function wpclink_license_type_label($license_slug = false){
	if($license_slug == 'as_is'){
		echo 'As Is';
	}elseif($license_slug == 'restricted'){
		echo 'Restricted';
	}else{
		echo 'N/A';
	}
}

/**
 * CLink License Content Status Label
 * 
 * @param string $content_slug  content status slug
 * 
 */
function wpclink_license_content_status_label($content_slug = false){
	if($content_slug == 'delivered'){
		echo 'Delivered';
	}elseif($content_slug == 'published'){
		echo 'Published';
	}else{
		echo 'N/A';
	}
}


/**
 * CLink License Version Slug to Label
 * 
 * @param string $license_slug license slug
 * 
 * @return string
 */

function wpclink_get_license_version_label($license_slug = false){
	
	$license_ver_array = wpclink_get_option('license_versions');
	
	if(empty($license_ver_array)){
		return 'N/A';
	}else{
		return $license_ver_array[$license_slug];
	}
}

/**
 * CLink License Type Slug to Label
 * 
 * @param string $license_slug license slug
 * 
 * @return string
 */

function wpclink_get_license_type_label($license_slug = false){
	if($license_slug == 'as_is'){
		return 'As Is';
	}elseif($license_slug == 'restricted'){
		return 'Restricted';
	}else{
		return 'N/A';
	}
}


/**
 * CLink CLink.ID HTML Hyperlink Generate
 * 
 * @param string $clinkid  clink id 
 * 
 * @return string hyperlink
 */

function wpclink_cid_hyperlink($clinkid = ''){
	return '<a href="'.WPCLINK_ID_URL.'/#objects/'.$clinkid.'" target="_blank">'.$clinkid.'</a>';
}

/**
 * CLink Check Content is in Linked Site List
 * 
 * @param integer $content_id  content id
 * 
 * @return mixed content id | false
 */

function wpclink_is_content_linked($content_id = 0){
	
	global $wpdb;
	$table_license = $wpdb->prefix . 'wpclink_licenses';
	$mylink = $wpdb->get_row( "SELECT * FROM $table_license WHERE licensed_creation_id = '$content_id' AND mode = 'referent' AND verification_status = 'good' ",ARRAY_A );
	
	if ( NULL !== $mylink ) {	
	return $mylink['licensed_creation_id'];
	}else{
		return false;	
	}	
}



/**
 * CLink Check the Site Content is in Linked Site List
 * 
 * @param integer $get_content content id
 * 
 * @return boolean
 */

function wpclink_is_content_linked_site($get_content = 0){
	
	$content_return = wpclink_is_content_linked($get_content);
	if($content_return == $get_content){
		return false;	
	}else{
		return true;	
	}
}

/**
 * CLink Display Name from User ID
 * 
 * @param integer $user_id  user id
 * 
 * @return string
 */

function wpclink_user_display_name($user_id = false){
	
	if($user_id == false) return false;	
	
	// DATA
	$user_data = get_userdata( $user_id );
	return $user_data->display_name;
}


/**
 * CLink Read Only 
 * 
 * CLink read only for those user which have not access the certain pages it will be disable buttons and update funtions for perform action 
 * 
 * @return boolean
 */

function wpclink_user_readonly(){
	
	// CURRENT USER
	$current_user_id = get_current_user_id();
	
	
	// CREATOR
	$creator_array = wpclink_get_option('authorized_creators');
	$creator_id = $creator_array[0];
	
	// PARTY
	$clink_party_id = wpclink_get_option('authorized_party');
	
	
	// COPYRIGHT OWNER
	$copyright_owner = wpclink_get_option('copyright_owner');
	
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
		
	}
	
	$current_page = $_GET['page'];
	
	// ONLY ADMN
	if($current_user_id != $creator_id and current_user_can('administrator') and $current_user_id != $clink_party_id){
		
		if($current_page == 'cl-restriction' ||
		$current_page == 'cl-restriction-page-available' ||
		$current_page == 'cl-restriction-reuse' ||
		$current_page == 'cl-restriction-page' ||
		$current_page == 'content_link_post.php' ||
		$current_page == 'content_link_page.php' ||
		$current_page == 'cl-site-agreemnets' ||
		$current_page == 'cl-canonical' ||
		$current_page == 'cl-audit-trail' ||
		$current_page == 'cl_templates' ||
		$current_page == 'cl-my-agreemnets'){
			return true;	
		}
	
	// ONLY CREATOR
	}elseif($current_user_id == $creator_id and !current_user_can('administrator') and $copyright_owner_id != $current_user_id){
		
		if($current_page == 'cl_mainpage.php' || 
		$current_page == 'cl_users' || 
		$current_page == 'cl-restriction-reuse' || 
		$current_page == 'cl-restriction-page' || 
		$current_page == 'cl-canonical' ||
		$current_page == 'cl-audit-trail' ||
		$current_page == 'cl-site-agreemnets'){
			return true;
		}
	
	// CREATOR + COPYRGHT OWNER
	}elseif($current_user_id == $creator_id and !current_user_can('administrator') and $copyright_owner_id == $current_user_id and $current_user_id != $clink_party_id){
		
		if($current_page == 'cl_mainpage.php' || 
		$current_page == 'cl_users'){
			return true;
		}
		
	}elseif($current_user_id == $creator_id and !current_user_can('administrator') and $copyright_owner_id == $current_user_id and $current_user_id == $clink_party_id){
		
		if($current_page == 'cl_mainpage.php'){
			return true;
		}
		
	// CREATOR + ADMINISTRATOR
	}elseif($current_user_id == $creator_id and current_user_can('administrator') and $copyright_owner_id != $current_user_id){
		
		if($current_page == 'cl-restriction-reuse' || 
		$current_page == 'cl-restriction-page' ||
		$current_page == 'cl-canonical' ||
		$current_page == 'cl-audit-trail' ||
		$current_page == 'cl-site-agreemnets'){
			return true;
		}
		
	// CREATOR + ADMN + COPY
	}elseif($current_user_id == $creator_id and current_user_can('administrator') and $copyright_owner_id == $current_user_id){
	
	
	// CREATOR + PARTY
	}elseif($current_user_id == $creator_id and !current_user_can('administrator') and $current_user_id == $clink_party_id and $copyright_owner_id != $current_user_id){
		
		if($current_page == 'cl_mainpage.php' || 
		$current_page == 'cl-restriction-reuse' || 
		$current_page == 'cl-restriction-page' ||
		$current_page == 'cl-canonical' ||
		$current_page == 'cl-audit-trail' ||
		$current_page == 'cl-site-agreemnets'){
			return true;
		}
		
	// CREATOR + PARTY + COPYRIGHT OWNER
	}elseif($current_user_id == $creator_id and !current_user_can('administrator') and $current_user_id == $clink_party_id and $copyright_owner_id == $current_user_id){
		
		if($current_page == 'cl_mainpage.php'){
			return true;
		}
		
	// CREATOR + PARTY + COPYRIGHT OWNER + ADMN	
	}elseif($current_user_id == $creator_id and current_user_can('administrator') and $current_user_id == $clink_party_id and $copyright_owner_id == $current_user_id){
		
		
		
	// CREATOR + ADMN + COPY
	}elseif($current_user_id == $creator_id and current_user_can('administrator') and $copyright_owner_id == $current_user_id){
		

	// ONLY PARTY	
	}elseif($current_user_id == $clink_party_id and !current_user_can('administrator') and $copyright_owner_id != $current_user_id){
		
		if($current_page == 'cl_mainpage.php' ||
		$current_page == 'cl_templates' ||
		$current_page == 'cl-restriction' ||
		$current_page == 'cl-restriction-page-available' ||
		$current_page == 'cl-restriction-reuse' ||
		$current_page == 'cl-restriction-page' ||
		$current_page == 'content_link_post.php' ||
		$current_page == 'content_link_page.php' ||
		$current_page == 'cl-site-agreemnets' ||
		$current_page == 'cl-canonical' ||
		$current_page == 'cl-audit-trail' ||
		$current_page == 'cl-my-agreemnets' 
		){
			return true;
		}
	
	// PARTY + COPY
	}elseif($current_user_id == $clink_party_id and !current_user_can('administrator') and $copyright_owner_id == $current_user_id){
		
		if($current_page == 'cl_mainpage.php' ||
		$current_page == 'content_link_post.php' ||
		$current_page == 'content_link_page.php' ||
		$current_page == 'cl-my-agreemnets' 
		){
			return true;
		}
		
	// PARTY + ADMN
	}elseif($current_user_id == $clink_party_id and current_user_can('administrator') and $copyright_owner_id != $current_user_id){
		
		if($current_page == 'cl_templates' ||
		$current_page == 'cl-restriction' ||
		$current_page == 'cl-restriction-page-available' ||
		$current_page == 'cl-restriction-reuse' ||
		$current_page == 'cl-restriction-page' ||
		$current_page == 'content_link_post.php' ||
		$current_page == 'content_link_page.php' ||
		$current_page == 'cl-site-agreemnets' ||
		$current_page == 'cl-canonical' ||
		$current_page == 'cl-audit-trail' ||
		$current_page == 'cl-my-agreemnets' 
		){
			return true;
		}
			
	// PARTY + ADMN + COPY
	}elseif($current_user_id == $clink_party_id and current_user_can('administrator') and $copyright_owner_id == $current_user_id){
		
		if($current_page == 'content_link_post.php' ||
		$current_page == 'content_link_page.php' ||
		$current_page == 'cl-my-agreemnets' 
		){
			return true;
		}
			
	}
	
	
	// AT LAST
	return false;
}


/**
 * CLink Check the Tokem ie exists
 * @param string $token token name
 * 
 * @return boolean true | false
 */
function wpclink_is_token_exists($token = NULL){
	
	if($token == NULL) return false;
	
	global $wpdb;
		// Table Prefix
	$table_token = $wpdb->prefix . 'wpclink_tokens';
	
	$token_data = $wpdb->get_row( "SELECT * FROM $table_token WHERE token = '$token'", ARRAY_A );
	
	if ( NULL !== $token_data ) {
		
		return true;
		
	}else{
		
		return false;
	}
	
}

/**
 * Clink Get Posts
 * 
 * CLink get post list which  are on the referenet list allow to be get only linked sites.
 * 
 * @param array $get_perameter perameter
 * 
 * @return array post ids
 */
function wpclink_get_posts($get_perameter = array()){

	// CONTENT LICENSE
	$license_content_ids = wpclink_get_all_content_from_ip();
	
	// REQUESTED POSTS
	$requested = $get_perameter; 	
	
	// ALL REFRENT POSTS
	$referent_posts = wpclink_get_option('referent_posts');
	
	if(empty($referent_posts)) return array(0);
	
	
	$complete = array();
	
	foreach($requested as $req){
		if(in_array($req, $referent_posts)){
				$complete[] = $req;			
		}
	}
	
	
	$posts_ids = array();
	
	foreach($license_content_ids as $single_id){
		if(in_array($single_id, $complete)){
				$posts_ids[] = $single_id;			
		}
	}
	
	return $posts_ids;
					
}

/**
 * Clink Get Pages
 * 
 * CLink get pages list which  are on the referenet list allow to be get only linked sites.
 * 
 * @param array $get_perameter perameter
 * 
 * @return array pages ids
 */
function wpclink_get_pages($get_perameter = array()){
	
	// CONTENT LICENSE
	$license_content_ids = wpclink_get_all_content_from_ip();

	// REQUESTED POSTS
	$requested = $get_perameter; 	
	
	// ALL REFRENT POSTS
	$referent_pages = wpclink_get_option('referent_pages');
	
	if(empty($referent_pages)) return array(0);
	
	
	$complete = array();
	
	foreach($requested as $req){
		if(in_array($req, $referent_pages)){
				$complete[] = $req;			
		}
	}
	
	
	$pages_ids = array();
	
	foreach($license_content_ids as $single_id){
		if(in_array($single_id, $complete)){
				$pages_ids[] = $single_id;			
		}
	}
	
	return $pages_ids;
	
	
}

/**
 * Clink Get Content
 * 
 * CLink get all content which  are on the referenet list allow to be get only linked sites.
 * 
 * @param array $get_perameter perameter
 * @param array $post_type post type
 * 
 * @return array content ids
 */
function wpclink_get_all_posts($get_perameter = false, $post_type = 'post'){
	if($post_type == 'post'){
		return wpclink_get_posts($get_perameter);
	}elseif($post_type == 'page'){
		return wpclink_get_pages($get_perameter);
	}
}

/**
 * CLink Get Posts by post type
 * 
 * @param string $post_type post type
 * 
 * @return array post ids
 */

function wpclink_posts_show($post_type = 'post'){


	$license_content_ids = wpclink_get_all_content_from_ip();
	
		
	if($post_type == 'post'){
		
		// ALL REFRENT POSTS
		$referent_posts = wpclink_get_option('referent_posts'); 
		$post_ids = array();
		
		if(empty($referent_posts)) return array(0);
		
		
		foreach($referent_posts as $refpost){
			if(in_array($refpost,$license_content_ids)){
				$post_ids[] = $refpost;
			}
		}
		
		if(empty($post_ids)) return array(0);	
		return $post_ids;
		
		
	}elseif($post_type == 'page'){
		
		
		$referent_pages = wpclink_get_option('referent_pages'); 	
		$page_ids = array();
		
		if(empty($referent_pages)) return array(0);	
			
		foreach($referent_pages as $refpage){
			if(in_array($refpage,$license_content_ids)){
				$page_ids[] = $refpage;
			}
		}
		
				
		if(empty($page_ids)) return array(0);	
		return $page_ids;
			
	}
	
}