<?php
/**
 * CLink Schedule Functions
 *
 * CLink schedule of canonical URLs
 *
 * @package CLink
 * @subpackage System
 */

 // Direct Access Not Allowed
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );


register_activation_hook(WPCLINK_MAIN_FILE, 'wpclink_activation_schedule');

/**
 * Schedule to check linked is updated content
 * 
 */

function wpclink_activation_schedule() {
    if (! wp_next_scheduled ( 'cl_notify_me' )) {
	wp_schedule_event(time(), 'hourly', 'cl_notify_me');
    }
}

// Decative Schedule for deactive plugin
register_deactivation_hook(WPCLINK_MAIN_FILE, 'wpclink_deactivation_schedule');

/**
 * Deactive Schedule
 */
function wpclink_deactivation_schedule() {
	wp_clear_scheduled_hook('cl_notify_me');
}
/**
 * CLink Canonical Verification Schedule Run
 * 
 */
function wpclink_canonical_schedule(){
	
	global $wpdb;
	// CLINK  TABLE
	$clink_sites_table = $wpdb->prefix . 'wpclink_licenses'; 
	
	//$agreements = $wpdb->get_results( "SELECT * FROM $clink_sites_table", ARRAY_A );
	$agreements = wpclink_get_all_license_promoted();
	

	foreach($agreements as $single_agree){
		
		
			$cl_connect_site = $single_agree['site_url'];
		
			// REQUESTED QUERY
			$request_query['client_site'] = urlencode(get_bloginfo('url')."/");
			$request_query['s_agree'] = 1;
			$request_query['cl_action'] = 'cl_list';
			$request_query['content_id'] = $single_agree['licensed_creation_id'];
			$build_query = build_query( $request_query );
			
	
			// COMPLETE QUERY
			$context  = stream_context_create(array('http' => array('header' => 'Accept: application/xml')));
			$xml=file_get_contents($cl_connect_site.'?'.$build_query,false,$context);
			

		
		
			$xml = simplexml_load_string($xml);
			
			if(!isset($xml->channel->item) || empty($xml->channel->item)) return false;
			
			foreach($xml->channel->item as $single){
				
				$link = (string)$single->link;
				$match = wpclink_agreement_canonical_test($link,get_bloginfo('url'));
				
				if($match == false){
					
					
					if($canonical_fail_value = wpclink_get_option('verification_canonical_fail_threshold')){
						
					}else{
						$canonical_fail_value = 3;
					}
					
			 
					 
					 // RESTART
					wpclink_update_license_meta($single_agree['license_id'],'canonical_success_attemps',0);
					
					// ATTEMPS
					
					$attemps = wpclink_get_license_meta($single_agree['license_id'],'wpclink_license_attemps',true);
					
					if(($attemps >= 0)){
						
						$attemps_save = $attemps+1;
						
						wpclink_update_license_meta($single_agree['license_id'],'wpclink_license_attemps',$attemps_save);
						
					}
					
					if($attemps === false){
						wpclink_add_license_meta($single_agree['license_id'],'wpclink_license_attemps',1);
						}
										
					// GET ATTEMPS
					$attemps_check = wpclink_get_license_meta($single_agree['license_id'],'wpclink_license_attemps',true);
					
					
					// MORE THAN THREE
					if($attemps_check >= $canonical_fail_value){
					
					// VIOLATION
					$wpdb->update($clink_sites_table,array('verification_status' => 'violated'), array('license_id' => $single_agree['license_id'],'mode' => 'referent'));
					
					// BLACK LIST
					if($black_list_array = wpclink_get_option('wpclink_site_blacklist')){
						
						$blacklist = array_merge($black_list_array,array($cl_connect_site));
						wpclink_update_option('wpclink_site_blacklist',array_unique($blacklist));
						
					}else{
						wpclink_update_option('wpclink_site_blacklist',array($cl_connect_site));
					}
					
					// RESTART
					wpclink_update_license_meta($single_agree['license_id'],'wpclink_license_attemps',0);
					
					}
					
					
				}
				if($match == true){
					
					if($canonical_success_value = wpclink_get_option('verification_canonical_success_threshold')){
						
					}else{
						$canonical_success_value = 3;
					}
					
					
					
					// RESTART
					wpclink_update_license_meta($single_agree['license_id'],'wpclink_license_attemps',0);
					
					
					$attemps_success = wpclink_get_license_meta($single_agree['license_id'],'canonical_success_attemps',true);
					
					if($attemps_success >= 0){
						
						$attemps_success_save = $attemps_success+1;
						
						wpclink_update_license_meta($single_agree['license_id'],'canonical_success_attemps',$attemps_success_save);
						
					}
					
					if($attemps_success  === false){
						
						
						wpclink_add_license_meta($single_agree['license_id'],'canonical_success_attemps',1);
						
						
					}
										
					// GET ATTEMPS
					$attemps_success_check = wpclink_get_license_meta($single_agree['license_id'],'canonical_success_attemps',true);
					
					
					// MORE THAN THREE
					if($attemps_success_check >= $canonical_success_value){
					
					// GOOD CONDITION
					$wpdb->update($clink_sites_table,array('verification_status' => 'good'), array('license_id' => $single_agree['license_id'],'mode' => 'referent'));
					
					// BLACK LIST
					if($black_list_array = wpclink_get_option('wpclink_site_blacklist')){
						
						
						if(in_array($cl_connect_site,$black_list_array)){
							
							// REMOVE SITE
							$blacklist = array_diff($black_list_array,array($cl_connect_site));
							
						}
						
						wpclink_update_option('wpclink_site_blacklist',$blacklist);
						
					}
					
					// RESTART
					wpclink_update_license_meta($single_agree['license_id'],'canonical_success_attemps',0);
					
					}
					
					
					
				}
				
			
			}
		
	}
	
}


// Register clink canonical verification schedule on plugin activatation
register_activation_hook(WPCLINK_MAIN_FILE, 'wpclink_canonical_activation');

/**
 * CLink Canonical Verification Schedule Time on Activation
 * 
 * Verfication Schedule Time
 * - Daily 
 * - Hourly 
 * - Twice a Day
 * 
 */

function wpclink_canonical_activation() {
	$saved_options = wpclink_get_option( 'preferences_general' );
	
	if(!isset($saved_options['canonical_time'])){
		if (! wp_next_scheduled ( 'cl_daily_canonical_script' )) {
			wp_schedule_event(time(), 'daily', 'cl_daily_canonical_script');
    	}
	}elseif($saved_options['canonical_time'] == 'hourly'){
		if (! wp_next_scheduled ( 'cl_hourly_canonical_script' )) {
			wp_schedule_event(time(), 'hourly', 'cl_hourly_canonical_script');
    	}
	}elseif($saved_options['canonical_time'] == 'twicedaily'){
		if (! wp_next_scheduled ( 'cl_twicedaily_canonical_script' )) {
			wp_schedule_event(time(), 'twicedaily', 'cl_twicedaily_canonical_script');
    	}
	}elseif($saved_options['canonical_time'] == 'daily'){
		if (! wp_next_scheduled ( 'cl_daily_canonical_script' )) {
			wp_schedule_event(time(), 'daily', 'cl_daily_canonical_script');
    	}
	}
}


// Register Hourly Verfication
add_action('cl_hourly_canonical_script', 'wpclink_hourly_canonical_script_func');
/**
 * CLink Register Hourly Verification 
 *
 */
function wpclink_hourly_canonical_script_func() {	
	wpclink_canonical_schedule();
	}


// Register Twice a Day Verfication
add_action('cl_twicedaily_canonical_script', 'wpclink_twicedaily_canonical_script_func');
/**
 * CLink Register Twice a Day Verification 
 *
 */
function wpclink_twicedaily_canonical_script_func() {	
	wpclink_canonical_schedule();
}


// Register Daily Verification
add_action('cl_daily_canonical_script', 'wpclink_daily_canonical_script_func');
/**
 * CLink Register Daily Verification 
 *
 */
function wpclink_daily_canonical_script_func() {	
	wpclink_canonical_schedule();
}

/**
 * CLink Canonical Verification Schedule Time Reloader
 * 
 */

function wpclink_canonical_reloader(){
	$saved_options = wpclink_get_option( 'preferences_general' );
	
	// FLUSH
	wp_clear_scheduled_hook('cl_hourly_canonical_script');
	wp_clear_scheduled_hook('cl_twicedaily_canonical_script');
	wp_clear_scheduled_hook('cl_daily_canonical_script');
	
	// LOAD
	if(!isset($saved_options['canonical_time'])){
		if (! wp_next_scheduled ( 'cl_daily_canonical_script' )) {
			wp_schedule_event(time(), 'daily', 'cl_daily_canonical_script');
    	}
	}elseif($saved_options['canonical_time'] == 'hourly'){
		if (! wp_next_scheduled ( 'cl_hourly_canonical_script' )) {
			wp_schedule_event(time(), 'hourly', 'cl_hourly_canonical_script');
    	}
	}elseif($saved_options['canonical_time'] == 'twicedaily'){
		if (! wp_next_scheduled ( 'cl_twicedaily_canonical_script' )) {
			wp_schedule_event(time(), 'twicedaily', 'cl_twicedaily_canonical_script');
    	}
	}elseif($saved_options['canonical_time'] == 'daily'){
		if (! wp_next_scheduled ( 'cl_daily_canonical_script' )) {
			wp_schedule_event(time(), 'daily', 'cl_daily_canonical_script');
    	}
	}
}


// Deactivate Verification Schedule on Plugin Deactivation
register_deactivation_hook(WPCLINK_MAIN_FILE, 'wpclink_canonical_deactivation');

/**
 * CLink Canonical Verification Schedule Deactivation
 * 
 */
function wpclink_canonical_deactivation() {
	wp_clear_scheduled_hook('cl_hourly_canonical_script');
	wp_clear_scheduled_hook('cl_twicedaily_canonical_script');
	wp_clear_scheduled_hook('cl_daily_canonical_script');
}

