<?php
/**
 * CLink Structure Functions 
 *
 * CLink structure and layout functions
 *
 * @package CLink
 * @subpackage System
 */

// Direct Access Not Allowed
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

/**
 * CLink Referent Creator Column Value
 * 
 * @param string $column_name column name
 * @param integer $post_ID post id
 * 
 */
function wpclink_ref_creator_column($column_name, $post_ID) {

	if($column_name == 'cl_ref_creator'){
	
		$contentID_ref_creator = get_post_meta( $post_ID, 'clink_post_creator', true );	
		if ( !empty( $contentID_ref_creator ) ) {
			echo $contentID_ref_creator;
		}else{
			echo 'N/A';	
		}
	}

}
// Register register column on wordpress post olumns value
add_action('manage_posts_custom_column', 'wpclink_ref_creator_column', 1, 2);
add_action('manage_pages_custom_column', 'wpclink_ref_creator_column', 1, 2);

/**
 * CLink Referent Creator Column on WordPress Post Columns
 * 
 * @param string $defaults default column
 * 
 * @return string
 */
function wpclink_ref_creator_column_head($defaults) {
	
	
    $defaults['cl_ref_creator'] = 'Referent Creator';
    return $defaults;
}
// Register clink referent creator column on wordpress post column
add_filter('manage_posts_columns', 'wpclink_ref_creator_column_head');
add_filter('manage_pages_columns', 'wpclink_ref_creator_column_head');

/**
 * CLink Referent Content ID on WordPress Post List
 * 
 * @param string $defaults default column name
 * 
 */
function wpclink_clink_id_columns_head_ref($defaults) {
	
	
    $defaults['clink_id_ref'] = '<span class="clinkico-24-text">Referent</span>';
    return $defaults;
}
// Register refernet content id function
add_filter('manage_posts_columns', 'wpclink_clink_id_columns_head_ref');
//add_filter('manage_pages_columns', 'wpclink_clink_id_columns_head_ref');


/**
 * CLink Referent Content ID Value on WordPress Post List
 * 
 * @param string $column_name default column
 * @param integer $post_ID post id
 * 
 */
function wpclink_clink_id_content_ref($column_name, $post_ID) {

	if($column_name == 'clink_id_ref'){
	$contentID_ref = get_post_meta( $post_ID, 'wpclink_referent_creation_identifier', true );
	if ( !empty( $contentID_ref ) ) {
		echo '<a href="'.WPCLINK_ID_URL.'/#objects/'.$contentID_ref.'">'.$contentID_ref.'</a>'.get_post_mime_type( $post_ID );
	}else{
		echo 'N/A';	
	}
	}

}
// Register referent content id value function
add_action('manage_posts_custom_column', 'wpclink_clink_id_content_ref', 10, 2);
add_action('manage_pages_custom_column', 'wpclink_clink_id_content_ref', 10, 2);


/**
 * CLink Content ID Table Header on WordPress Post List
 * 
 * @param string $defaults default column
 * 
 */
function wpclink_clink_id_columns_head($defaults) {
	
	
    $defaults['clink_id'] = '<span class="clinkico-24-text"></span>';
    return $defaults;
}
// Register content id table header on wordpress post column
add_filter('manage_posts_columns', 'wpclink_clink_id_columns_head');
// Register content id table header on wordpress page column
add_filter('manage_pages_columns', 'wpclink_clink_id_columns_head');

 /**
  * CLink Content ID Column Value on WordPress Post List
  * 
  * @param string $column_name default column
  * @param integer $post_ID post id
  * 
  */
function wpclink_clink_id_content($column_name, $post_ID) {

	if($column_name == 'clink_id'){
	$contentID = get_post_meta( $post_ID, 'wpclink_creation_identifier', true );
	if ( !empty( $contentID ) ) {
		echo '<a href="'.WPCLINK_ID_URL.'/#objects/'.$contentID.'">'.$contentID.'</a>'.get_post_mime_type( $post_ID );
	}else{
		echo 'N/A';	
	}
	}

}
// Register content id column value function
add_action('manage_posts_custom_column', 'wpclink_clink_id_content', 10, 2);
add_action('manage_pages_custom_column', 'wpclink_clink_id_content', 10, 2);



/**
 * 
 * CLink Re-order Column
 *
 * Re-order Column CLink Referent Creator Column Should be Before Author Column
 *
 * @param string $columns default column
 * 
 * @return string
 */

function wpclink_reorder_columns($columns) {
  $cl_columns = array();
  $ref_creator = 'cl_ref_creator'; 
  $author = 'author'; 
  foreach($columns as $key => $value) {
    if ($key==$author){
      $cl_columns[$ref_creator] = $ref_creator;
    }
      $cl_columns[$key] = $value;
  }
  return $cl_columns;
}
// Register re-order oolumn function
add_filter('manage_posts_columns', 'wpclink_reorder_columns');
add_filter('manage_pages_columns', 'wpclink_reorder_columns');

/**
 * CLink Display CLink ID on the Publish Widger of Post
 * 
 */
function wpclink_show_content_id() {
	
	global $post;
    $post_id= $post->ID;
	
	$current_user_id = get_current_user_id();
	$party_user_id = wpclink_get_option('authorized_party');
	
	// CREATOR
	$creator_array = wpclink_get_option('authorized_creators');
	$clink_creator_id = $creator_array[0];
	
	$post_author_id = get_post_field( 'post_author', $post_id );
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
	}
	
	
	// ONLY FOR CREATOR
	if(($current_user_id == $clink_creator_id and $current_user_id == $post_author_id) || ($current_user_id == $copyright_owner_id and $current_user_id == $post_author_id) ){
		
	
	
	
	$contentID = get_post_meta( $post_id, 'wpclink_creation_identifier', true );
	
	
	if($clink_versions = get_post_meta( $post_id, 'wpclink_versions', true )){
		
		if(count($clink_versions) == 1){
			$version_count = 'Version: <strong>'.count($clink_versions).'</strong>';
		}else{
			$version_count = 'Versions: <strong>'.count($clink_versions).'</strong>';
		}
	}else{
		$version_count = 'Version: <strong>N/A</strong>';
	}
	
	if($clink_versions = get_post_meta( $post_id, 'wpclink_versions', true )){
	
		$all_versions = '';
		
		foreach($clink_versions as $single_version){
			$all_versions .='<a href=\"'.WPCLINK_ID_URL.'/#objects/'.$single_version.'\" target=\"_blank\">'.$single_version.'</a><br/>';
		
		}
	
	}
	
	
	if ( !empty( $contentID ) ) {
	}else{
		return false;
	}
	
	 $current_screen = get_current_screen();
	 if($current_screen->id == 'post' || $current_screen->id == 'page'){
		 
		 
		 echo '<script type="text/javascript">
		 jQuery(document).ready(function(){
			 jQuery( "<div class=\"misc-pub-section clink_post_id\"><span class=\"clinkico\"></span>'.$version_count.' <a class=\"button cl-small show_version \">View</a> <a class=\"button cl-small make_version \">Make</a> <div class=\"all_versions\" style=\"display:none;\">'.$all_versions.'</div> <span class=\"clinkid\"><a href=\"'.WPCLINK_ID_URL.'/#objects/'.$contentID.'\" target=\"_blank\">'.$contentID.'</a></span></div><input type=\"hidden\" id=\"cl_version\" name=\"cl_version\" value=\"0\" /> " ).insertAfter( ".misc-pub-section.curtime.misc-pub-curtime" );
			 
jQuery(".show_version").click(function(){ jQuery(".all_versions").slideToggle("fast"); });
			 
jQuery(".make_version").click(function(){
			 
jQuery( "#dialog-confirm" ).dialog({
      resizable: false,
      height: "auto",
      width: 400,
      modal: true,
      buttons: {
        "Yes": function() {
			jQuery("#cl_version").attr("value","1");
			jQuery("#publish").trigger("click");
			jQuery( this ).dialog( "close" );
        },
        "No": function() {
			jQuery("#cl_version").attr("value","0");
          	jQuery( this ).dialog( "close" );
        }
      }
    });
	
});
		 });</script>';
	 }
	 
	 }else{
		
	$contentID = get_post_meta( $post_id, 'wpclink_creation_identifier', true );
	
	
	if($clink_versions = get_post_meta( $post_id, 'clink_versions', true )){
		
		if(count($clink_versions) == 1){
			$version_count = 'Version: <strong>'.count($clink_versions).'</strong>';
		}else{
			$version_count = 'Versions: <strong>'.count($clink_versions).'</strong>';
		}
	}else{
		$version_count = 'Version: <strong>N/A</strong>';
	}
	
	if($clink_versions = get_post_meta( $post_id, 'wpclink_versions', true )){
	
		$all_versions = '';
		
		foreach($clink_versions as $single_version){
			$all_versions .='<a href=\"'.WPCLINK_ID_URL.'/#objects/'.$single_version.'\" target=\"_blank\">'.$single_version.'</a><br/>';
		
		}
	
	}
	
	
	if ( !empty( $contentID ) ) {
	}else{
		return false;
	}
	
	 $current_screen = get_current_screen();
	 if($current_screen->id == 'post' || $current_screen->id == 'page'){
		 
		 
		 echo '<script type="text/javascript">
		 jQuery(document).ready(function(){
			 jQuery( "<div class=\"misc-pub-section clink_post_id\"><span class=\"clinkico\"></span>'.$version_count;
			 if(!empty($clink_versions) and $clink_versions >= 1){
				 echo ' <a class=\"button cl-small show_version \">View</a>';
			 }
			 echo '<div class=\"all_versions\" style=\"display:none;\">'.$all_versions.'</div> <span class=\"clinkid\"><a href=\"'.WPCLINK_ID_URL.'/#objects/'.$contentID.'\" target=\"_blank\">'.$contentID.'</a></span></div>" ).insertAfter( ".misc-pub-section.curtime.misc-pub-curtime" );
			 jQuery(".show_version").click(function(){ jQuery(".all_versions").slideToggle("fast"); });

		 });</script>';
	 }
	}
	
}
// CLink display clink id register function
add_action( 'admin_head', 'wpclink_show_content_id' );

/**
 * CLink Create Version of Post Confirmation Popup
 * 
 */
function wpclink_confirm_popup() {
	 $current_screen = get_current_screen();
	 if($current_screen->id == 'post' || $current_screen->id == 'page'){
		 
	echo '<div id="dialog-confirm" title="CLink.ID Version" style="display:none;"><p>Versions are like snapshots.  Those are immutable, in other words un-editable. It is made from the current version of the content. It creates a new registry entry and shows the relationship with the current and previous versions. </p></div>';
	 
	 }
}
// Register clink version confirmation popup on admin footer
add_action('admin_footer', 'wpclink_confirm_popup');

/**
 * CLink Register Content CLink.ID From on Publish Widget of Post
 * 
 */
function wpclink_clinkid_submit_button(){
	
	
	
	global $post;
	global $wpCLink_domain_quota;
    $post_id= $post->ID;
	
	
	$current_user_id = get_current_user_id();
	$party_user_id = wpclink_get_option('authorized_party');
	
	// CREATOR
	$creator_array = wpclink_get_option('authorized_creators');
	$clink_creator_id = $creator_array[0];
	
	
	$copyright_owner = wpclink_get_option('copyright_owner');
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
	}
	
	
	$post_author_id = get_post_field( 'post_author', $post_id );
	
	// SHOW ONLY COPY+CREATOR
	if(($current_user_id == $clink_creator_id and $current_user_id == $post_author_id) || ($current_user_id == $copyright_owner_id and $current_user_id == $post_author_id)){
		
	}else{
		return false;
	}
	
	// if our current user can't edit this post, bail
    if( !current_user_can( 'edit_post' ) ) return;

	
	$current_screen = get_current_screen();
	 if($current_screen->id == 'post' || $current_screen->id == 'page'){
	 }else{
		return false; 
	 }
	
	// SHOW QUOTA
	$quota_number = $wpCLink_domain_quota;
		 
		 if($quota_number >= 50){
			 $status = 'normal';
		 }elseif($quota_number < 20 and $quota_number >= 20){
			 $status = 'warning';
		 }elseif($quota_number < 10){	 
		 	 $status = 'alert';
		 }
	
	if($quota_number < 50){
	 $quota = 'CLink.ID Quota: <strong>'.$quota_number.'</strong>';
	 $scripts ='
		 jQuery(document).ready(function(){
			 
			 jQuery( "<div class=\"misc-pub-section clink_quota_id '.$status.'\"><span class=\"clinkico\"></span> '.$quota.'</div>" ).insertAfter( ".misc-pub-section.curtime.misc-pub-curtime" );
			 
		
	 });';
	}
	 
	 $contentID = get_post_meta( $post_id, 'wpclink_creation_identifier', true );
	 if($contentID == false){
	 
	 // SHOW REGISTER
	 $content_register_restrict = get_post_meta($post_id,'wpclink_post_register_status',true);
	
	if($content_register_restrict == '1'){
		$restrict_status = 'Restricted';
	}else{
		$restrict_status = 'Register';	
	}
	 $scripts.= ' jQuery(document).ready(function(){
	 jQuery( "<div class=\"misc-pub-section clink_quota_id\"><span class=\"clinkico\"></span> Register to CLink.ID: <strong class=\"res_status\">'.$restrict_status.'</strong> <a href=\"#edit_register\" class=\"edit-register hide-if-no-js\" role=\"button\"><span aria-hidden=\"true\">Edit</span></a><div class=\"cl_register_form\" style=\"display:none;\"><label><input id=\"cl_register_process\" name=\"cl_register_process\" type=\"checkbox\" value=\"1\" '.checked( $content_register_restrict, 1, false ).' /> Exclude to Register</label> <a id=\"cancel_register\" href=\"#\">Cancel</a></div></div>" ).insertAfter( ".misc-pub-section.curtime.misc-pub-curtime" );
			 
			 jQuery(".edit-register").click(function(){ jQuery(".cl_register_form").slideToggle("fast"); });
			 jQuery("#cancel_register").click(function(){ jQuery(".cl_register_form").slideToggle("fast"); });
			 
			 
			jQuery("#cl_register_process").change(function(){
				 if(jQuery(this).is(":checked")) {
					jQuery(".res_status").text("Exclude");
				 }else{
					jQuery(".res_status").text("Register");
				 }
				
			});
			});';
			
	 }
	 
	 echo  '<script type="text/javascript">'.$scripts.'</script>';
}
// Register clink id on publish widget of post function
add_action( 'admin_head', 'wpclink_clinkid_submit_button' );

/**
 * CLink Linked Content Read Only Post Title
 * 
 */
function wpclink_clinkid_readonly_post_title(){
	global $post;
	global $wpCLink_domain_quota;
    $post_id= $post->ID;
	
	$current_screen = get_current_screen();
	if($current_screen->id == 'post' || $current_screen->id == 'page'){
	
	if($contentID = get_post_meta( $post_id, 'wpclink_creation_reuse_status', true )){
	echo  '<script type="text/javascript">jQuery("#title").attr("readonly", true).addClass("readonly_title"); jQuery("#edit-slug-buttons").remove();</script>';
	}
	}
}
// Register linked content read only post title function
add_action( 'admin_footer', 'wpclink_clinkid_readonly_post_title' );

 /**
  * CLink User Profile Form Fields
  * 
  * @param object $user  
  * 
  */ 
function wpclink_custom_user_field( $user )
{
	
	
	
	$clink_social_display = get_user_meta($user->ID,'wpclink_social_display',true);
	$get_clink_display_email = get_user_meta($user->ID,'wpclink_email_display_status',true);
	$creator_identifier = get_user_meta($user->ID,'wpclink_creator_identifier',true);
    
	
	$party_id = wpclink_get_option('authorized_party');
	
	$creator_array = wpclink_get_option('authorized_creators');
	$creator_id = $creator_array[0];
	
	// NO PARTY AND CREATOR
	if($party_id == $user->ID || $creator_id == $user->ID || !empty($creator_identifier)){
		
	}else{
		return false;	
	}
	
	$submit_to_clinkid = get_user_meta($user->ID,'submit_to_clinkid',true);
	$make_version = get_user_meta($user->ID,'make_version',true);
	// Submit to CLinkID
	if($submit_to_clinkid == 1){
		
		if($make_version == 1){
			echo 'NIIIIICEE';
			$make_version = true;
		}
		
		
		
		// Party and Creator
		if($user->ID == $party_id and $user->ID == $creator_id){
			
			wpclink_creator_user_update($user->ID,$make_version);
			wpclink_party_user_update($user->ID,$make_version);
			delete_user_meta($user->ID,'submit_to_clinkid');
			delete_user_meta($user->ID,'make_version');
			
		// Party
		}elseif($user->ID == $party_id){
			
			wpclink_party_user_update($user->ID,$make_version);
			delete_user_meta($user->ID,'submit_to_clinkid');
			delete_user_meta($user->ID,'make_version');
		
		// Creator
		}elseif($user->ID == $creator_id){
			wpclink_creator_user_update($user->ID,$make_version);
			delete_user_meta($user->ID,'submit_to_clinkid');
			delete_user_meta($user->ID,'make_version');
			
		}
		
		
	}
	
	
	echo '<h3 class="heading">CLink.ID</h3>';

    ?>
    <table class="form-table clink_user_fields">
   
    <?php 
	$disabled = '';
	
	
	
	
    if($has_identifier_creator = get_user_meta($user->ID,'wpclink_creator_identifier',true) and $user->ID != $party_id){
		if($user->ID == $creator_id){
			$my_user_status = '<span class="clid-active">&#9679; Authorized</span>';	
		}else{
			$disabled = 'disabled="disabled"';
			$my_user_status = '<span class="clid-inactive">&#9679; Inactive</span>';
			echo '<tr><th>CLink Creator Identifier </th><td><a href="'.WPCLINK_ID_URL.'/#objects/'.$has_identifier_creator.'">'.$has_identifier_creator.'</a> <span class="clid-active">'.$my_user_status.'</span></td></tr>';	
		}
	}else if($has_identifier_party = get_user_meta($party_id,'wpclink_party_identifier',true)){
		if($user->ID == $party_id){
			$my_user_status = '<span class="clid-active">&#9679; Authorized</span>';	
		}
	}
	
	
	if($user->ID == $party_id || $user->ID == $creator_id){
	}else{
		$disabled = 'disabled="disabled"';
	}
	
	 ?>
    
    
		
		
    <?php if($user->ID == $creator_id){ ?>
	<tr>
    <th>CLink Creator ID </th> 
    <td><a class="cl_primary_id" target="_blank" href="<?php echo WPCLINK_ID_URL; ?>/#objects/<?php echo $creator_identifier;  ?>"><?php echo $creator_identifier; ?></a> <?php echo $my_user_status; ?> <input class="button version_toggle creator" type="button" value="Versions" /></td>
    </tr>
	<?php }elseif($user->ID == $party_id){ ?>
    <?php if($creator_identifier = get_user_meta($user->ID,'wpclink_creator_identifier',true)){ ?>
    <tr>
	<th>CLink Creator ID  </th> 
    <td><a  class="cl_primary_id" target="_blank" href="<?php echo WPCLINK_ID_URL; ?>/#objects/<?php echo $creator_identifier; ?>"><?php echo $creator_identifier; ?></a> <input class="button version_toggle creator" type="button" value="Versions" /></td>
    </tr>
    <?php } ?>
	<?php }	?>
		<?php $creator_versions = get_user_meta($user->ID,'wpclink_versions',true); ?>
		
  </table> 


		<?php if ($creator_versions = array_reverse(get_user_meta($user->ID,'wpclink_versions',true))){ ?>
<ul class="versions_users creator">
		<p>
			<?php  foreach ($creator_versions as $single_creator_version){
		if(!empty($single_creator_version['id'])){ ?>
		<li><a class="version_identifier" target="_blank" href="<?php echo WPCLINK_ID_URL; ?>/#objects/<?php echo $single_creator_version['id']; ?>"><?php echo $single_creator_version['id']; ?></a> <span class="version_time"><span class="dashicons dashicons-clock"></span> <?php echo date( 'Y-m-d H:i:s',$single_creator_version['time']); ?></span></li></p>
			<?php  }
	 	} ?>
</ul>			
	<?php } ?>

<table class="form-table clink_user_fields">
    <tr style="display:none;">
    <th>Display Social Accounts in CLink.ID</th> 
    <td><label for="clink_field_1"><input type="checkbox" id="clink_social_display" name="clink_social_display" value="1" <?php checked( $clink_social_display, 1 ); ?> <?php echo $disabled; ?>> Enable</label></td>
    </tr>
    <tr>
    <th>Display Email in CLink.ID </th> 
    <td><label for="user_display_email"><input type="checkbox" id="user_display_email" name="user_display_email" value="1" <?php checked( $get_clink_display_email, 'yes' ); ?> <?php echo $disabled; ?>> Enable</label></td>
    </tr>
   </table>
   
<table class="form-table">



      
    <?php if($user->ID == $creator_id and $user->ID != $party_id){ ?>
    <?php if(!empty(get_user_meta($user->ID,'wpclink_party_identifier',true))){ ?>
    <tr>
    <th>CLink Party ID </th> 
    <td><a class="cl_primary_id" target="_blank" href="<?php echo WPCLINK_ID_URL; ?>/#objects/<?php echo get_user_meta($user->ID,'wpclink_party_identifier',true);  ?>"><?php echo get_user_meta($user->ID,'wpclink_party_identifier',true);  ?></a> <input class="button version_toggle party" type="button" value="Versions" /></td>
    </tr>
    <?php } ?>
    <?php } ?>
    <?php if($user->ID == $party_id){ ?>
    <tr>
    <th>CLink Party ID </th> 
    <td><a class="cl_primary_id" target="_blank" href="<?php echo WPCLINK_ID_URL; ?>/#objects/<?php echo get_user_meta($user->ID,'wpclink_party_identifier',true);  ?>"><?php echo get_user_meta($user->ID,'wpclink_party_identifier',true);  ?></a> <?php echo $my_user_status; ?> <input class="button version_toggle party" type="button" value="Versions" /></td>
    </tr>
    <?php } ?>
     
	<?php $party_versions = get_user_meta($user->ID,'wpclink_versions_party',true); ?>
		
    </table>

<?php

	if ($party_versions = array_reverse(get_user_meta($user->ID,'wpclink_versions_party',true))){ ?>
<ul class="versions_users party">
		<p>
			<?php  foreach ($party_versions as $single_party_version){
		if(!empty($single_party_version['id'])){ ?>
		<li><a class="version_identifier" target="_blank" href="<?php echo WPCLINK_ID_URL; ?>/#objects/<?php echo $single_party_version['id']; ?>"><?php echo $single_party_version['id']; ?></a> <span class="version_time"><span class="dashicons dashicons-clock"></span> <?php echo date( 'Y-m-d H:i:s',$single_party_version['time']); ?></span></li></p>
			<?php  }
	 	} ?>
</ul>			
	<?php } ?>

	<input type="hidden" id="make_version" name="make_version" value="1" />
    <input type="hidden" id="submit_to_clinkid" name="submit_to_clinkid" value="0" /><br />
<script>

jQuery(document).ready(function(e) {
    

  jQuery('#submit').click(function(event){
	  jQuery('.cl_user_popup').show();
	  event.preventDefault();
  });
  
  jQuery('#submit2').click(function(event){
	  jQuery('#submit_to_clinkid').attr('value','1');
  });
	
	
jQuery('#make_version_checkbox').change(function() {
  if (jQuery(this).is(':checked')) {
     jQuery('#make_version').attr('value','1');
  } else {
   	 jQuery('#make_version').attr('value','0');
  }
});
	
	jQuery(".version_toggle.creator").click(function(){ jQuery(".versions_users.creator").slideToggle("fast"); });
	jQuery(".version_toggle.party").click(function(){ jQuery(".versions_users.party").slideToggle("fast"); });
        
  jQuery(document).tooltip();
});


 

  </script>
   
   <div class="cl_user_popup">
   <div class="content">
  <p>Do you want to update the user information also in CLink.ID</p>
	   <label><input type="checkbox" id="make_version_checkbox" name="make_version_checkbox" value="1" checked /> Make a version of the existing profile <span class="icon-box" title="Your current profile will be kept as a version in the CLink Registry"></span> </label><br><br>
  <center><input name="submit2" id="submit2" class="button " value="Yes" type="submit"> <input name="submit3" id="submit3" class="button " value="No" type="submit"></center>
  </div>
</div>

    <?php
}
// Register clink user profile form on edit profile
add_action( 'edit_user_profile', 'wpclink_custom_user_field' );	
// Register clink user profile form on show profile
add_action( 'show_user_profile', 'wpclink_custom_user_field' );

/**
 * CLink User Fields Update
 * 
 * @param integer $user_id  user id
 * 
 */

function wpclink_custom_user_field_save( $user_id )
{
        
	if ( !current_user_can( 'edit_user', $user_id ) )
	return FALSE;
	
	
	if(isset($_POST['clink_social_display'])){
    $clink_social_display = $_POST['clink_social_display'];
    update_user_meta( $user_id, 'wpclink_social_display', $clink_social_display );
	}
	
	if(isset($_POST['party_structure_type'])){
	//$party_structure_type = $_POST['party_structure_type'];
    //update_user_meta( $user_id, 'clink_party_structural_type', $party_structure_type );
	
	}
	
	if(isset($_POST['user_display_email'])){
	$user_display_email = $_POST['user_display_email'];
		if($user_display_email == '1'){
			update_user_meta( $user_id, 'wpclink_email_display_status','yes');
		}else{
			update_user_meta( $user_id, 'wpclink_email_display_status','no');
		}
	}else{
		update_user_meta( $user_id, 'wpclink_email_display_status','no');	
	}
	
	
	
	
 
}
// Register clink user fileds save on profile update
add_action( 'edit_user_profile_update', 'wpclink_custom_user_field_save' );
// Register clink user fileds save on personal option update
add_action( 'personal_options_update', 'wpclink_custom_user_field_save' );

/**
 * CLink Author Creator Column
 * 
 * @param string $columns default column
 * 
 */
function wpclink_author_creator_column( $columns ) {  
    //print_r($columns);  
    $columns[ 'author' ] = 'Author / Creator';  
    return $columns;  
}
// Register clink author creator column function
add_filter('manage_edit-post_columns','wpclink_author_creator_column');
add_filter('manage_edit-page_columns','wpclink_author_creator_column');


/**
 * CLink Publish Content Popup
 * 
 * To show license of linked content allow to As Is | Restricted
 * 
 */
function wpclink_publish_linked_content_popup(){
	if(isset($_GET['page']) and ($_GET['page'] == 'content_link_post.php' || $_GET['page'] == 'content_link_page.php' )){ ?>
<div id="cl_publish_popup" class="cl_popup" style="display:none;">
<span class="dashicons dashicons-no-alt close-pbox"></span>
<div class="inner">
<h3><center>Publish Content</center></h3>
     <p class="cl_message"></p>
     <div class="cl_actions"><a class="button button-primary">Publish</a></div>
</div>
</div>
	<?php }
}
// Register publish content popup on footer of admin 
add_action('admin_footer','wpclink_publish_linked_content_popup');

/**
 * CLink Pre-Authorization Popup
 * 
 */

function wpclink_pre_auth_popups(){
	if(isset($_GET['page']) and ($_GET['page'] == 'cl-restriction') || ($_GET['page'] == 'cl-restriction-page-available')){ 
	
	
			// Pre Author
			$clink_popup_pre_auth = wpclink_get_option('pre_auth_license');
			
			// E-Sign
			$clink_esign_pre_auth = wpclink_get_option('pre_auth_esign');
			
			
				$html = '<div id="cl_show_pre_auth" title="CONSENT TO PRE-AUTHORIZED" style="display:none;">'.$clink_popup_pre_auth.'</div>'; 
				
				$html.= '<div id="cl_show_esign_pre" title="CONSENT TO PRE-AUTHORIZED" style="display:none;">'.$clink_esign_pre_auth.'</div>'; 
				
				
				echo $html;
	
	
	 }
}
// Register pre-authorization popup on admin footer
add_action('admin_footer','wpclink_pre_auth_popups');

/**
 *  CLink Select License Popup
 * 
 */

function wpclink_license_selection_popup(){
	// Versions
	$license_ver = wpclink_get_option('license_versions');
	
	if(isset($_GET['page']) and $_GET['page'] == 'cl-restriction' ||  $_GET['page'] == 'cl-restriction-page-available'){ ?>

 
  
<div id="cl-license-selection_step2" class="cl_popup" style="display:none;">
<span class="dashicons dashicons-no-alt close-pbox"></span>
<div class="inner">
<form action="" method="post">
<input type="hidden" value="<?php if($_GET['page'] == 'cl-restriction'){ echo 'cl-restriction'; }elseif($_GET['page'] == 'cl-restriction-page-available'){ echo 'cl-restriction-page-available'; } ?>" id="page_name" name="page" />
<p><label><input name="pre_authorize" class="pre_auth_check" type="checkbox" value="1" /> I consent to <a id="cl_pop1" href="#">Pre-Authorized Lincensing of Referent Creations</a> and <a id="cl_pop2" href="#">Pre-Authorized application of E-Signature to License</a></label></p>
<input type="hidden" value="" id="referent_id_s2" name="referent" />
<input type="hidden" value="" id="license_version_s2" name="license_version" />
<input type="hidden" value="" id="license_type_s2" name="license_type" />
<p class="pre-auth-btn">
<input type="button" class="button button button-large show-lc-btn" value="View License"  />
<input type="submit" class="button button-primary button-large make-ref-btn_s2" disabled="disabled" value="Confirm and Continue"  />
</p>
</form>
</div>
</div>


<div id="cl-license-show" title="License" style="display:none;">
<div class="inner">
<div class="license_text">
<div id="license_show_box"></div>
</div>
</div>
</div>

<?php if($_GET['page'] == 'cl-restriction') { ?>
<div id="cl-license-selection" class="cl_popup" style="display:none;">
<span class="dashicons dashicons-no-alt close-pbox"></span>
<div class="inner">

<h3>Please select License Type</h3>
<h5 class="view_lstype"><a href="<?php echo menu_page_url( 'cl_templates', false ); ?>"><?php echo "View License Templates"; ?></a></h5>
<input type="hidden" value="<?php if($_GET['page'] == 'cl-restriction'){ echo 'cl-restriction'; }elseif($_GET['page'] == 'cl-restriction-page-available'){ echo 'cl-restriction-page-available'; } ?>" id="page_name" name="page" />
<select id="license_type" name="license_type" class="license_type_form" >
<option value="as_is">As Is</option>
<option value="restricted">Restricted</option>
</select>
<input type="hidden" value="" id="referent_id" name="referent" />
<p><input type="submit" class="button button-primary button-large make-ref-btn" value="Select"  /></p>
</div>
</div>
<?php }else{ ?>
<div id="cl-license-selection" class="cl_popup" style="display:none;">
<span class="dashicons dashicons-no-alt close-pbox"></span>
<div class="inner">

<h3>License</h3>
<h5 class="view_lstype"><a href="<?php echo menu_page_url( 'cl_templates', false ); ?>&cl_license_type=as_is"><?php echo "View License Template"; ?></a></h5>
<p><?php _e('Selected page to be published with AS IS License','cl_text'); ?></p>	
<input type="hidden" value="<?php if($_GET['page'] == 'cl-restriction'){ echo 'cl-restriction'; }elseif($_GET['page'] == 'cl-restriction-page-available'){ echo 'cl-restriction-page-available'; } ?>" id="page_name" name="page" />
<input id="license_type" type="hidden" name="license_type" value="as_is" />
<input type="hidden" value="" id="referent_id" name="referent" />
<p><input type="submit" class="button button-primary button-large make-ref-btn" value="Next"  /></p>
</div>
</div>	
<?php } ?>
	<?php }
}
// Register select the license popup on admin footer
add_action('admin_footer', 'wpclink_license_selection_popup');

/**
 * CLink Accept Pre Auth Popops
 * 
 */
function wpclink_accept_pre_auth_popups($post_id = 0, $meta_key = NULL){
								
	// View Time
	$view_time = date("Y-m-d H:i:s");
	
	// Audit
	$return_id = update_post_meta($post_id,$meta_key,$view_time);
	
	return 	$return_id;			
}

/**
 * CLink Remove Quick Edit on the Referent Linked Contents
 * 
 * @param array $unset_actions post actions
 * @param object $post post object 
 * 
 * @return array unset actions
 */

function wpclink_remove_quick_edit_referent_linked_content( $unset_actions, $post ) {
	
	// Screen
  	global $current_screen;

	// Post and Page
	if ( $current_screen->post_type == 'post'  || $current_screen->post_type == 'page' ){
	
	// Post ID
	$post_id = $post->ID;
	
		// Referent Content
		if(wpclink_is_content_linked($post_id) > 0){
			
			// Quick Edit
			unset( $unset_actions[ 'inline hide-if-no-js' ] );
		}
	
	}

	return $unset_actions;
}
// Register clink remove quick edit on the referent link post functions
add_filter( 'post_row_actions', 'wpclink_remove_quick_edit_referent_linked_content', 10, 2 );
add_filter( 'page_row_actions', 'wpclink_remove_quick_edit_referent_linked_content', 10, 2 );


/**
 * CLink Remove Quick Edit on Linked Content
 * 
 * @param array $unset_actions actions link of row
 * @param object $post post object
 * 
 */

function wpclink_remove_quick_edit_linked_content( $unset_actions, $post ) {
	
	// Screen
  	global $current_screen;

	// Post and Page
	if ( $current_screen->post_type == 'post'  || $current_screen->post_type == 'page' ){
	
	// Post ID
	$post_id = $post->ID;
	
		// Linked Content
		if($sync_origin = get_post_meta( $post_id, 'wpclink_referent_uri', true )){
			
			// Quick Edit
			unset( $unset_actions[ 'inline hide-if-no-js' ] );
		}
	
	}

	return $unset_actions;
}
add_filter( 'post_row_actions', 'wpclink_remove_quick_edit_linked_content', 10, 2 );
add_filter( 'page_row_actions', 'wpclink_remove_quick_edit_linked_content', 10, 2 );

/**
 * CLink Linked Content Supplementary  Meta Boxes
 * 
 * @param object $post post object
 * 
 */
function wpclink_linked_content_meta_box( $post ){
	
	if (  get_current_screen()->post_type === 'post') {
	
	 
		 if(isset($_GET['post'])){
			 if(is_numeric($_GET['post'])){
		 
			 // Post ID
			$post_id = $_GET['post'];
			
			$license_type = get_post_meta( $post_id, 'wpclink_creation_license_type', true );
				// Only Linked Content
				if($sync_origin = get_post_meta( $post_id, 'wpclink_referent_uri', true )){
					if($license_type == 'restricted'){
						
		// Tags
		add_meta_box( 'cl_linked_tags_meta', __( 'Supplementary Tags', 'cl_text' ), 'wpclink_linked_supplementary_tags_meta_box', 'post' );
		// Categories
		add_meta_box( 'cl_linked_categories_meta', __( 'Supplementary Categories', 'cl_text' ), 'wpclink_linked_supplementary_categories_meta_box', 'post' );
		
					}
		
				}
			 }
		 }
		 
	 }
			 
}
// Register Clink linked content supplementary meta boxes function
add_action( 'add_meta_boxes', 'wpclink_linked_content_meta_box' );

/**
 * Linked Content Supplementary Categories
 *
 * @param int $post_id The post ID.
 */
function wpclink_linked_supplementary_tags( $post_id ){
	// verify taxonomies meta box nonce
	if ( !isset( $_POST['clink_linked_supplementary_tags'] ) || !wp_verify_nonce( $_POST['clink_linked_supplementary_tags'], basename( __FILE__ ) ) ){
		return;
	}
	// return if autosave
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ){
		return;
	}
	// Check the user's permissions.
	if ( ! current_user_can( 'edit_post', $post_id ) ){
		return;
	}
	
	$license_type = get_post_meta( $post_id, 'wpclink_creation_license_type', true );
	
	if($license_type != 'restricted'){
		return;
	}
	
	$tags_name = array();
	
	
	// store custom fields values
	if( isset( $_POST['cl_linked_tags'] ) ){
		$linked_tags = (array) $_POST['cl_linked_tags'];
		// sinitize array
		$linked_tags = array_map( 'sanitize_text_field', $linked_tags );
		// save data
		
		foreach($linked_tags as $single_tag){
			$tag_data = get_term($single_tag,'post_tag');
			$tags_name[] = $tag_data->name;
		}
		
		wp_set_post_tags( $post_id, $tags_name, false );
	}
}
add_action( 'save_post', 'wpclink_linked_supplementary_tags' );

/**
 * CLink Linked Supplementary Categories Metabox
 *
 * @param post $post The post object
 */
function wpclink_linked_supplementary_tags_meta_box( $post ){
	
	// make sure the form request comes from WordPress
	wp_nonce_field( basename( __FILE__ ), 'clink_linked_supplementary_tags' );
	
	
	// All categories
	$all_tags = get_tags( array(
	    'orderby' => 'name',
    	'order'   => 'ASC'
	) );
	
	
	
	// Post Categories
	$post_tags = wp_get_post_tags( $post->ID );
	$tgs = array();
	$tg_ids = array();
		 
	foreach($post_tags as $t){
		
		$selected_tag[] = $t->term_id;
	}

	
	foreach($all_tags as $single_tag){
		
		$tags_only_ids[] = $single_tag->term_id;
		
	}
	
	
	$referent_tags_ids = array();
	
	if($referent_tags = get_post_meta($post->ID,'wpclink_creation_referent_tags',true)){
		
		foreach($referent_tags as $single_ref){
			$term = get_term_by('name',$single_ref, 'post_tag');
			$referent_tags_ids[] = $term->term_taxonomy_id;
			
		}
		
	}else{
		$referent_tags_ids = array();	
	}

	// Only Supplementary Categories
	$supplementary_tag = array_diff($tags_only_ids,$referent_tags_ids);
	
	
	?>
	<div class='inside'>
    <div class="supplementary_box">
		<p>
		<?php
			foreach ( $all_tags as $tag ) {
				
				if(in_array($tag->term_id,$supplementary_tag)){
					
					?>
				<label for="cl_linked_tags-<?php echo $tag->term_id; ?>"><input id="cl_linked_tags-<?php echo $tag->term_id; ?>" type="checkbox" name="cl_linked_tags[]" value="<?php echo $tag->term_id; ?>" <?php if(in_array($tag->term_id,$selected_tag)){ echo "checked=checked"; } ?>  /><?php echo $tag->name; ?> </label><br />

				<?php
				}else{
				
				?>
				<label for="cl_linked_tags-<?php echo $tag->term_id; ?>"><input id="cl_linked_tags-<?php echo $tag->term_id; ?>" type="checkbox" checked="checked" disabled="disabled" /><?php echo $tag->name; ?></label>
                <input type="hidden" name="cl_linked_tags[]" value="<?php echo $tag->term_id; ?>" /><br />

				<?php
				
				}
			}
		?>
		</p>
        </div>
	</div>
	<?php
}

/**
 * CLink Linked Supplementary Categories Metabox
 *
 * @param post $post The post object
 */
function wpclink_linked_supplementary_categories_meta_box( $post ){
	
	// make sure the form request comes from WordPress
	wp_nonce_field( basename( __FILE__ ), 'clink_linked_supplementary_categories' );
	
	
	// All categories
	$categories = get_categories( array(
	    'orderby' => 'name',
    	'order'   => 'ASC'
	) );
	
	// Post Categories
	$post_categories = wp_get_post_categories( $post->ID );
	$cats = array();
	$category_ids = array();
		 
	foreach($post_categories as $c){
		$cat = get_category( $c );
		$cats[] = $cat->term_id;
	}
	
	foreach($categories as $single_category){
		
		$category_ids[] = $single_category->term_id;
		
	}
	
	if($referent_categories = get_post_meta($post->ID,'wpclink_creation_referent_categories',true)){	
		
	}else{
		$referent_categories = array();	
	}

	// Only Supplementary Categories
	$supplementary_cat = array_diff($category_ids,$referent_categories);
	

	
	
	?>
	<div class='inside'>
    <div class="supplementary_box">
		<p>
		<?php
			foreach ( $categories as $category ) {
				
				if(in_array($category->term_id,$supplementary_cat)){
					
					?>
				<label for="cl_linked_categories-<?php echo $category->term_id; ?>"><input id="cl_linked_categories-<?php echo $category->term_id; ?>" type="checkbox" name="cl_linked_categories[]" value="<?php echo $category->term_id; ?>" <?php if(in_array($category->term_id,$cats)){ echo "checked=checked"; } ?>  /><?php echo $category->name; ?> </label><br />

				<?php
				}else{
				
				?> 
				<label for="cl_linked_categories-<?php echo $category->term_id; ?>"><input id="cl_linked_categories-<?php echo $category->term_id; ?>" type="checkbox" checked="checked" disabled="disabled" /><?php echo $category->name; ?></label>
                <input type="hidden" name="cl_linked_categories[]" value="<?php echo $category->term_id; ?>" /><br />

				<?php
				
				}
			}
		?>
		</p>
        </div>
	</div>
	<?php
}