<?php
/**
 * CLink XML Functions
 *
 * CLink XML creation functions
 *
 * @package CLink
 * @subpackage Content Manager
 */

 
 // Direct Access Not Allowed
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

/**
 * CLink Get Client IP
 * 
 * @return string
 */

function wpclink_get_client_ip() {
    $ipaddress = '';
    if (getenv('HTTP_CLIENT_IP'))
        $ipaddress = getenv('HTTP_CLIENT_IP');
    else if(getenv('HTTP_X_FORWARDED_FOR'))
        $ipaddress = getenv('HTTP_X_FORWARDED_FOR');
    else if(getenv('HTTP_X_FORWARDED'))
        $ipaddress = getenv('HTTP_X_FORWARDED');
    else if(getenv('HTTP_FORWARDED_FOR'))
        $ipaddress = getenv('HTTP_FORWARDED_FOR');
    else if(getenv('HTTP_FORWARDED'))
        $ipaddress = getenv('HTTP_FORWARDED');
    else if(getenv('REMOTE_ADDR'))
        $ipaddress = getenv('REMOTE_ADDR');
    else
        $ipaddress = 'UNKNOWN';
 
    return $ipaddress;
}

/**
 * CLink License Agreement Template Generate
 * 
 * @param integer $content_id  content id
 * 
 * @return string license template
 */

function wpclink_agreement_template_ready($content_id = 0){
	
	// Info
	$time = current_time('H:i');
	$date = current_time('M d, Y');
	$site  = get_bloginfo('url').'/';
	
	// Party
	$party_id = wpclink_get_option('authorized_party');
	$party_info = get_userdata($party_id);
	$party_display_name = $party_info->display_name;
	$party_first_name = $party_info->first_name;
	$party_last_name = $party_info->last_name;
	
	// Creator
	$creator_array = wpclink_get_option('authorized_creators');
	$creator_id = $creator_array[0];
	$creator_info = get_userdata($creator_id);
	$creator_display_name = $creator_info->display_name;
	$creatot_first_name = $creator_info->first_name;
	$creator_last_name = $creator_info->last_name;
	$creator_email = $creator_info->user_email;
	
	// Copyright Owner 
	$copyright_owner = wpclink_get_option('copyright_owner');
	if($copyright_owner == 'party'){
		$copyright_owner_firstname = $party_info->first_name;
		$copyright_owner_lastname = $party_info->last_name;
		$copyright_owner_display = $party_info->display_name;
		$copyright_owner_email = $party_info->user_email;
		
		$copyright_identifier = get_user_meta($party_id,'wpclink_party_identifier',true);
		
	}else if($copyright_owner == 'creator'){
		$copyright_owner_firstname = $creator_info->first_name;
		$copyright_owner_lastname = $creator_info->last_name;
		$copyright_owner_display = $creator_info->display_name;
		$copyright_owner_email = $creator_info->user_email;
		
		$copyright_identifier = get_user_meta($creator_id,'wpclink_creator_identifier',true);
	}
	
	
	$post_url = get_permalink($content_id);
	$post_creation_identifier = get_post_meta($content_id,'wpclink_creation_identifier',true);
	$creator_identifier = get_user_meta($creator_id,'wpclink_creator_identifier',true);
	
	
	$search = array('[current_date]','[current_time]','[my_site]','[party_display]','[party_firstname]','[party_lastname]','[creator_displayname]','[creator_firstname]','[creator_lastname]','[copyright_owner_firstname]','[copyright_owner_lastname]','[copyright_owner_display_name]','[date_of_license]','[canonical_url]','[creation_identifier]','[display_name]','[copyright_owner_identifier]','[creator_identifier]','[post_copyright_owner]','[copyright_owner_user_email]','[creator_user_email]');
	$replace = array($date,$time,$site,$party_display_name,$party_first_name,$party_last_name,$creator_display_name,$creatot_first_name,$creator_last_name,$copyright_owner_firstname,$copyright_owner_lastname,$copyright_owner_display,$date,$post_url,$post_creation_identifier,$copyright_owner_display,$copyright_identifier,$creator_identifier,$copyright_owner_display,$copyright_owner_email,$creator_email);
	
	// License By Post
	if($content_id > 0){
		if($license_type = get_post_meta($content_id,'wpclink_creation_license_type',true)){
			if($license_type == 'as_is'){
				$clink_licenses = wpclink_get_option( 'licenses' );
				$agreement_template = $clink_licenses['as_is'];
			}elseif($license_type == 'restricted'){
				$clink_licenses = wpclink_get_option( 'licenses' );
				$agreement_template = $clink_licenses['restricted'];
			}
		}
	}
	
	$agreement_template_final = str_replace($search,$replace,$agreement_template);
	
	return $agreement_template_final;
}


/**
 * CLink Generate Content XML
 * 
 * CLink generate the content for linked sites
 * Content will generate from following security checks:
 *
 * 1. Content is in referent list.
 * 2. Content request site has token and link establish without canonical voilation.
 * 3. Content request pass key should be match the plugin activation pass key.
 * 4. Content request ip should be match to ip recorded when link is created.
 * 5. Content request should be only allowed query variabes listed in code.
 *
 */

function wpclink_start_content_link_xml(){


header("Cache-Control: no-cache, no-store, must-revalidate"); // HTTP 1.1.
header("Pragma: no-cache"); // HTTP 1.0.
header("Expires: 0"); // Proxies.

// Random Pass Key
$pass_key = wpclink_get_option('DYNAMIC_URL_POSTFIX_PASS');

// Get Option
$options = wpclink_get_option( 'preferences_general' );

// GET URL RESET
$get_wpsync = $_GET;

$get_pass_key = $_GET['pass_key'];

if($get_pass_key == $pass_key){
	
	// Prepare WP Variables
	$date = date();
	$curr_date_time = strtotime($date);
	$site_url = network_site_url( '/' );
	
}else{
	die('0');
}

if(isset($_GET['direct'])){
}else{
	if(wpclink_extention_signal()){	
	}else{
		die('Action not Allowed');	
}
}
?><?php echo'<?xml version="1.0" encoding="UTF-8" ?>'; ?>
<rss version="2.0"
	xmlns:excerpt="http://wordpress.org/export/1.2/excerpt/"
	xmlns:content="http://purl.org/rss/1.0/modules/content/"
	xmlns:wfw="http://wellformedweb.org/CommentAPI/"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:wp="http://wordpress.org/export/1.2/"
>
<channel>
 <title><?php bloginfo('name'); ?></title>
    <link><?php bloginfo('url'); ?></link>
    <description><?php bloginfo('description'); ?></description>
    <pubDate><?php echo $curr_date_time; ?></pubDate>
    <language><?php bloginfo('language'); ?></language>
    <wp:wxr_version>1.2</wp:wxr_version>
    <wp:base_site_url><?php echo $site_url; ?></wp:base_site_url>
    <wp:base_blog_url><?php echo site_url(); ?></wp:base_blog_url>
    <blog_local_time><?php echo date( 'Y-m-d H:i:s', current_time( 'timestamp', 0 )); ?></blog_local_time>
    <generator>https://wordpress.org/?v=4.6.1</generator>
    <cl_status><?php echo 'active'; ?></cl_status>
    <?php 
// WP_Query arguments
$args = array();

if(isset($get_wpsync['posts_per_page'])){
	$args['posts_per_page'] = $get_wpsync['posts_per_page'];
}
if(isset($get_wpsync['order'])){
	$args['order'] = $get_wpsync['order'];
}
if(isset($get_wpsync['orderby'])){
	$args['orderby'] = $get_wpsync['orderby'];
}
if(isset($get_wpsync['nopaging'])){
	$args['nopaging'] = $get_wpsync['nopaging'];
}
if(isset($get_wpsync['post_type'])){	
	// Remove c- 
	$get_wpsync['post_type'] = str_replace("c-","",$get_wpsync['post_type']);
	
	$my_post_types = explode(",",$get_wpsync['post_type']);
	$args['post_type'] =  $my_post_types;
	$post_type = str_replace("c-","",$get_wpsync['post_type']);
}
if(isset($get_wpsync['post__in'])){
	$my_not_posts_show = explode(",",$get_wpsync['post__in']);
	$args['post__in'] = wpclink_get_all_posts($my_not_posts_show,$post_type);
	
}else{
		$args['post__in'] = wpclink_posts_show($post_type);
}
if(isset($get_wpsync['search'])){
	$args['s'] = $get_wpsync['search'];
}
if(isset($get_wpsync['author_id'])){
	$args['author'] = $get_wpsync['author_id'];
}
if(isset($get_wpsync['author_name'])){
	$args['author_name'] = $get_wpsync['author_name'];
}
if(isset($get_wpsync['tag'])){
	$args['tag'] = $get_wpsync['tag'];
}
if(isset($get_wpsync['category_name'])){
	$args['category_name'] = $get_wpsync['category_name'];
}
$args['ignore_sticky_posts'] = true;

$args['meta_key'] = 'wpclink_creation_identifier';
$args['meta_value'] = ' ';
$args['meta_compare'] = '!=';

$paged = ( $get_wpsync['paged'] ) ? $get_wpsync['paged'] : 1;
if(isset($get_wpsync['paged'])){
	$paged = ( $get_wpsync['paged'] ) ? $get_wpsync['paged'] : 1;
	$args['paged'] = $get_wpsync['paged'];
	$paged = $args['paged'];
}

$content_show = false;
if((isset($get_wpsync['get_type'])) and ($get_wpsync['get_type'] == 'content')){
	$content_show = true;
}
	
// The Query
$export_query = new WP_Query( $args );

// Total Number of Posts
echo '<item_count>'.$export_query->found_posts.'</item_count>';

if ( $export_query->have_posts() ) {
	// The Loop
	while ( $export_query->have_posts() ) {
	$export_query->the_post();
	$post_id = get_the_ID();
	
	if($reuse_content = get_post_meta($post_id,'wpclink_creation_reuse_status',true)){
	}else{
	$author_id = get_the_author_meta('id');
	$post_type = get_post_type($post_id);
	?>
    <item>
      <title><?php echo get_the_title(); ?></title>
      <link><?php echo get_permalink(); ?></link>
      <pubDate><?php echo get_the_date(); ?></pubDate>
      <dc:creator_id><?php echo $author_id; ?></dc:creator_id>
      <dc:creator><![CDATA[<?php echo the_author_meta('user_login'); ?>]]></dc:creator>
      <guid isPermaLink="false"><?php echo get_the_guid($post_id); ?></guid>
      <description></description>
      <?php if($content_show){ ?>
      <content:encoded><![CDATA[<?php echo get_the_content(); ?>]]></content:encoded>
      <excerpt:encoded><![CDATA[<?php echo get_the_excerpt(); ?>]]></excerpt:encoded>
	  <?php } ?>
      <?php if(has_post_thumbnail()){ ?>
      <wp:post_thumbnail><post_thumbnail_url><?php the_post_thumbnail_url(); ?></post_thumbnail_url></wp:post_thumbnail>
	  <?php } ?>
      <wp:post_id><?php echo $post_id; ?></wp:post_id>
      <post_id><?php echo $post_id; ?></post_id>
      <post_license_type><?php 
	  if($get_license_type = get_post_meta($post_id, 'wpclink_creation_license_type', true)){
		  echo $get_license_type;
	  }else{
		  echo wpclink_get_option( 'wpclink_license_type' ); 
	  } ?></post_license_type>
      <post_creator_clink_id><?php 
	  echo get_user_meta($author_id,'wpclink_creator_identifier',true);
	  ?></post_creator_clink_id>
      <post_creator><?php 
	  $user_info = get_userdata($author_id);
      echo $user_info->display_name;
	  ?></post_creator>
      <post_copyright_owner><?php 
      $copyright_owner = wpclink_get_option('copyright_owner');
	
	if($copyright_owner == 'party'){
		$copyright_owner_id = wpclink_get_option('authorized_party');
	}elseif($copyright_owner == 'creator'){
		$creator_array = wpclink_get_option('authorized_creators');
		$copyright_owner_id = $creator_array[0];
		
	}
	
	$copyright_owner_user_id = $copyright_owner_id;
	$copyright_owner_user_id = get_user_meta($copyright_owner_user_id,'wpclink_creator_identifier',true);
	
	echo $copyright_owner_user_id;
      ?></post_copyright_owner>
      <post_license_version><?php echo get_post_meta($post_id, 'wpclink_post_license_version', true); ?></post_license_version>
      <?php if($post_type == 'page'){ ?><wp:post_parent><?php echo wp_get_post_parent_id( $post_id ); ?></wp:post_parent><?php } ?>
      <wp:post_type><![CDATA[<?php echo get_post_type($post_id); ?>]]></wp:post_type>
	  <wp:status><![CDATA[<?php echo get_post_status($post_id); ?>]]></wp:status>
      <created_time><?php echo get_the_date( 'Y-m-d' ).' '.get_the_time('H:i:s'); ?></created_time>
      <modified_time><?php echo get_the_modified_date( 'Y-m-d H:i:s' ); ?></modified_time>
      <?php if($content_id = get_post_meta( $post_id, 'wpclink_creation_identifier', true )){ ?>
      <content_id><?php echo $content_id; ?></content_id>
      <?php } ?>
      <?php 
	  if(get_post_type($post_id) == 'post'){
	  $post_categories = wp_get_post_categories( $post_id );
	  $cats = array();
     
		foreach($post_categories as $c){
    		$cat = get_category( $c );
			?>
            <category domain="category" nicename="<?php echo $cat->slug; ?>"><![CDATA[<?php echo $cat->name; ?>]]></category>
            <?php
		}
		
		$t = wp_get_post_tags($post_id);
		$tags = $t;
		foreach($tags as $tag){ 
		?>
        <category domain="post_tag" nicename="<?php echo $tag->slug;?>"><![CDATA[<?php echo $tag->name;?>]]></category>
		<?php	
		}
		
	  }
	  ?></item>
<?php } ?>
<wp:pagination>
<?php
if (($export_query->max_num_pages > 1) and ($paged < $export_query->max_num_pages)) { ?>
<pg_max><?php echo $export_query->max_num_pages; ?></pg_max>
<pg_next><?php echo $paged+1; ?></pg_next>
<pg_prev><?php  if($paged > 1){ echo $paged-1; } ?></pg_prev>
<?php } ?>
<pg_current><?php echo $paged; ?></pg_current>
<?php if($paged > 1){ ?><pg_prev><?php echo $paged-1; ?></pg_prev><?php } ?>
</wp:pagination>
<?php wp_reset_postdata();
}
} ?></channel></rss>
<?php }

/**
 * CLink Start Site Agreements
 * 
 * Use for create the site agreemnet link
 * 
 */
function wpclink_start_site_agreement(){


// XML CLEANUP
error_reporting(0);

header("Cache-Control: no-cache, no-store, must-revalidate"); // HTTP 1.1.
header("Pragma: no-cache"); // HTTP 1.0.
header("Expires: 0"); // Proxies.

// Prepare WP Variables
	$date = date();
	$curr_date_time = strtotime($date);
	$site_url = network_site_url( '/' );


if(($_GET['cl_action'] == 'connect') and !empty($_GET['client_site'])){
	
global $wpdb;

// Table Prefix
$table_name_token = $wpdb->prefix . 'wpclink_tokens'; 

$request_agree = $_GET;
$token = $request_agree['token'];

$record_found = $wpdb->get_row( 'SELECT * FROM '.$table_name_token.' WHERE token = "'.$token.'" AND token_expiration <> 1' );


if($record_found){
	
	// Action Begins
	$site_url =	$_GET['client_site'];
	$client_site = urldecode($site_url);
	
	// GET IP
	$url = parse_url($client_site);
	$host_url = $url['host'];
	
	// PICK IP
	//$ip = gethostbyname($host_url);
	$ip = wpclink_get_client_ip();
	
	global $wpdb;
	$clink_sites_table = $wpdb->prefix . 'wpclink_licenses'; 
	
	// Status
	$agreement_status = 'good';
	
	// Linked Info
	$link_firstname = urldecode($request_agree['link_first']);
	$link_lastname = urldecode($request_agree['link_last']);
	$link_display = urldecode($request_agree['link_display']);
	$link_email = urldecode($request_agree['link_email']);
	$link_identifier = urldecode($request_agree['link_identifier']);
	$link_unique_id = urldecode($request_agree['cl_unique_id']);
	
	// Esign
	$esign_by = urldecode($request_agree['esign_by']);
	$esign_reason = urldecode($request_agree['esign_reason']);
	$esign_time = urldecode($request_agree['esign_time']);
	$esign_email = urldecode($request_agree['esign_email']);
	$esign_copyright_identifier = urldecode($request_agree['esign_copyright_identifier']);
	$esign_sign_date = date("Y-m-d H:i:s");
	
	$esign_time_formated = date("Y-m-d H:i:s",$esign_time);
	
	// Time Difference
	$time_difference = urldecode($request_agree['time_diff']);
	$time_difference_formate = date("H:i:s",$time_difference);
	
	
	$esign_html_stamp = wpclink_esign_print2($esign_by,$esign_reason,$esign_time_formated,$esign_copyright_identifier);
	
	
	// Array
	$extra_link = array('link_email' => $link_email, 'link_identifier' => $link_identifier,'licensee_accept_datetime' => $time_difference_formate);
	
	// Content ID by Token
	$content_id = $record_found->post_id;
	
	// Content URL by Token
	$content_url = $record_found->creation_uri;
	
	
	$ip_match = $wpdb->get_results( "SELECT * FROM $clink_sites_table WHERE licensed_creation_id = '$content_id' AND mode = 'referent' ", ARRAY_A );
	
	
	// IP Verification
	if($ip_match){
		
			
	$license_promoted_id = wpclink_add_license_promoted($site_url,$ip,$agreement_status,1,$link_firstname,$link_lastname,$link_display,$content_id,$content_url,'',$extra_link,$token);
	
	// Electronic Signature by Licensor
	wpclink_add_esign($esign_by,$esign_reason,$esign_sign_date,$esign_time_formated, $token, $esign_email,$ip, $content_id,$license_promoted_id,$esign_html_stamp);		
	
	// RSS
		echo '<?xml version="1.0" encoding="UTF-8" ?>'; ?>
		<rss version="2.0"
	xmlns:excerpt="http://wordpress.org/export/1.2/excerpt/"
	xmlns:content="http://purl.org/rss/1.0/modules/content/"
	xmlns:wfw="http://wellformedweb.org/CommentAPI/"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:wp="http://wordpress.org/export/1.2/"
>
	<channel>
    <site_address><?php echo bloginfo('url').'/'; ?></site_address>
    <secret_key><?php echo wpclink_get_option('DYNAMIC_URL_POSTFIX_SECRET_KEY'); ?></secret_key>
    <auth_code><?php echo wpclink_get_option('DYNAMIC_URL_POSTFIX_DATA_KEY'); ?></auth_code> 
    <license_type><?php
	
	if($license_type = get_post_meta($content_id,'wpclink_creation_license_type',true)){
		if($license_type == '0'){
			echo wpclink_get_option('wpclink_license_type');
		}else{
			echo $license_type;
		}
	}else{
		echo wpclink_get_option('wpclink_license_type');
	}
	
	// CREATOR
	$creator_array = wpclink_get_option('authorized_creators');
	$creator_id = $creator_array[0];
	$creator_info = get_userdata($creator_id);
	
	
	// PARTY
	$party_id = wpclink_get_option('authorized_party');
	$party_info = get_userdata($party_id);
	

	?></license_type>
    <request_content_id><?php echo $content_id; ?></request_content_id>
    <request_content_url><?php echo $content_url; ?></request_content_url>
    <party_name><?php echo $party_info->display_name; ?></party_name>
    <party_email><?php echo $party_info->user_email; ?></party_email>
    <creator_name><?php echo $creator_info->display_name; ?></creator_name>
    <creator_email><?php echo $creator_info->user_email; ?></creator_email>
    </channel>
</rss><?php 
		
	}else{
		
	$license_promoted_id = wpclink_add_license_promoted($client_site,$ip,$agreement_status,1,$link_firstname,$link_lastname,$link_display,$content_id,$content_url,'',$extra_link,$token);
	
	// Electronic Signature by Licensor
	wpclink_add_esign($esign_by,$esign_reason,$esign_sign_date,$esign_time_formated,$token,$esign_email,$ip,$content_id,$license_promoted_id,$esign_html_stamp);	
	
	
	
	
	// Time
	$esign_found = wpclink_get_esign_by_post_id($content_id);
	$esign_added_id = $esign_found['esign_id'];
	$view_time = date("Y-m-d H:i:s");
		
		
		echo '<?xml version="1.0" encoding="UTF-8" ?>'; ?><rss version="2.0"
	xmlns:excerpt="http://wordpress.org/export/1.2/excerpt/"
	xmlns:content="http://purl.org/rss/1.0/modules/content/"
	xmlns:wfw="http://wellformedweb.org/CommentAPI/"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:wp="http://wordpress.org/export/1.2/"
>
	<channel>
    <site_address><?php echo bloginfo('url').'/'; ?></site_address>
    <secret_key><?php echo wpclink_get_option('DYNAMIC_URL_POSTFIX_SECRET_KEY'); ?></secret_key>
    <auth_code><?php echo wpclink_get_option('DYNAMIC_URL_POSTFIX_DATA_KEY'); ?></auth_code> 
    <license_type><?php
	
	if($license_type = get_post_meta($content_id,'wpclink_creation_license_type',true)){
		if($license_type == '0'){
			echo wpclink_get_option('wpclink_license_type');
		}else{
			echo $license_type;
		}
	}else{
		echo wpclink_get_option('wpclink_license_type');
	}
	
	// CREATOR
	$creator_array = wpclink_get_option('authorized_creators');
	$creator_id = $creator_array[0];
	$creator_info = get_userdata($creator_id);
	
	
	// PARTY
	$party_id = wpclink_get_option('authorized_party');
	$party_info = get_userdata($party_id);
	
	?></license_type>
    <request_content_id><?php echo $content_id; ?></request_content_id>
    <request_content_url><?php echo $content_url; ?></request_content_url>
    <party_name><?php echo $party_info->display_name; ?></party_name>
    <party_email><?php echo $party_info->user_email; ?></party_email>
    <creator_name><?php echo $creator_info->display_name; ?></creator_name>
    <creator_email><?php echo $creator_info->user_email; ?></creator_email>
    </channel>
</rss><?php 
		}
	}else{
		// INVALID
		echo '<?xml version="1.0" encoding="UTF-8" ?>'; ?>
		<rss version="2.0"
	xmlns:excerpt="http://wordpress.org/export/1.2/excerpt/"
	xmlns:content="http://purl.org/rss/1.0/modules/content/"
	xmlns:wfw="http://wellformedweb.org/CommentAPI/"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:wp="http://wordpress.org/export/1.2/"
>
	<channel>
    <response><?php echo 'invalid'; ?></response> 
    </channel>
</rss>

		<?php 
	}
	die();
	
}elseif(($_GET['cl_action'] == 'cl_list') and !empty($_GET['client_site'])){
	
	echo '<?xml version="1.0" encoding="UTF-8" ?>'; ?>
		<rss version="2.0"
	xmlns:excerpt="http://wordpress.org/export/1.2/excerpt/"
	xmlns:content="http://purl.org/rss/1.0/modules/content/"
	xmlns:wfw="http://wellformedweb.org/CommentAPI/"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:wp="http://wordpress.org/export/1.2/"
><channel><?php 
	$site_url =	$_GET['client_site'];
	$client_site = urldecode($site_url);
	$content_id = $_GET['content_id'];
	
	// List of All Links
	wpclink_linked_complete_list_v3($content_id,$client_site); ?></channel>
</rss>
	<?php 
}elseif(($_GET['cl_action'] == 'disconnect') and !empty($_GET['client_site'])){
	
	$site_url =	$_GET['client_site'];
	$client_site = urldecode($site_url);
	
	// GET IP
	$url = parse_url($client_site);
	$host_url = $url['host'];
	
	// PICK IP
	//$ip = gethostbyname($host_url);
	$ip = wpclink_get_client_ip();
	
	
	global $wpdb;
	$clink_sites_table = $wpdb->prefix . 'wpclink_licenses'; 
	
	// Need Single
	$ip_match = $wpdb->get_row( "SELECT * FROM $clink_sites_table WHERE site_url = '$client_site' AND mode = 'referent' " );
	
	if($ip_match){
	
		// Cencel
		$deleted_agr = $wpdb->delete( $clink_sites_table, array( 'site_url' => $client_site ) );
		
		
		echo '<?xml version="1.0" encoding="UTF-8" ?>'; ?>
		<rss version="2.0"
	xmlns:excerpt="http://wordpress.org/export/1.2/excerpt/"
	xmlns:content="http://purl.org/rss/1.0/modules/content/"
	xmlns:wfw="http://wellformedweb.org/CommentAPI/"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:wp="http://wordpress.org/export/1.2/"
>
	<channel>
    <cencel_agree>1</cencel_agree>
    </channel>
</rss>
		<?php 
		
	}
	
}elseif(isset($_GET['token'])){
	
global $wpdb;

// Table Prefix
$table_name_token = $wpdb->prefix . 'wpclink_tokens'; 

$request_agree = $_GET;
$token = $request_agree['token'];


$record_found = $wpdb->get_row( 'SELECT * FROM '.$table_name_token.' WHERE token = "'.$token.'" AND token_expiration <> 1' );

if($record_found){

// Content ID
$content_id = $record_found->post_id;

// Get User from Post Meta
$user_id = get_post_meta($content_id,'wpclink_post_copyright_owner_id',true);

// Update the Deliver Time
$deliver_time = date("Y-m-d H:i:s");

// Update
$wpdb->update( 
	$table_name_token, 
	array( 
		'license_deliver_date' => $deliver_time,
	), 
	array( 'token' => $token ));



// Copyright Owner Display Name
$user_info = get_userdata($user_id);
$display_name = $user_info->display_name;
$email_address = $user_info->user_email;


$creator_array = wpclink_get_option('authorized_creators');
$creator_id = $creator_array[0];
$party_id = wpclink_get_option('authorized_party');

if($user_id == $creator_id){
	$identifier = get_user_meta($user_id,'wpclink_creator_identifier',true);
}elseif($user_id == $party_id){
	$identifier = get_user_meta($user_id,'wpclink_party_identifier',true);
}else{
	
	$creator_identifier_exists = get_user_meta($user_id,'wpclink_creator_identifier',true);
	$party_identifier_exists = get_user_meta($user_id,'wpclink_party_identifier',true);
	
	if(!empty($creator_identifier_exists)){
		$identifier = $creator_identifier_exists;
	}else if(!empty($party_identifier_exists)){
		$identifier = $party_identifier_exists;
	}
}

echo '<?xml version="1.0" encoding="UTF-8" ?>'; ?>
<rss version="2.0"
	xmlns:excerpt="http://wordpress.org/export/1.2/excerpt/"
	xmlns:content="http://purl.org/rss/1.0/modules/content/"
	xmlns:wfw="http://wellformedweb.org/CommentAPI/"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:wp="http://wordpress.org/export/1.2/"
>
<channel>
<title><?php bloginfo('name'); ?></title>
<link><?php bloginfo('url'); ?></link>
<description><?php bloginfo('description'); ?></description>
<pubDate><?php echo $curr_date_time; ?></pubDate>
<language><?php bloginfo('language'); ?></language>
<wp:wxr_version>1.2</wp:wxr_version>
<wp:base_site_url><?php echo $site_url; ?></wp:base_site_url>
<wp:base_blog_url><?php echo site_url(); ?></wp:base_blog_url>
<blog_local_time><?php echo date( 'Y-m-d H:i:s', current_time( 'timestamp', 0 )); ?></blog_local_time>
<generator>https://wordpress.org/?v=4.6.1</generator>
<cl_status><?php echo 'active'; ?></cl_status>
<esign_copyright_owner><?php echo $display_name; ?></esign_copyright_owner>
<esign_copyright_identifier><?php echo $identifier; ?></esign_copyright_identifier>
<esign_reason><?php echo 'ldc'; ?></esign_reason>
<esign_time><?php echo date( 'Y-m-d H:i:s', current_time( 'timestamp', 0 )); ?></esign_time>
<esign_email><?php echo $email_address; ?></esign_email>
<agreement>
<![CDATA[<?php echo wpclink_agreement_template_ready($content_id); ?>]]>
</agreement>
<license_type><?php 

	if($license_type = get_post_meta($content_id,'wpclink_creation_license_type',true)){
		if($license_type == '0'){
			echo wpclink_get_option('wpclink_license_type');
		}else{
			echo $license_type;
		}
	}else{
		echo wpclink_get_option('wpclink_license_type');
	}

 ?></license_type>
</channel>
</rss>

<?php
		}else{
			// INVALID
		echo '<?xml version="1.0" encoding="UTF-8" ?>'; ?>
		<rss version="2.0"
	xmlns:excerpt="http://wordpress.org/export/1.2/excerpt/"
	xmlns:content="http://purl.org/rss/1.0/modules/content/"
	xmlns:wfw="http://wellformedweb.org/CommentAPI/"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:wp="http://wordpress.org/export/1.2/"
>
	<channel>
    <response><?php echo 'invalid'; ?></response> 
    </channel>
</rss>

		<?php 
		}
	}

}